@@ -107,7 +107,7 @@ static void divl(void)
 	uint64_t i; int donei=0; int oldi;
 	uint_fast32_t j; int donej=0; int oldj;
 	uint32_t tmp;
-	
+
 	fprintf(stderr, "divl y:\n");
 	for (i=0;!donei;)
 	{
@@ -178,7 +178,7 @@ static void imul_1_w(void)
 	for (i=0;i<=65536;)
 	{
 		for (j=0;j<=65536;)
-		{			
+		{
 			state.ax=i;
 			asm_imul_1_w(&state, j);
 			tmp = ((int_fast32_t)(int16_t)i)*(int16_t)j;
@@ -217,7 +217,7 @@ static void imul_1_l(void)
 	{
 		donej=0;
 		for (j=0;!donej;)
-		{			
+		{
 			state.eax=i;
 			asm_imul_1_l(&state, j);
 			tmp = ((int_fast64_t)(int32_t)i)*(int32_t)j;
@@ -228,7 +228,7 @@ static void imul_1_l(void)
 			else if ((tmp & 0xffffffff00000000LL) == 0xffffffff00000000LL)
 				tmp2 = 0;
 			else
-				tmp2 = 1; 
+				tmp2 = 1;
 			if ((state.eax != tmp3) || (state.edx != tmp4) || (read_cf(state.eflags) != tmp2) || (read_of(state.eflags) != tmp2))
 			{
 				failed++;
@@ -255,7 +255,8 @@ static void imul_2_l(void)
 	int i; int donei=0; int oldi;
 	int j; int donej=0; int oldj;
 	int_fast64_t tmp;
-/*	int tmp2;*/
+/*
+	int tmp2;*/
 	uint32_t tmp3, tmp4;
 
 	fprintf(stderr, "imul_2_l x,y:\n");
@@ -263,7 +264,7 @@ static void imul_2_l(void)
 	{
 		donej=0;
 		for (j=0x80000000;!donej;)
-		{			
+		{
 			state.eax=i;
 			asm_imul_2_l(&state, j, &state.eax);
 			tmp = ((int_fast64_t)(int32_t)i)*(int32_t)j;
@@ -271,7 +272,8 @@ static void imul_2_l(void)
 			tmp4 = (uint_fast64_t)tmp>>32;
 			if ((tmp4 == 0x00000000) || (tmp4 == 0xffffffff)) /* we ignore overruns for now */
 			{
-/*			if ((tmp & 0xffffffff00000000LL) == 0x0000000000000000LL)
+/*
+			if ((tmp & 0xffffffff00000000LL) == 0x0000000000000000LL)
 				tmp2 = 0;
 			else if ((tmp & 0xffffffff00000000LL) == 0xffffffff00000000LL)
 				tmp2 = 0;
@@ -436,7 +438,7 @@ static void subb(void)
 }
 
 int main(int argc, char *argv[])
-{	
+{
 	init_assembler_state(&state, writecallback, readcallback);
 
 	asm_flds(&state, -123.4567);
@@ -509,7 +511,7 @@ int main(int argc, char *argv[])
 				case FPU_TAG_VALID:
 					fprintf(stderr, "VALID\n");
 					fprintf(stderr, "ST%d = " FPU_TYPE_FORMAT "\n", i, read_fpu_st(&state, i));
-					break;	
+					break;
 				case FPU_TAG_ZERO:
 					fprintf(stderr, "ZERO\n");
 					fprintf(stderr, "ST%d = " FPU_TYPE_FORMAT "\n", i, read_fpu_st(&state, i));
@@ -521,7 +523,7 @@ int main(int argc, char *argv[])
 						if (signbit(data))
 							fprintf(stderr, "- ");
 						else
-							fprintf(stderr, "+ ");						
+							fprintf(stderr, "+ ");
 						if (isnan(data))
 							fprintf(stderr, "NaN ");
 						if (isfinite(data))
