@@ -120,7 +120,7 @@ static void restartstuff(struct itimerval *i)
 	setitimer(ITIMER_REAL, &i[0], 0);
 	setitimer(ITIMER_VIRTUAL, &i[1], 0);
 	setitimer(ITIMER_PROF, &i[2], 0);
-	if (crashmode==101)	
+	if (crashmode==101)
 	{
 		if (_plSetGraphMode != NULL)
 			if (*_plSetGraphMode != NULL)
@@ -152,7 +152,8 @@ static const char *locate_ocp_ini(void)
 	const char *temp;
 	if ((temp=getenv("CPDIR")))
 	{
-/*		if (!AllowSymlinked)
+/*
+		if (!AllowSymlinked)
 		{
 			fprintf(stderr, "Using $CPDIR when running setuid is not allowed\n");
 		} else*/if ((retval=locate_ocp_ini_try(temp)))
@@ -314,7 +315,7 @@ void sigsegv(int signal)
 		snprintf(buffer, sizeof(buffer), "%d", getpid());
 		argv[3]=buffer;
 		argv[4]=NULL;
-	
+
 		if (!(pid=fork()))
 		{
 			if (!isatty(2))
@@ -389,7 +390,7 @@ int validate_home(void)
 	char *temp;
 	const char *temp2;
 	struct stat st;
-	
+
 	if (!home)
 		home="/root";
 	else if (!strlen(home))
@@ -508,9 +509,11 @@ static void *locate_libocp_try(const char *src, int verbose)
 static char *locate_libocp(void)
 {
 	char *retval;
-/*	if (AllowSymlinked)
+/*
+	if (AllowSymlinked)
 		if ((retval=locate_libocp_try(dir, 0)))
-			return retval;*/
+			return retval;
+*/
 	if ((retval=locate_libocp_try(LIBDIR, 1)))
 		return retval;
 	if ((retval=locate_libocp_try(PREFIX "/lib", 1)))
@@ -601,6 +604,8 @@ int main(int argc, char *argv[])
 
 #ifdef __linux
 	dir=get_current_dir_name();
+#elif defined(HAVE_GETCWD)
+	dir=getcwd(malloc(PATH_MAX), PATH_MAX);
 #else /* BSD */
 	dir=getwd(malloc(PATH_MAX));
 #endif
