@@ -1,7 +1,7 @@
 #ifndef _PLINKMAN_H
 #define _PLINKMAN_H 1
 
-struct linkinfostruct
+struct __attribute__ ((aligned (64))) linkinfostruct
 {
 	const char *name;
 	const char *desc;
@@ -15,6 +15,7 @@ struct linkinfostruct
 	void (*Close)(void);
 	void (*LateClose)(void); /* low priority Close */
 };
+#define LINKINFOSTRUCT_NOEVENTS ,0,0,0,0,0,0
 
 struct dll_handle
 {
@@ -36,4 +37,10 @@ extern char *lnkReadInfoReg(const int id, const char *key);
 extern int lnkCountLinks(void);
 extern int lnkGetLinkInfo(struct linkinfostruct *l, int index);
 
+#ifdef SUPPORT_STATIC_PLUGINS
+#define DLLEXTINFO_PREFIX __attribute__ ((section ("plugin_list"))) __attribute__ ((used)) static
+#else
+#define DLLEXTINFO_PREFIX
+#endif
+
 #endif
