@@ -110,7 +110,7 @@ static int cmdhlp(void)
 		printf("     curses       : ncurses driver\n");
 		printf("     x11          : x11 driver\n");
 		printf("     vcsa         : vcsa/fb linux console driver\n");
-		printf("     sdl          : SDL video driverr\n");
+		printf("     sdl          : SDL video driver\n");
 		printf("\nExample : ocp -fl0,r1 -vp75,f2 -spdevpdisk -sr48000 ftstar.xm\n");
 		printf("          (for nice HD rendering of modules)\n");
 		return errHelpPrinted;
@@ -196,7 +196,7 @@ static int init_modules(int argc, char *argv[])
 			cfSetProfileString("devpCA", "link", "devpcoreaudio");
 
 			fprintf(stderr, "ocp.ini update (0.1.14) changed [devsOSS] revstereo to off\nn");
-			cfSetProfileBool("devsOSS", "revstereo", 0);	
+			cfSetProfileBool("devsOSS", "revstereo", 0);
 
 			fprintf(stderr, "ocp.ini update (0.1.14) adds [filetype 38]\n");
 			cfSetProfileInt("filetype 38", "color", 6, 10);
@@ -222,7 +222,7 @@ static int init_modules(int argc, char *argv[])
 
 			fprintf(stderr, "ocp.ini update (0.1.16) adds [x11] font=1\n");
 			cfSetProfileInt("x11", "font", cfGetProfileInt("x11", "font", 1, 10), 10);
-	
+
 			fprintf(stderr, "ocp.ini update (0.1.16) adds [x11] xvidmode=on\n");
 			cfSetProfileBool("x11", "xvidmode", cfGetProfileBool("x11", "xvidmode", 1, 1));
 		}
@@ -270,9 +270,56 @@ static int init_modules(int argc, char *argv[])
 			cfSetProfileString("fileselector", "modextensions", temp2);
 		}
 
-		if (epoch < 20100517)
+		if (epoch < 20110319)
 		{
-			cfSetProfileInt("version", "epoch", 20100517, 10);
+			const char *list;
+			char temp1[1024];
+
+			fprintf(stderr, "ocp.ini update (0.1.21) adds devpSDL\n");
+
+			list = cfGetProfileString("sound", "playerdevices", "");
+
+			if (strstr(list, "devpSDL"))
+			{
+				snprintf(temp1, sizeof(temp1), "%s", list);
+			} else {
+				int added = 0;
+				temp1[0] = 0;
+				while (1)
+				{
+					char drvhand[9];
+					if (!cfGetSpaceListEntry(drvhand, &list, 8))
+						break;
+
+					if (!strcmp (drvhand, "devpNONE"))
+					{
+						added = 1;
+						if (strlen(temp1) < 1014)
+							strcat (temp1, " devpSDL");
+					}
+					if (strlen(temp1) < 1014)
+					{
+						strcat (temp1, " ");
+						strcat (temp1, drvhand);
+					}
+				}
+
+				if (!added)
+				{
+					added = 1;
+					if (strlen(temp1) < 1014)
+						strcat (temp1, " devpSDL");
+				}
+			}
+
+			cfSetProfileString("sound", "playerdevices", temp1);
+
+			cfSetProfileString("devpSDL", "link", "devpsdl");
+		}
+
+		if (epoch < 20110319)
+		{
+			cfSetProfileInt("version", "epoch", 20110319, 10);
 			cfStoreConfig();
 			if (isatty(2))
 			{
@@ -283,13 +330,13 @@ static int init_modules(int argc, char *argv[])
 			sleep(5);
 		}
 	}
-	if (cfGetProfileInt("version", "epoch", 0, 10)!=20100517)
+	if (cfGetProfileInt("version", "epoch", 0, 10)!=20110319)
 	{
 		if (isatty(2))
 		{
-			fprintf(stderr,"\n\033[1m\033[31mWARNING, ocp.ini [version] epoch != 20100515\033[0m\n\n");
+			fprintf(stderr,"\n\033[1m\033[31mWARNING, ocp.ini [version] epoch != 20110319\033[0m\n\n");
 		} else {
-			fprintf(stderr,"\nWARNING, ocp.ini [version] epoch != 20100515\033[0m\n\n");
+			fprintf(stderr,"\nWARNING, ocp.ini [version] epoch != 20110319\033[0m\n\n");
 		}
 		sleep(5);
 	}
@@ -405,7 +452,7 @@ static int _bootup(int argc, char *argv[])
 		if (result!=errHelpPrinted)
 			fprintf(stderr, "%s\n", errGetLongString(result));
 
-    	done_modules();
+	done_modules();
 
 	cfCloseConfig();
 
