@@ -1,16 +1,11 @@
 #ifndef __PMAIN_H
 #define __PMAIN_H
 
-struct initcloseregstruct
-{
-	int (*Init)(void);
-	void (*Close)(void);
-	struct initcloseregstruct *next;
-};
-
 struct mainstruct
 {
 	int (*main)(int argc, char *argv[]);
 };
 
+extern struct mainstruct *ocpmain;
+
 #endif
