@@ -82,7 +82,7 @@ static int readiniline(char *key, char *str, char *comment, const char *line)
 	const char *chk;
 
 	comment[0]=0;
-	
+
   /* read until we get a line*/
 	while (isspace(*line))
 		line++;
@@ -96,7 +96,7 @@ static int readiniline(char *key, char *str, char *comment, const char *line)
 
 	sol=line;
 	eol=sol;
-    
+
 	while ((*eol!='#')&&(*eol!=';')&&(*eol))
 		eol++;
 	if ((eol[0]==';')||(eol[0]=='#'))
@@ -127,18 +127,18 @@ static int readiniline(char *key, char *str, char *comment, const char *line)
 			return 0;
 		chk--;
 	}
-	
+
 	if ((chk-sol)>=(KEYBUF_LEN-1))
 		return 0;
 	memcpy(key, sol, chk-sol);
 	key[chk-sol]=0;
-	
+
 	while (chk[-1]!='=')
 		chk++;
-	
+
 	while ((chk<eol)&&isspace(*chk))
 		chk++;
-	
+
 	if ((eol-chk)>=(STRBUF_LEN-1))
 		return 0;
 	memcpy(str, chk, eol-chk);
@@ -168,12 +168,10 @@ static int cfReadINIFile(int argc, char *argv[])
 
 	cfINIApps=0;
 	cfINInApps=0;
-	
+
 	if (!(f=fopen(path, "r")))
 		return 1;
 
-/*	fprintf(stderr, "Parsing %s\n", path);*/
- 
 	while (fgets(linebuffer, sizeof(linebuffer), f))
 	{
 		linenum++;
@@ -282,7 +280,7 @@ static int cfReadINIFile(int argc, char *argv[])
 						argvstat++;
 				}
 			}
-			
+
 		cfINInApps++;
 		cfINIApps=realloc(cfINIApps, sizeof(cfINIApps[cfINInApps])*cfINInApps);
 		cfINIApps[cfINInApps-1].app=strdup("CommandLine");
@@ -298,7 +296,7 @@ static int cfReadINIFile(int argc, char *argv[])
 
 				if ((argv[c][1]=='-')&&(!argv[c][2])) /* Unix legacy */
 					break;
-				
+
 				cfINIApps[cfINInApps-1].nkeys++;
 				cfINIApps[cfINInApps-1].keys=realloc(cfINIApps[cfINInApps-1].keys, sizeof(cfINIApps[cfINInApps-1].keys[0])*(index+1));
 				cfINIApps[cfINInApps-1].keys[index].key=strdup("_");
@@ -307,7 +305,7 @@ static int cfReadINIFile(int argc, char *argv[])
 				cfINIApps[cfINInApps-1].keys[index].linenum=-1;
 				cfINIApps[cfINInApps-1].keys[index].comment=NULL;
 			}
-	
+
 		cfINInApps++;
 		cfINIApps=realloc(cfINIApps, sizeof(cfINIApps[cfINInApps])*cfINInApps);
 		cfINIApps[cfINInApps-1].app=strdup("CommandLine--");
@@ -315,7 +313,7 @@ static int cfReadINIFile(int argc, char *argv[])
 		cfINIApps[cfINInApps-1].nkeys=0;
 		cfINIApps[cfINInApps-1].linenum=-1;
 		cfINIApps[cfINInApps-1].comment=NULL;
-	
+
 		for (c=1;c<argc;c++)
 			if ((argv[c][0]=='-')&&(argv[c][1]=='-'))
 			{
@@ -323,7 +321,7 @@ static int cfReadINIFile(int argc, char *argv[])
 
 				if (!argv[c][2]) /* Unix legacy */
 					break;
-				
+
 				cfINIApps[cfINInApps-1].nkeys++;
 				cfINIApps[cfINInApps-1].keys=realloc(cfINIApps[cfINInApps-1].keys, sizeof(cfINIApps[cfINInApps-1].keys[0])*(index+1));
 				cfINIApps[cfINInApps-1].keys[index].key=strdup(argv[c]+2);
@@ -331,7 +329,7 @@ static int cfReadINIFile(int argc, char *argv[])
 				cfINIApps[cfINInApps-1].keys[index].linenum=-1;
 				cfINIApps[cfINInApps-1].keys[index].comment=NULL;
 			}
-	
+
 		cfINInApps++;
 		cfINIApps=realloc(cfINIApps, sizeof(cfINIApps[cfINInApps])*cfINInApps);
 		cfINIApps[cfINInApps-1].app=strdup("CommandLine_Files");
@@ -376,7 +374,6 @@ static int cfReadINIFile(int argc, char *argv[])
 				}
 			}
 		}
-	
 	}
 	fclose(f);
 	return 0;
@@ -525,7 +522,7 @@ void cfRemoveEntry(const char *app, const char *key)
 							free(cfINIApps[i].keys[j].key);
 						if (cfINIApps[i].keys[j].comment)
 							free(cfINIApps[i].keys[j].comment);
-						memmove(cfINIApps[i].keys + j, cfINIApps[i].keys + j + 1, cfINIApps[i].nkeys * sizeof(cfINIApps[i].keys[0]));
+						memmove(cfINIApps[i].keys + j, cfINIApps[i].keys + j + 1, (cfINIApps[i].nkeys - j  - 1) * sizeof(cfINIApps[i].keys[0]));
 						cfINIApps[i].nkeys--;
 						if (cfINIApps[i].nkeys)
 						{
@@ -546,7 +543,7 @@ int cfCountSpaceList(const char *str, int maxlen)
 	{
 		const char *fb;
 
-	    	while (isspace(*str))
+		while (isspace(*str))
 			str++;
 		if (!*str)
 			return i;
@@ -611,7 +608,7 @@ int cfGetConfig(int argc, char *argv[])
 			return -1;
 		}
 		strcat(cfDataDir, "/");
-   	}
+	}
 	t=getenv("TEMP");
 	if (!t)
 		t=getenv("TMP");
@@ -699,7 +696,7 @@ int cfStoreConfig(void)
 				strcat(buffer, cfINIApps[i].comment);
 			}
 			strcat(buffer, "\n");
-	
+
 			fprintf(f, "%s", buffer);
 			for (j=0;j<cfINIApps[i].nkeys;j++)
 				if (cfINIApps[i].keys[j].linenum>=0)
