@@ -132,7 +132,7 @@ void cpiSetTextMode(int size)
 void cpiDrawGStrings()
 {
 	char *verstr="  opencp v" VERSION;
-	char *author="(c) 1994-2010 Stian Skjelstad ";
+	char *author="(c) 1994-2011 Stian Skjelstad ";
 	char tstr[CONSOLE_MAX_X+1];
 
 #ifdef DEBUG
@@ -169,8 +169,8 @@ void cpiDrawGStrings()
 		int chann;
 		int chan0;
 		int i;
-		int limit=plScrWidth-(80-32);
 		int offset;
+		int limit=plScrWidth-(80-32);
 		char lstr[CONSOLE_MAX_X+1];
 
 
@@ -247,7 +247,7 @@ void cpiDrawGStrings()
 			int chan0;
 			int i;
 			int limit=plScrWidth-(80-32);
-			int offset;
+			/* int offset; */
 
 			if (limit<2)
 				limit=2;
@@ -260,7 +260,7 @@ void cpiDrawGStrings()
 			if (chan0<0)
 				chan0=0;
 
-			offset=plScrWidth/2-chann/2;
+			/* offset=plScrWidth/2-chann/2; */
 
 			for (i=0; i<chann; i++)
 			{ /* needs tuning... TODO */
@@ -466,7 +466,9 @@ static int plmpOpenFile(const char *path, struct moduleinfostruct *info, FILE **
 	strcpy(secname, "filetype ");
 
 	sprintf(secname+strlen(secname), "%d", info->modtype&0xff);
-/*	ultoa(info.modtype&0xFF, secname+strlen(secname), 10);*/
+/*
+	ultoa(info.modtype&0xFF, secname+strlen(secname), 10);
+*/
 
 	link=cfGetProfileString(secname, "pllink", "");
 	name=cfGetProfileString(secname, "player", "");
@@ -500,7 +502,7 @@ static int plmpOpenFile(const char *path, struct moduleinfostruct *info, FILE **
 		return 0;
 	}
 
-      	for (mod=cpiDefModes; mod; mod=mod->nextdef)
+	for (mod=cpiDefModes; mod; mod=mod->nextdef)
 		cpiRegisterMode(mod);
 	for (mod=cpiModes; mod; mod=mod->next)
 		if (!strcasecmp(mod->handle, curmodehandle))
@@ -612,9 +614,11 @@ static int cpiChanProcessKey(uint16_t key)
 			if (key=='0')
 				key=9;
 			else
-/*				if (key<='9')*/
+/*
+				if (key<='9')*/
 					key-='1';
-/*				else
+/*
+				else
 					key=(key>>8)-0x78+10;*/
 			if (key>=plNLChan)
 				break;
@@ -704,10 +708,12 @@ static interfaceReturnEnum plmpDrawScreen(void)
 	while (ekbhit())
 	{
 		uint16_t key=egetch();
-	/*	if ((key&0xFF)==0xE0)
+/*
+		if ((key&0xFF)==0xE0)
 			key&=0xFF00;
 		if (key&0xFF)
-			key&=0x00FF;*/
+			key&=0x00FF;
+*/
 		needdraw=0;
 
 		if (plEscTick)
