@@ -259,7 +259,9 @@ static int InstGetWin(struct cpitextmodequerystruct *q)
 				q->hgtmax=1+(plInsDisplay.height+3)/(/* 4 */plScrWidth/33);
 			else
 				q->hgtmax=1+(plInsDisplay.height+1)/(/* 2 */plScrWidth/40);
-/*			q->hgtmax=1+(plInsDisplay.height+1)/2;*/
+/*
+			q->hgtmax=1+(plInsDisplay.height+1)/2;
+*/
 			q->xmode=1;
 			break;
 		case 2:
