@@ -1,9 +1,22 @@
 /* OpenCP Module Player
- * copyright (c) '08-'09 Stian Skjelstad <stian@nixia.no>
+ * copyright (c) '08-'10 Stian Skjelstad <stian@nixia.no>
  *
  * Keyboard shortcut help-browser.
+ *'
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
- 
 
 #include "config.h"
 #include <curses.h>
@@ -41,6 +54,7 @@ static struct cpiKeyHelpKeyName KeyNames[] =
 	{KEY_CTRL_S, "ctrl+s"},
 	{KEY_CTRL_Z, "ctrl+z"},
 	{KEY_CTRL_BS, "ctrl+backspace"},
+	{KEY_CTRL_HOME, "ctrl+home"},
 	{KEY_DOWN, "down"},
 	{KEY_UP, "up"},
 	{KEY_LEFT, "left"},
@@ -305,4 +319,4 @@ void cpiKeyHelpDisplay(void)
 #ifndef SUPPORT_STATIC_PLUGINS
 char *dllinfo="";
 #endif
-DLLEXTINFO_PREFIX struct linkinfostruct dllextinfo = {"keyhelp", "OpenCP Key Helper (c) 2007 Stian Skjelstad", DLLVERSION, 0};
+DLLEXTINFO_PREFIX struct linkinfostruct dllextinfo = {"keyhelp", "OpenCP Key Helper (c) 2007-09 Stian Skjelstad", DLLVERSION, 0};
