@@ -219,7 +219,8 @@ static int plScopesKey(uint16_t key)
 		case KEY_TAB: /* tab */
 		case KEY_SHIFT_TAB:
 		/* case 0x0F00: // shift-tab */
-/* TODO -keys	case 0xA500: // alt-tab */
+/* TODO -keys
+		case 0xA500: // alt-tab */
 		case KEY_ALT_O:
 		/*case 0x1800: // alt-o*/
 			if (plOszChan==2)
@@ -361,7 +362,7 @@ static void drawframe(void)
 		} else
 			for (bp=replacebuf; bp<replacebufpos; bp++)
 				*bp&=0x00ffffff;
-		
+
 	dotbufpos=dotbuf;
 }
 
