@@ -201,9 +201,8 @@ static void plotbuf(uint32_t *buf, int len)
 {
 	int i;
 	uint8_t *b=(uint8_t*)buf;
-	uint32_t *buf2;
 
-	for (i=0, buf2=buf; i<len; i++, b+=4)
+	for (i=0; i<len; i++, b+=4)
 		*(uint8_t*)(plVidMem+(buf[i]&0x00ffffff))=(buf[i])>>24;
 }
 
@@ -316,7 +315,7 @@ static int plScopesKey(uint16_t key)
 			break;
 		case KEY_TAB: /* tab */
 		case KEY_ALT_O:
-		case KEY_SHIFT_TAB: 
+		case KEY_SHIFT_TAB:
 		/* case 0xA500 : // alt-tab TODO KEYS */
 			if (plOszChan==2)
 			{
@@ -381,9 +380,9 @@ static void plDrawScopes(void)
 				}
 				removescope((scopedx-scopesx)/2+x*scopedx, scopedy*(i/scopenx)+scopedy/2, scopes+((i&~1)|x)*scopesx, scopesx);
 				break;
- 			}
+			}
 			plGetLChanSample(i+chan0, plSampBuf, scopesx+(plOszTrigger?scopetlen:0), plOszRate/scopenx, 0);
-      			paus=plMuteCh[i];
+			paus=plMuteCh[i];
 			if (plChanChanged)
 			{
 				gdrawchar8p(x?616:8, 96+scopedy*(i>>1)+scopedy/2-3, '0'+(i+1+chan0)/10, ((i+chan0)==plSelCh)?15:paus?8:7, plOpenCPPict?(plOpenCPPict-96*640):0);
@@ -423,7 +422,7 @@ static void plDrawScopes(void)
 				continue;
 			}
 
-      			bp=plSampBuf;
+			bp=plSampBuf;
 			if (plOszTrigger)
 			{
 				int j;
