@@ -145,7 +145,7 @@ static void cpiSetFocus(const char *name)
 	cpiFocus=mode;
 	mode->active=1;
 	strcpy(cpiFocusHandle, cpiFocus->handle);
-	cpiTextRecalc();	
+	cpiTextRecalc();
 }
 
 void cpiTextSetMode(const char *name)
@@ -170,7 +170,7 @@ void cpiTextRecalc(void)
 	struct cpitextmodequerystruct win[10];
 	unsigned int nwin=0;
 	struct cpitextmoderegstruct *mode;
-	
+
 	int sidemin,sidemax,sidesize;
 	int winmin,winmax,winsize;
 
@@ -340,7 +340,6 @@ void cpiTextRecalc(void)
 			}
 			if (win[best].top)
 			{
-/*				wid=((winfirst>=sidefirst)&&((winfirst+hgt)<=(sidefirst+sideheight))&&(plScrWidth==132))?132:80;*/
 				wid=((winfirst>=sidefirst)&&((winfirst+hgt)<=(sidefirst+sideheight))&&(plScrWidth>=132))?plScrWidth:plScrWidth-52;
 				if (plScrWidth<132) /* dirty hack */
 					wid=plScrWidth;
@@ -349,7 +348,6 @@ void cpiTextRecalc(void)
 				winfirst+=hgt;
 				sidefirst=winfirst+hgt; /* dirty hack... not supposed to be here.... */
 			} else {
-/*				wid=(((winfirst+winheight)<=(sidefirst+sideheight))&&((winfirst+winheight-hgt)>=sidefirst)&&(plScrWidth==132))?132:80;*/
 				wid=(((winfirst+winheight)<=(sidefirst+sideheight))&&((winfirst+winheight-hgt)>=sidefirst)&&(plScrWidth>=132))?plScrWidth:plScrWidth-52;
 				if (plScrWidth<132) /* dirty hack */
 					wid=plScrWidth;
@@ -362,7 +360,8 @@ void cpiTextRecalc(void)
 			winsize-=win[best].size;
 			winmax-=win[best].hgtmax;
 
-/*			if (wid>=132)
+/*
+			if (wid>=132)
 			{
 				if (win[best].top)
 				{
@@ -568,7 +567,7 @@ static void txtCloseMode(void)
 {
 	struct cpitextmoderegstruct *mode;
 
-      	cpiSetFocus(0);
+	cpiSetFocus(0);
 	for (mode=cpiTextActModes; mode; mode=mode->nextact)
 		if (mode->Event)
 			mode->Event(cpievClose);
