@@ -247,7 +247,8 @@ static void preparetrack8inf(uint16_t *bp)
 
 struct patviewtype
 {
-/*	uint8_t maxch;   These are now calculated real-time */
+/*
+	uint8_t maxch;   These are now calculated real-time */
 	uint8_t gcmd;
 	uint8_t width;
 	const char *title;
@@ -515,7 +516,7 @@ static void gmdDrawPattern(int sel)
 	int curpat=pat;
 	signed int crow=currow;
 	signed int i,j,row;
-	int plen;
+	/* int plen; */
 
 	if (plPatManualPat!=-1)
 	{
@@ -573,7 +574,7 @@ static void gmdDrawPattern(int sel)
 	displaystrattr(plPatFirstLine-1, 0, pattitle2, plPatWidth);
 	/* done */
 
-	plen=getpatlen(pat);
+	/* plen=getpatlen(pat); */
 	for (i=0, row=crow-min(plPatHeight/3, 20); i<plPatHeight; i++, row++)
 	{
 		/* if no manual position, and we are not at the current position, display the buffer normal */
@@ -684,7 +685,7 @@ static int gmdTrkProcessKey(uint16_t key)
 			}
 			break;
 		case KEY_SHIFT_TAB:
-/* TODO-keys	
+/* TODO-keys
 		case 0xA500:*/
 			if (plPatManualPat==-1)
 			{
