@@ -40,28 +40,28 @@ static int GIFimageInterlace=0; /* oh I am so lazy */
 static int *interlaceTable=0; /* I'm so lame it hurts */
 static int currentLine=0; /* my brain hurts */
 
-static /*inline*/ int get_byte(void) 
+static /*inline*/ int get_byte(void)
 {
-	if(filedata<filedataEnd) 
+	if(filedata<filedataEnd)
 		return *filedata++;
 
 	return -1;
 }
 
-static /*inline*/ int out_line(uint8_t *line, int len) 
+static /*inline*/ int out_line(uint8_t *line, int len)
 {
 	int i;
 
-	if(GIFimageInterlace) 
+	if(GIFimageInterlace)
 	{
-		if(currentLine<GIFimageHeight) 
+		if(currentLine<GIFimageHeight)
 		{
 			int offset=interlaceTable[currentLine++];
 			for(i=0; i<len; i++)
 				image[offset+i]=line[i];
 			return 0;
 		}
-	} else if(currentLine<GIFimageHeight) 
+	} else if(currentLine<GIFimageHeight)
 	{
 		currentLine++;
 		for(i=0; i<len; i++)
@@ -111,7 +111,7 @@ static uint8_t b1;                           /* Current byte */
 static uint8_t byte_buff[257];               /* Current block */
 static uint8_t *pbytes;                      /* Pointer to next byte in block */
 
-static int32_t code_mask[13] = 
+static int32_t code_mask[13] =
 {
 	0,
 	0x0001, 0x0003,
@@ -416,9 +416,9 @@ int GIF87read(unsigned char *fd, int filesize, unsigned char *pic, unsigned char
 	uint16_t GIFscreenHeight;
 	uint8_t byte;
 	int GIFglobalColorMap;
-	int GIFcolorResolution;
+	/* int GIFcolorResolution; */
 	int GIFbitPerPixel;
-	uint8_t GIFbackground;
+	/* uint8_t GIFbackground; */
 	uint16_t GIFimageLeft;
 	uint16_t GIFimageTop;
 	uint16_t GIFimageWidth;
@@ -435,9 +435,9 @@ int GIF87read(unsigned char *fd, int filesize, unsigned char *pic, unsigned char
 	/* check if file format is GIF87 */
 	GIFsignature=(unsigned char *)"GIF87a";
 	for(i=0; i<6; i++)
-		if(GIFsignature[i]!=*filedata++) 
+		if(GIFsignature[i]!=*filedata++)
 		{
-			if (i==4) 
+			if (i==4)
 				continue;
 			return -1;
 		}
@@ -451,12 +451,18 @@ int GIF87read(unsigned char *fd, int filesize, unsigned char *pic, unsigned char
 
 	byte=*filedata++;
 	GIFglobalColorMap=byte&128;
+#if 0
 	GIFcolorResolution=((byte&(64+32+16))>>4)+1;
+#endif
 	GIFbitPerPixel=(byte&7)+1;
 
+#if 0
 	GIFbackground=*filedata++;
+#else
+	filedata++;
+#endif
 
-	if(*filedata++!=0) 
+	if(*filedata++!=0)
 		return -1;
 
 	/* read the global color map */
@@ -489,7 +495,7 @@ int GIF87read(unsigned char *fd, int filesize, unsigned char *pic, unsigned char
 	GIFimageInterlace=byte&64;
 	GIFimageBitPerPixel=(byte&7)+1;
 
-	if(GIFimageInterlace) 
+	if(GIFimageInterlace)
 	{
 		int z;
 		interlaceTable=calloc(sizeof(int), GIFimageHeight);
