@@ -108,7 +108,7 @@ void mcpDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 		}
 		_writenum(buf[0], 62, 0x0F, globalmcpspeed*100/256, 10, 3);
 		_writenum(buf[0], 75, 0x0F, globalmcppitch*100/256, 10, 3);
-		
+
 		writestring(buf[1], 58, 0x09, "amp: ...% filter: ... ", 22);
 		_writenum(buf[1], 63, 0x0F, amp*100/64, 10, 3);
 		writestring(buf[1], 76, 0x0F, (set.filter==1)?"AOI":(set.filter==2)?"FOI":"off", 3);
@@ -139,7 +139,7 @@ void mcpDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 		if (splock)
 			writestring(buf[0], 115, 0x09, "\x1D", 1);
 		_writenum(buf[0], 124, 0x0F, globalmcppitch*100/256, 10, 3);
-		
+
 		writestring(buf[1], 81, 0x09, "              amplification: ...%  filter: ...     ", 52);
 		_writenum(buf[1], 110, 0x0F, amp*100/64, 10, 3);
 		writestring(buf[1], 124, 0x0F, (set.filter==1)?"AOI":(set.filter==2)?"FOI":"off", 3);
@@ -273,7 +273,8 @@ int mcpSetProcessKey(uint16_t key)
 			if (splock)
 				mcpSet(-1, mcpMasterSpeed, globalmcpspeed=globalmcppitch);
 			break;
-/* TODO-keys	case 0x5f00: // ctrl f2
+/* TODO-keys
+		case 0x5f00: // ctrl f2
 			if ((amp-=4)<4)
 				amp=4;
 			mcpSet(-1, mcpMasterAmplify, 256*amp);
@@ -318,7 +319,8 @@ int mcpSetProcessKey(uint16_t key)
 		case KEY_BACKSPACE:
 			mcpSet(-1, mcpMasterFilter, set.filter=(set.filter==1)?2:(set.filter==2)?0:1);
 			break;
-/* TODO-keys	case 0x6a00:
+/* TODO-keys
+		case 0x6a00:
 			mcpNormalize();
 			break;
 		case 0x6900:
