@@ -47,7 +47,6 @@ int deviReadDevices(const char *list, struct devinfonode **devs)
 		char *dsym;
 		struct sounddevice *dev;
 		int bypass;
-/*		char str[100];*/
 
 		if (!cfGetSpaceListEntry(drvhand, &list, 8))
 			break;
@@ -62,7 +61,7 @@ int deviReadDevices(const char *list, struct devinfonode **devs)
 		for (i=strlen(drvhand); i<8; i++)
 			fprintf(stderr, " ");
 		fprintf(stderr, ": ");
-		
+
 		strncpy(dname,cfGetProfileString(drvhand, "link", ""),19);
 
 		n->linkhand=lnkLink(dname);
@@ -103,10 +102,12 @@ int deviReadDevices(const char *list, struct devinfonode **devs)
 		n->keep=dev->keep;
 		n->devinfo.port=cfGetProfileInt(drvhand, "port", -1, 16);
 		n->devinfo.port2=cfGetProfileInt(drvhand, "port2", -1, 16);
-/*		n->dev.irq=cfGetProfileInt(drvhand, "irq", -1, 10);
+/*
+		n->dev.irq=cfGetProfileInt(drvhand, "irq", -1, 10);
 		n->dev.irq2=cfGetProfileInt(drvhand, "irq2", -1, 10);
 		n->dev.dma=cfGetProfileInt(drvhand, "dma", -1, 10);
-		n->dev.dma2=cfGetProfileInt(drvhand, "dma2", -1, 10);*/
+		n->dev.dma2=cfGetProfileInt(drvhand, "dma2", -1, 10);
+*/
 		n->devinfo.subtype=cfGetProfileInt(drvhand, "subtype", -1, 10);
 		strncpy(n->devinfo.path, cfGetProfileString(drvhand, "path", ""), sizeof(n->devinfo.path));
 		n->devinfo.path[sizeof(n->devinfo.path)-1]=0;
@@ -132,7 +133,7 @@ int deviReadDevices(const char *list, struct devinfonode **devs)
 				fprintf(stderr, " not found: optimize ocp.ini!\n");
 				lnkFree(n->linkhand);
 				free(n);
-			        continue;
+				continue;
 			}
 		} else
 			n->devinfo.devtype=dev;
@@ -152,9 +153,10 @@ int deviReadDevices(const char *list, struct devinfonode **devs)
 			fprintf(stderr, " q%x", n->devinfo.port2);
 		if (n->devinfo.mem)
 			fprintf(stderr, " m%d", (int)(n->devinfo.mem>>10));
-		fprintf(stderr, ")\n"); 
-		
-/*		strcpy(str, " (");
+		fprintf(stderr, ")\n");
+
+/*
+		strcpy(str, " (");
 		strcat(str, "#");
 		ltoa(n->ihandle, str+strlen(str), 10);
 		if (n->dev.subtype!=-1)
