@@ -225,7 +225,7 @@ static int plrReadDir(struct modlist *ml, const struct dmDrive *drive, const uin
 				modlist_append(ml, &m);
 			}
 		}
-			
+
 	}
 
 	if (path==node)
@@ -238,9 +238,10 @@ static int plrReadDir(struct modlist *ml, const struct dmDrive *drive, const uin
 			memset(&m, 0, sizeof(m));
 
 			fsConvFileName12(m.name, hnd, ".DEV");
-/*			if (fsMatchFileName12(m.name, mask))*/
+/*
+			if (fsMatchFileName12(m.name, mask))*/
 			{
-				char npath[64];	
+				char npath[64];
 				m.fileref=mdbGetModuleReference(m.name, dev->devinfo.mem);
 				if (m.fileref==0xffffffff)
 					goto out;
