@@ -204,7 +204,7 @@ static int sampdevinit(void)
 	else
 		if (plSamplerDevices)
 			smpSetDevice(plSamplerDevices->handle, 1);
-	
+
 	fprintf(stderr, "\n");
 
 	smpBufSize=cfGetProfileInt2(cfSoundSec, "sound", "smpbufsize", 100, 10)*65;
@@ -274,7 +274,7 @@ static int smpReadDir(struct modlist *ml, const struct dmDrive *drive, const uin
 				m.flags=MODLIST_FLAG_DIR;
 				modlist_append(ml, &m);
 			}
-		}	
+		}
 	}
 
 	if (path==node)
@@ -287,7 +287,8 @@ static int smpReadDir(struct modlist *ml, const struct dmDrive *drive, const uin
 			memset(&m, 0, sizeof(m));
 
 			fsConvFileName12(m.name, hnd, ".DEV");
-/*			if (fsMatchFileName12(m.name, mask)) */
+/*
+			if (fsMatchFileName12(m.name, mask)) */
 			{
 				char npath[64];
 				m.fileref=mdbGetModuleReference(m.name, dev->devinfo.mem);
