@@ -257,7 +257,9 @@ static int mcpReadDir(struct modlist *ml, const struct dmDrive *drive, const uin
 			memset(&m, 0, sizeof(m));
 
 			fsConvFileName12(m.name, hnd, ".DEV");
-/*			if (fsMatchFileName12(m.name, mask))*/
+/*
+			if (fsMatchFileName12(m.name, mask))
+*/
 			{
 				char npath[64];
 				m.fileref=mdbGetModuleReference(m.name, dev->devinfo.mem);
@@ -300,8 +302,10 @@ static int mcpSetDev(const char *path, struct moduleinfostruct *mi, FILE **fp)
 static void mcpPrep(const char *path, struct moduleinfostruct *info, FILE **bp)
 {
 	mcpResetDevice();
-/*	if (info->gen.moduleflags&MDB_BIGMODULE)           TODO
-		mcpSetDevice(cfGetProfileString2(cfSoundSec, "sound", "bigmodules", ""), 0);  */
+/*
+	if (info->gen.moduleflags&MDB_BIGMODULE)           TODO
+		mcpSetDevice(cfGetProfileString2(cfSoundSec, "sound", "bigmodules", ""), 0);
+*/
 }
 
 
