@@ -72,15 +72,15 @@ extern void (*mcpSet)(int ch, int opt, int val);
 extern int (*mcpGet)(int ch, int opt);
 extern void (*mcpGetRealVolume)(int ch, int *l, int *r);
 extern void (*mcpGetRealMasterVolume)(int *l, int *r);
-extern void (*mcpGetMasterSample)(int16_t *s, int len, uint32_t rate, int opt);
-extern int (*mcpGetChanSample)(int ch, int16_t *s, int len, uint32_t rate, int opt);
-extern int (*mcpMixChanSamples)(int *ch, int n, int16_t *s, int len, uint32_t rate, int opt);
+extern void (*mcpGetMasterSample)(int16_t *s, unsigned int len, uint32_t rate, int opt);
+extern int (*mcpGetChanSample)(unsigned int ch, int16_t *s, unsigned int len, uint32_t rate, int opt);
+extern int (*mcpMixChanSamples)(unsigned int *ch, unsigned int n, int16_t *s, unsigned int len, uint32_t rate, int opt);
 
-extern int mcpMixMaxRate;
-extern int mcpMixProcRate;
+extern unsigned int mcpMixMaxRate;
+extern unsigned int mcpMixProcRate;
 extern int mcpMixOpt;
-extern int mcpMixBufSize;
-extern int mcpMixMax;
+extern unsigned int mcpMixBufSize;
+extern unsigned int mcpMixMax;
 extern int mcpMixPoll;
 
 extern void (*mcpIdle)(void);
