@@ -43,14 +43,14 @@ static void __attribute__ ((used)) dummy55 (void)
 #ifdef __PIC__
 __asm__ __volatile__
 (
-	".local	interpolate\n"
-	".comm	interpolate,4,4\n"
-	".local	play16bit\n"
-	".comm	play16bit,4,4\n"
-	".local	playfloat\n"
-	".comm	playfloat,4,4\n"
-	".local	render16bit\n"
-	".comm	render16bit,4,4\n"
+	".local interpolate\n"
+	".comm  interpolate,4,4\n"
+	".local play16bit\n"
+	".comm  play16bit,4,4\n"
+	".local playfloat\n"
+	".comm  playfloat,4,4\n"
+	".local render16bit\n"
+	".comm  render16bit,4,4\n"
 	".local voltabs\n"
 	".comm  voltabs,8,8\n"
 	".comm  mixIntrpolTab,4,4\n"
@@ -63,7 +63,7 @@ __asm__ __volatile__
 #endif
 __asm__ __volatile__
 (
- 	".equ MIX_PINGPONGLOOP, %0\n"
+	".equ MIX_PINGPONGLOOP, %0\n"
 	".equ MIX_PLAYING, %1\n"
 	".equ MIX_LOOPED, %2\n"
 	".equ MIX_PLAYFLOAT, %3\n"
@@ -97,7 +97,6 @@ void mixasm_remap_start(void){}
 void mixPlayChannel(int32_t *buf, uint32_t len, struct mixchannel *ch, int stereo)
 {
 	int d0;
-	
 #ifdef __PIC__
 	int ebx;
 #endif
@@ -278,7 +277,6 @@ void mixPlayChannel(int32_t *buf, uint32_t len, struct mixchannel *ch, int stere
 #ifdef __PIC__
 		"  movl %14, %%ebx\n"
 #endif
-	
 		: "=&D" (d0)                                         /*   0  */
 		: "m" (stereo),                                      /*   1  */
 		  "m" (len),                                         /*   2  */
@@ -298,7 +296,7 @@ void mixPlayChannel(int32_t *buf, uint32_t len, struct mixchannel *ch, int stere
 #endif
 		  "0" (ch)
 		: "memory", "eax", "ecx", "edx", "esi"
-	);	    
+	);
 }
 
 static void __attribute__ ((used)) dummy54 (void)
@@ -399,7 +397,7 @@ static void __attribute__ ((used)) dummy54 (void)
 		  "m" (((struct mixchannel *)NULL)->fpos), /*  2  */
 		  "m" (((struct mixchannel *)NULL)->pos)   /*  3  */
 	);
-  
+
 	  __asm__ __volatile__
 	(
 		"playmono32:"
@@ -429,7 +427,7 @@ static void __attribute__ ((used)) dummy54 (void)
 		"    fmuls scale\n"
 		"    fistpl integer\n"
 		"    movl integer, %%eax\n"
-		
+
 		"    addl $1234, %%edx\n"
 		"edx3:\n"
 		"    adcl $1234, %%esi\n"
@@ -464,7 +462,7 @@ static void __attribute__ ((used)) dummy54 (void)
 		"  cmpl $0, play16bit\n"
 		"  jnz playmonoi16\n"
 
-		"  cmpl $0, playfloat\n" 
+		"  cmpl $0, playfloat\n"
 		"  jnz playmono32\n"   /* !! */
 
 		"  cmpl $0, %%ebp\n"
@@ -1109,7 +1107,7 @@ uint32_t mixAddAbs(const struct mixchannel *ch, uint32_t len)
 	__asm__ __volatile__
 	(
 #ifdef __PIC__
-	 	"movl %%ebx, %10\n"
+		"movl %%ebx, %10\n"
 #endif
 		"  testb $MIX_PLAY16BIT, %3(%%eax)\n"
 		                                  /*  %3 = ch->status */
@@ -1125,14 +1123,14 @@ uint32_t mixAddAbs(const struct mixchannel *ch, uint32_t len)
 		"  addl %6(%%eax), %%ebx\n"       /*  %6 = ch->samp */
 /* eax = ch
  * edi = target len
- * 
+ *
  * edx = replen
  * esi = current pos in sample (effecient pointer)
  * ebx = end (effecient pointer)
  */
 		"  addl %%esi, %%edi\n"
 /* edi = ETA end (effecient pointer)
- * 
+ *
  * eax = ch
  * edx = replen
  * esi = current pos in sample (effecient pointer)
@@ -1275,7 +1273,7 @@ uint32_t mixAddAbs(const struct mixchannel *ch, uint32_t len)
 
 		"mixAddAbs_exit:\n"
 #ifdef __PIC__
-	 	"movl %10, %%ebx\n"
+		"movl %10, %%ebx\n"
 
 #endif
 		: "=c"  (retval),                            /*   0  */
@@ -1303,10 +1301,10 @@ void mixClip(int16_t *dst, const int32_t *src, uint32_t len, int16_t (*tab)[256]
 	__asm__ __volatile__
 	(
 #ifdef __PIC__
-	 	"  pushl %%ebx\n" /* EBX is pic register */
+		"  pushl %%ebx\n" /* EBX is pic register */
 #endif
 		"  movl %%eax, %%ebx\n"
-		
+
 		"  movl %%ebx, (amp1-4)\n"
 		"  addl $512, %%ebx\n"
 		"  movl %%ebx, (amp2-4)\n"
@@ -1383,7 +1381,8 @@ void mixClip(int16_t *dst, const int32_t *src, uint32_t len, int16_t (*tab)[256]
 		"  cmpl $1234, %%edi\n"
 		"endp3:\n"
 		"  jb mixlp\n"
-/*		"  jmp done\n" */
+/*
+		"  jmp done\n" */
 
 		"done:\n"
 #ifdef __PIC__
@@ -1404,7 +1403,7 @@ void mixClip(int16_t *dst, const int32_t *src, uint32_t len, int16_t (*tab)[256]
 #else
 		: "memory", "ebx"
 #endif
-		
+
 	);
 }
 
@@ -1418,7 +1417,7 @@ int16_t (*mixIntrpolTab2)[256][2];
 uint32_t mixAddAbs(const struct mixchannel *chan, uint32_t len)
 {
 	unsigned long retval=0;
-	
+
 	if (chan->status&MIX_PLAY16BIT)
 	{
 		int replen=chan->replen;
@@ -1449,7 +1448,7 @@ uint32_t mixAddAbs(const struct mixchannel *chan, uint32_t len)
 			target-=replen;
 			pos-=replen;
 		}
-	
+
 	} else if (chan->status&MIX_PLAYFLOAT)
 	{
 		int replen=chan->replen;
@@ -1520,7 +1519,7 @@ void mixClip(int16_t *dst, const int32_t *src, uint32_t len, int16_t (*tab)[256]
 	int16_t *amp2=tab[1];
 	int16_t *amp3=tab[2];
 	int32_t min=~max;
-	int16_t minv = 
+	int16_t minv =
 		tab[0][min&0xff] +
 		tab[1][(min&0xff00)>>8] +
 		tab[2][(min&0xff0000)>>16];
@@ -2031,21 +2030,21 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 				len=mylen;
 			}
 		}
-	
+
 /*mixPlayChannel_playecx:*/
 		playrout(dst, mylen, ch);
 
 		dst+=mylen<<(!!stereo);
 		len-=mylen;
-		
+
 		pos=((uint64_t)ch->pos<<16)|ch->fpos;
 		pos+=(int64_t)mylen*(int64_t)ch->step;
-		
+
 		if (!inloop)
 			break;
 
 		eax=ch->pos;
-		
+
 		if (ch->step<0)
 		{
 			if (eax>=ch->loopstart)
@@ -2135,7 +2134,7 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 
 
 
-		
+
 		"mixPlayChannel_bigloop:\n"
 		"  movl %2, %%ecx\n"              /*  %2 = len */
 		"  movl %11(%%edi), %%ebx\n"      /* %11 = ch->step */
@@ -2149,7 +2148,7 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 		ebx=ch->step
 		edx=ch->pos
 		 si=ch->fpos
-		
+
 		inloop=0;
 
 
@@ -2166,7 +2165,6 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 		%11=->step
 		%12=->vol.voltabs[0]
 		%13=->vol.voltabs[1]
-	
 
 		"  cmpl $0, %%ebx\n"
 
@@ -2183,7 +2181,6 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 	edx=ch->pos
 		eax=ch->pos
 		 si=ch->fpos
-	
 		"    testb $MIX_LOOPED, %8(%%edi)\n"
 		                                  /*  %8 = ch->->status */
 		"    jz mixPlayChannel_maxplaylen\n"
@@ -2214,7 +2211,7 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 		edx=ch->pos
 		eax=runlength
 		 si=abs(ch->fpos) /* rel step */
-		
+
 		"  xorl %%edx, %%edx\n"
 
 		edx=0
@@ -2225,13 +2222,13 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 		edx=(runlength&0xffff0000)>>16
 
 		"  shll $16, %%esi\n"
-		
+
 		esi=abs(16bit ch->fpos)<<16
-		
+
 		"  shld $16, %%esi, %%eax\n"
-		
+
 		eax=(runlength<<16)|abs(16bit fpos)
-		
+
 		"  addl %%ebx, %%eax\n"
 
 		eax=(runlength<<16)|abs(16bit fpos) + abs(ch->step)
@@ -2241,7 +2238,7 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 		edx=(runlength&0xffff0000)>>16 carry from eax
 
 		"  subl $1, %%eax\n"
-		
+
 		eax--
 
 		"  sbbl $0, %%edx\n"
@@ -2254,7 +2251,7 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 		/* check that we are not going to throw exception.. this is FUCKING clever */
 		if (abs(step) <= (runlength&0xffff0000)>>16 + carry from eax - carry from eax )
 			goto mixPlayChannel_playecx
-	
+
 		"  divl %%ebx\n"
 
 		eax=(edx:eax)/ebx
@@ -2267,7 +2264,7 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 
 		if (ecx<eax) /* ecx is copy of len */
 			goto mixPlayChannel_playecx
-		
+
 		"    movl %%eax, %%ecx\n"
 		"    cmpl $0, inloop\n"
 		"    jnz mixPlayChannel_playecx\n"
@@ -2313,15 +2310,15 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 		edx=ignored
 		esi=ignored
 		edi=ch
-		
+
 		"  movl %%ecx, %%eax\n"
-		
+
 		eax=samplecount(dst)
-		
+
 		"  shll $2, %%eax\n"
 
 		eax=samplecount(dst)*sizeof(uint32_t)
-		
+
 		"  cmpl $0, %1\n"                 /*  %1 = stereo */
 		"  je mixPlayChannel_m2\n"
 		"  shll $1, %%eax\n"
@@ -2329,11 +2326,11 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 
 		if (stereo)
 			eax*=2;
-		
+
 		"  addl %%eax, %3\n"              /*  %3 = buf */
 
 		buf+=eax
-			
+
 		"  subl %%ecx, %2\n"              /*  %2 = len */
 
 		len-=len;
@@ -2341,40 +2338,40 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 		"  movl %11(%%edi), %%eax\n"      /* %11 = ch->step */
 
 		eax=ch->step
-			
+
 		"  imul %%ecx\n"
 
 		edx:eax=ch->step*samplecount /* This should not go above 0x0000:ffff:ffff:ffff */
-	
+
 		"  shld $16, %%eax, %%edx\n"
 
 		edx=n of edx:eax
-	
+
 		"  addw %%ax, %10(%%edi)\n"       /* %10 = ch->->fpos */
 
 		ch->fpos+=ax (fp of edx:eax)
-		
+
 		"  adcl %%edx, %9(%%edi)\n"       /*  %9 = ch->pos */
 
 		edi->pos+=edx (n of edx_eax)+carry from above
-		
+
 		"  movl %9(%%edi), %%eax\n"       /*  %9 = ch->pos */
 
 		eax=ch->pos
 
 		"  cmpl $0, inloop\n"
 		"  jz pcexit\n"
-	
+
 		if (!inloop)
 			goto pcexit
 
 
 		"  cmpl $0, %11(%%edi)\n"         /* %11 = ch->step */
 		"  jge mixPlayChannel_forward2\n"
-		
+
 		if (ch->step>=0)
-			goto mixPlayChannel_forward2;	
-		
+			goto mixPlayChannel_forward2;
+
 		"    cmpl %7(%%edi), %%eax\n"     /*  %7 = ch->loopstart */
 		"    jge pcexit\n"
 
@@ -2389,11 +2386,11 @@ void mixPlayChannel(int32_t *dst, uint32_t len, struct mixchannel *ch, int stere
 			goto mixPlayChannel_pong;
 
 		"      addl %6(%%edi), %%eax\n"   /*  %6 = ch->replen */
-		
+
 		eax+=ch->replen
 		=>
-		eax=ch->pos+ch->replen;		
-		
+		eax=ch->pos+ch->replen;
+
 		"      jmp mixPlayChannel_loopiflen\n"
 		goto mixPlayChannel_loopiflen
 
@@ -2404,70 +2401,70 @@ mixPlayChannel_pong:
 		"      negl %11(%%edi)\n"         /* %11 = ch->step */
 
 		ch->step=-ch->step
-		
+
 		"      negw %10(%%edi)\n"         /* %10 = ch->->fpos */
 
 		ch->fpos=-ch->fpos
 
 		"      adcl $0, %%eax\n"
-		
+
 		if (ch->fpos)
-			eax++;		
-		
+			eax++;
+
 		"      negl %%eax\n"
-		
-		eax=-eax;		
-		
+
+		eax=-eax;
+
 		"      addl %7(%%edi), %%eax\n"   /*  %7 = ch->->loopstart */
 		"      addl %7(%%edi), %%eax\n"   /*  %7 = ch->->loopstart */
-		
-		
+
+
 		ch->loopstart+=eax
-		ch->loopstart+=eax		
-		
+		ch->loopstart+=eax
+
 		"      jmp mixPlayChannel_loopiflen\n"
-		
+
 		goto mixPlayChannel_loopiflen
-		
+
 		"mixPlayChannel_forward2:\n"
-		
+
 mixPlayChannel_forward2:
-	
-		eax=ch->pos	
-		
+
+		eax=ch->pos
+
 		"    cmpl %5(%%edi), %%eax\n"     /*  %5 = ch->->loopend */
 		"    jb pcexit\n"
-		
+
 		if (eax<ch->loopend)
 				goto pcexit;
-		
+
 		"    testb $MIX_PINGPONGLOOP, %8(%%edi)\n"
 		                                  /*  %8 = ch->status */
 		"    jnz mixPlayChannel_ping\n"
 
 		if (ch->status&MIX_PINGPONGLOOP)
 				goto mixPlayChannel_ping;
-		
+
 		"      sub %6(%%edi), %%eax\n"    /*  %6 = ch->replen */
-		
+
 		eax=ch->pos
 		=>
 		eax-=ch->replen
-			
+
 		"      jmp mixPlayChannel_loopiflen\n"
 
 		goto mixPlayChannel_loopiflen
-		
+
 		"mixPlayChannel_ping:\n"
 
 mixPlayChannel_ping:
 
 		"      negl %11(%%edi)\n"         /* %11 = ch->step */
-		
+
 		ch->step=-ch->step
 		"      negw %10(%%edi)\n"         /* %10 = ch->->fpos */
 		"      adcl $0, %%eax\n"
-		
+
 		eax=ch->pos
 		=>
 		if (ch->fpos=-ch->fpos)
@@ -2476,7 +2473,7 @@ mixPlayChannel_ping:
 		"      negl %%eax\n"
 
 		eax=-eax;
-			
+
 		"      addl %5(%%edi), %%eax\n"   /*  %5 = ch->->loopend */
 		"      addl %5(%%edi), %%eax\n"   /*  %5 = ch->->loopend */
 
@@ -2486,17 +2483,17 @@ mixPlayChannel_ping:
 		"mixPlayChannel_loopiflen:\n"
 
 mixPlayChannel_loopiflen:
-		
+
 		"  movl %%eax, %9(%%edi)\n"       /*  %9 = ch->pos */
-		
+
 		ch->pos=eax
-		
+
 		"  cmpl $0, %2\n"                 /*  %2 = len */
 		"  jne mixPlayChannel_bigloop\n"
 
 		if (len)
 			mixPlayChannel_bigloop
-		
+
 		"pcexit:\n"
 
 pcexit:
