@@ -84,6 +84,8 @@ static volatile int busy=0;
 uint32_t customfileref=0xffffffff;
 uint32_t custommixerref=0xffffffff;
 
+static int alsa_1_0_11_or_better;
+
 static int mlDrawBox(void)
 {
 	int mlTop=plScrHeight/2-2;
@@ -113,7 +115,7 @@ static int mlDrawBox(void)
 static int getbufpos(void)
 {
 	int retval;
-	
+
 	if (busy++)
 	{
 		/* can't escape if already set, and shouldn't happen */
@@ -128,7 +130,8 @@ static int getbufpos(void)
 			return retval;
 		}
 	}
-/*	if ((!cachelen)&&(!kernlen))
+/*
+	if ((!cachelen)&&(!kernlen))
 		retval=(kernpos+buflen-(0<<(bit16+stereo)))%buflen;
 	else*/
 		retval=(kernpos+buflen-(1<<(bit16+stereo)))%buflen;
@@ -143,9 +146,9 @@ static int getplaypos(void)
 	if (busy++)
 	{
 	} else {
-		snd_pcm_sframes_t tmp;	
+		snd_pcm_sframes_t tmp;
 		int err;
-		
+
 #ifdef ALSA_DEBUG
 		fprintf(stderr, "ALSA snd_pcm_status(alsa_pcm, alsa_pcm_status) = ");
 #endif
@@ -165,7 +168,7 @@ static int getplaypos(void)
 			fprintf(stderr, "%ld\n", tmp);
 #endif
 			tmp<<=(bit16+stereo);
-	
+
 			if (tmp<0) /* we ignore buffer-underruns */
 				tmp=0;
 			else if (tmp==0)
@@ -175,7 +178,7 @@ static int getplaypos(void)
 				if (tmp<0)
 					tmp=0;
 			}
-		
+
 			if (tmp>kernlen)
 			{
 			} else {
@@ -197,9 +200,9 @@ static void flush(void)
 	if (busy++)
 	{
 		busy--;
-		return;		
+		return;
 	}
-		
+
 #ifdef ALSA_DEBUG
 	fprintf(stderr, "ALSA snd_pcm_status(alsa_pcm, alsa_pcm_status) = ");
 #endif
@@ -220,7 +223,7 @@ static void flush(void)
 #ifdef ALSA_DEBUG
 	fprintf(stderr, "%i\n", odelay);
 #endif
-	odelay<<=(bit16+stereo);	
+	odelay<<=(bit16+stereo);
 	if (odelay<0) /* we ignore buffer-underruns */
 		odelay=0;
 	else if (odelay==0)
@@ -239,13 +242,13 @@ static void flush(void)
 		kernlen=odelay;
 		kernpos=(cachepos-kernlen+buflen)%buflen;
 	}
-	
+
 	if (!cachelen)
 	{
 		busy--;
 		return;
 	}
-	
+
 	if (bufpos<=cachepos)
 		n=buflen-cachepos;
 	else
@@ -255,7 +258,7 @@ static void flush(void)
 	if (n>info.bytes)
 		n=info.bytes;
 	*/
-	
+
 	if (n<=0)
 	{
 		busy--;
@@ -359,7 +362,7 @@ static uint32_t gettimer(void)
 			}
 		}
 	}
-	
+
 	tmp-=odelay;
 	busy--;
 	return imuldiv(tmp, 65536>>(stereo+bit16), plrRate);
@@ -465,7 +468,7 @@ static FILE *alsaSelectMixer(struct modlistentry *entry)
 				break;
 			case _KEY_ENTER:
 				strcpy(alsaMixerName, str);
-				setcurshape(0);	
+				setcurshape(0);
 				goto out;
 			}
 			while ((curpos-scrolled)>=(plScrWidth-10))
@@ -593,7 +596,7 @@ static FILE *alsaSelectPcmOut(struct modlistentry *entry)
 				break;
 			case _KEY_ENTER:
 				strcpy(alsaCardName, str);
-				setcurshape(0);	
+				setcurshape(0);
 				goto out;
 			}
 			while ((curpos-scrolled)>=(plScrWidth-10))
@@ -608,7 +611,10 @@ static FILE *alsaSelectPcmOut(struct modlistentry *entry)
 		if (!(t=strchr(entry->name, ',')))
 			return NULL;
 		device=atoi(t+1);
-		snprintf(alsaCardName, sizeof(alsaCardName), "plughw:%d,%d", card, device);
+		if (alsa_1_0_11_or_better)
+			snprintf(alsaCardName, sizeof(alsaCardName), "hw:%d,%d", card, device);
+		else
+			snprintf(alsaCardName, sizeof(alsaCardName), "plughw:%d,%d", card, device);
 		snprintf(alsaMixerName, sizeof(alsaMixerName), "hw:%d", card);
 	}
 out:
@@ -636,7 +642,7 @@ static int list_devices_for_card(int card, struct modlist *ml, const struct dmDr
 	int pcm_device=-1;
 	int cards=0;
 	snd_ctl_t *ctl;
-	
+
 	snprintf(dev, sizeof(dev), "hw:%i", card);
 #ifdef ALSA_DEBUG
 	fprintf(stderr, "ALSA snd_ctl_open(&ctl, \"%s\", 0) = ", dev);
@@ -707,7 +713,7 @@ static int list_devices_for_card(int card, struct modlist *ml, const struct dmDr
 			continue;
 		}
 
-#ifdef ALSA_DEBUG	
+#ifdef ALSA_DEBUG
 		fprintf(stderr, "ALSA: hw:%d,%d: name %s\n", card, pcm_device, snd_pcm_info_get_name(pcm_info));
 #endif
 		if (ml)
@@ -883,7 +889,7 @@ static int list_cards(struct modlist *ml, const struct dmDrive *drive, uint32_t
 			cards+=list_devices_for_card(card, ml, drive, parent, mask, opt);
 #ifdef ALSA_DEBUG
 		fprintf(stderr, "ALSA snd_card_next(&card (%i)) = ", card);
-#endif	
+#endif
                 if ((result=snd_card_next(&card)))
                 {
 #ifdef ALSA_DEBUG
@@ -895,7 +901,7 @@ static int list_cards(struct modlist *ml, const struct dmDrive *drive, uint32_t
 		fprintf(stderr, "ok\n");
 #endif
 	}
-	return cards;		
+	return cards;
 }
 
 /* plr API start */
@@ -972,7 +978,7 @@ static void SetOptions(unsigned int rate, int opt)
 			{
 				opt&=~(PLR_16BIT|PLR_SIGNEDOUT);
 				opt|=PLR_16BIT;
-			} else 
+			} else
 			{
 #ifdef ALSA_DEBUG
 			fprintf(stderr, "failed: %s\n", snd_strerror(-err));
@@ -982,7 +988,7 @@ static void SetOptions(unsigned int rate, int opt)
 				{
 					opt&=~(PLR_16BIT|PLR_SIGNEDOUT);
 					opt|=PLR_SIGNEDOUT;
-				} else 
+				} else
 				{
 #ifdef ALSA_DEBUG
 				fprintf(stderr, "failed: %s\n", snd_strerror(-err));
@@ -1128,7 +1134,7 @@ static int alsaPlay(void **buf, unsigned int *len)
 {
 	if (!alsa_pcm)
 		return 0;
-	
+
 	if ((*len)<(plrRate&~3))
 		*len=plrRate&~3;
 	if ((*len)>(plrRate*4))
@@ -1380,9 +1386,38 @@ static int volalsaSetVolume(struct ocpvolstruct *v, int n)
 	}
 	return 0;
 }
+
 static int alsaInit(const struct deviceinfo *c)
 {
-/*	memcpy(&currentcard, card, sizeof(struct deviceinfo));*/
+	{
+		const char *version = snd_asoundlib_version ();
+		int major = 0;
+		int minor = 0;
+		int patch = 0;
+
+		major = atoi(version);
+		version = strchr(version, '.');
+		if (version)
+		{
+			version++;
+			minor = atoi(version);
+			version = strchr(version, '.');
+			if (version)
+			{
+				version++;
+				patch = atoi(version);
+			}
+		}
+		if (major > 255)
+			major = 255;
+		if (minor > 255)
+			minor = 255;
+		if (patch > 255)
+			patch = 255;
+		alsa_1_0_11_or_better = ((major << 16) | (minor << 8) | patch) >= 0x01000b;
+	}
+/*
+	memcpy(&currentcard, card, sizeof(struct deviceinfo));*/
 	dmSETUP=RegisterDrive("setup:");
 
 	plrSetOptions=SetOptions;
@@ -1405,7 +1440,8 @@ static int alsaDetect(struct deviceinfo *card)
 	snprintf(alsaCardName, sizeof(alsaCardName), "%s", card->path);
 	snprintf(card->mixer, sizeof(card->mixer), "%s", cfGetProfileString("devpALSA", "mixer", "default"));
 	snprintf(alsaMixerName, sizeof(alsaMixerName), "%s", card->mixer);
-/*	card->irq=-1;
+/*
+	card->irq=-1;
 	card->irq2=-1;
 	card->dma=-1;
 	card->dma2=-1;*/
@@ -1514,39 +1550,41 @@ static void __attribute__((destructor))fini(void)
 	mdbUnregisterReadDir(&readdirAlsa);
 	if (alsa_pcm)
 	{
+
+#ifdef ALSA_DEBUG
 		int err;
-#ifdef ALSA_DEBUG
+
 		fprintf(stderr, "ALSA(fini) snd_pcm_drain(alsa_pcm) = ");
-#endif
 		err=snd_pcm_drain(alsa_pcm);
-#ifdef ALSA_DEBUG
 		if (err)
 			fprintf(stderr, "failed: %s\n", snd_strerror(-err));
 		else
 			fprintf(stderr, "ok\n");
+
 		fprintf(stderr, "ALSA(fini) snd_pcm_close(alsa_pcm) = ");
-#endif
 		err=snd_pcm_close(alsa_pcm);
-#ifdef ALSA_DEBUG
 		if (err)
 			fprintf(stderr, "failed: %s\n", snd_strerror(-err));
 		else
 			fprintf(stderr, "ok\n");
+#else
+		snd_pcm_drain(alsa_pcm);
+		snd_pcm_close(alsa_pcm);
 #endif
 		alsa_pcm=NULL;
 	}
 	if (mixer)
 	{
+#ifdef ALSA_DEBUG
 		int err;
-#ifdef ALSA_DEBUG
 		fprintf(stderr, "ALSA(fini) snd_mixer_close(mixer) = ");
-#endif
 		err=snd_mixer_close(mixer);
-#ifdef ALSA_DEBUG
 		if (err)
 			fprintf(stderr, "failed: %s\n", snd_strerror(-err));
 		else
 			fprintf(stderr, "ok\n");
+#else
+		snd_mixer_close(mixer);
 #endif
 		mixer=NULL;
 	}
