@@ -61,8 +61,8 @@ volatile static uint32_t playpos; /* how many samples have we done totally */
 static const char *OSStatus_to_string(OSStatus status)
 {
 	switch (status)
- 	{
-   		case kAudioHardwareNoError:
+	{
+		case kAudioHardwareNoError:
 			return "kAudioHardwareNoError";
 		case kAudioHardwareNotRunningError:
 			return "kAudioHardwareNotRunningError";
@@ -88,7 +88,7 @@ static const char *OSStatus_to_string(OSStatus status)
 			return "kAudioHardwareBadObjectError";
 		case (OSErr)badComponentInstance:
 			return "badComponentInstance";
-  		case (OSErr)badComponentSelector:
+		case (OSErr)badComponentSelector:
 			return "badComponentSelector";
 		default:
 			return "unknown";
@@ -171,6 +171,8 @@ static OSStatus theRenderProc(void *inRefCon, AudioUnitRenderActionFlags *inActi
 	cachelen -= i;
 	cachepos = kernpos;
 
+	playpos += i<<(2/*stereo+bit16*/);
+
 	if ((i+kernpos)>buflen)
 	{
 		i2 = ( i + kernpos ) % buflen;
@@ -305,7 +307,7 @@ static int CoreAudioPlay(void **buf, unsigned int *len)
 #endif
 	if (status)
 	{
-  		fprintf(stderr, "[CoreAudio] AudioOutputUnitStart returned %d (%s)\n", (int)status, OSStatus_to_string(status));
+		fprintf(stderr, "[CoreAudio] AudioOutputUnitStart returned %d (%s)\n", (int)status, OSStatus_to_string(status));
 		free(*buf);
 		*buf = playbuf = 0;
 		plrGetBufPos = 0;
@@ -413,7 +415,7 @@ static int CoreAudioDetect(struct deviceinfo *card)
 			fprintf(stderr, "[CoreAudio] Unable to retrieve default audio device name length (status = %d (%s))\n", (int)status, OSStatus_to_string(status));
 			break;
 		}
-		
+
 		/* Retrieve the name of the device. */
 		psz_name = malloc(i_param_size);
 		if (!psz_name)
@@ -460,7 +462,7 @@ static int CoreAudioDetect(struct deviceinfo *card)
 #endif
 
 	CoreAudioRate = inDesc.mSampleRate;
-/*	inDesc.mSampleRate = 44100; Use default here */
+	/* inDesc.mSampleRate = 44100; Use default here */
 	inDesc.mFormatID=kAudioFormatLinearPCM;
 	inDesc.mChannelsPerFrame=channels;
 	inDesc.mBitsPerChannel=16;
