@@ -203,7 +203,7 @@ static int dwPlay(void **buf, unsigned int *len)
 			continue;
 		break;
 	}
-			
+
 	buflen=*len;
 	bufpos=0;
 	busy=0;
@@ -254,7 +254,6 @@ rewrite:
 				goto rewrite;
 		}
 	}
-		
 
 	wavlen=lseek(file, 0, SEEK_CUR)-0x2C;
 
@@ -311,10 +310,12 @@ static int dwDetect(struct deviceinfo *card)
 	card->devtype=&plrDiskWriter;
 	card->port=-1;
 	card->port2=-1;
-/*	card->irq=-1;
+/*
+	card->irq=-1;
 	card->irq2=-1;
 	card->dma=-1;
-	card->dma2=-1;*/
+	card->dma2=-1;
+*/
 	card->subtype=-1;
 	card->mem=0;
 	card->chan=2;
