@@ -54,6 +54,12 @@
 #include "dwmixa.h"
 #include "dwmixqa.h"
 
+#if defined(__PIC__) && defined(I386_ASM)
+#warning I386_ASM is disabled in non FPU mixers when compiled PIC
+#undef I386_ASM
+#endif
+
+
 #ifdef I386_ASM
 #include "stuff/pagesize.inc.c"
 #endif
@@ -221,7 +227,7 @@ static void calcamptab(signed long amp)
 
 static void calcstep(struct channel *c)
 	/* Used by calcsteps
-	 * 	   SET
+	 *         SET
 	 */
 {
 	if (!(c->status&MIXRQ_PLAYING))
@@ -725,13 +731,13 @@ static void SET(int ch, int opt, int val)
 			orgspeed=val;
 			calcspeed();
 			break;
-		
+
 		case mcpMasterVolume:
 			if (val>=0 && val<=64)
 				mastervol=(val<0)?0:(val>63)?63:val;
 			calcvols();
 			break;
-		
+
 		case mcpMasterPanning:
 #ifndef __STRANGE_BUG__
 			if (val>=-64 && val<=64)
@@ -788,7 +794,7 @@ static int GET(int ch, int opt)
 	if (ch>=channelnum)
 		ch=channelnum-1;
 	if (ch<0)
-		ch=0;	
+		ch=0;
 	chn=&channels[ch];
 	switch (opt)
 	{
@@ -860,7 +866,7 @@ static int LoadSamples(struct sampleinfo *sil, int n)
 
 	samples=malloc(sizeof(*sil)*n);
 	memcpy(samples, sil, sizeof(*sil)*n);
-	
+
 	for (i=0;i<n;i++)
 	{
 		samples[i].ptr=malloc(samples[i].length+pagesize()*10);
@@ -918,7 +924,7 @@ static int OpenPlayer(int chan, void (*proc)())
 		interpoltabr=0;
 		if (!(scalebuf=malloc(sizeof(int16_t)*MIXBUFLEN))) /* new short [MIXBUFLEN];*/
 			return 0;
-		
+
 		if (!(voltabsq=malloc(sizeof(uint16_t)*513*2*256))) /*new short [513][2][256];*/
 		{
 			free(scalebuf);
@@ -1060,7 +1066,7 @@ static void ClosePlayer()
 		if (mode->Close)
 			mode->Close();
 
-    	if (voltabsr) free(voltabsr);
+	if (voltabsr) free(voltabsr);
 	if (interpoltabr) free(interpoltabr);
 	if (scalebuf) free(scalebuf);
 	if (voltabsq) free(voltabsq);
@@ -1139,7 +1145,7 @@ static int wmixInit(const struct deviceinfo *dev)
 		if (write(fd, start2, len2)!=len2)
 		{
 #ifdef MIXER_DEBUG
-	 		fprintf(stderr, "write 2 failed\n");
+			fprintf(stderr, "write 2 failed\n");
 #endif
 			return 0;
 		}
@@ -1155,12 +1161,13 @@ static int wmixInit(const struct deviceinfo *dev)
 			perror("mmap()");
 			return 0;
 		}
-		
-/*	if (mprotect((char *)(((int)remap_range1_start)&~(pagesize()-1)), (((char *)remap_range1_stop-(char *)remap_range1_start)+pagesize()-1)& ~(pagesize()-1), PROT_READ|PROT_WRITE|PROT_EXEC) ||
-	    mprotect((char *)(((int)remap_range2_start)&~(pagesize()-1)), (((char *)remap_range2_stop-(char *)remap_range2_start)+pagesize()-1)& ~(pagesize()-1), PROT_READ|PROT_WRITE|PROT_EXEC) )
+
+/*
+		if (mprotect((char *)(((int)remap_range1_start)&~(pagesize()-1)), (((char *)remap_range1_stop-(char *)remap_range1_start)+pagesize()-1)& ~(pagesize()-1), PROT_READ|PROT_WRITE|PROT_EXEC) ||
+		    mprotect((char *)(((int)remap_range2_start)&~(pagesize()-1)), (((char *)remap_range2_stop-(char *)remap_range2_start)+pagesize()-1)& ~(pagesize()-1), PROT_READ|PROT_WRITE|PROT_EXEC) )
 	    {
-			perror("Couldn't mprotect"); 
- 			return 0;
+			perror("Couldn't mprotect");
+			return 0;
 		}*/
 #ifdef MIXER_DEBUG
 		fprintf(stderr, "Done ?\n");
@@ -1185,10 +1192,12 @@ static int wmixDetect(struct deviceinfo *c)
 	c->devtype=&mcpMixer;
 	c->port=-1;
 	c->port2=-1;
-/*	c->irq=-1;
+/*
+	c->irq=-1;
 	c->irq2=-1;
 	c->dma=-1;
-	c->dma2=-1;*/
+	c->dma2=-1;
+*/
 	if (c->subtype==-1)
 		c->subtype=0;
 	c->chan=/*(MAXCHAN>99)?99:MAXCHAN;*/MAXCHAN;
@@ -1226,7 +1235,7 @@ static void mixrInit(const char *sec)
 	fprintf(stderr, "[devwmix] INIT, ");
 	if (!quality)
 	{
-#ifdef I386_ASM 
+#ifdef I386_ASM
 		fprintf(stderr, "using dwmixa.c x86-asm version\n");
 #else
 #ifdef I386_ASM_EMU
@@ -1236,7 +1245,7 @@ static void mixrInit(const char *sec)
 #endif
 #endif
 	} else {
-#ifdef I386_ASM 
+#ifdef I386_ASM
 		fprintf(stderr, "using dwmixaq.c x86-asm version\n");
 #else
 		fprintf(stderr, "using dwmixaq.c C version\n");
