@@ -3,7 +3,7 @@
 
 struct mixqpostprocregstruct
 {
-	void (*Process)(long *buffer, int len, int rate, int stereo);
+	void (*Process)(int32_t *buffer, int len, int rate, int stereo);
 	void (*Init)(int rate, int stereo);
 	void (*Close)(void );
 	struct mixqpostprocregstruct *next;
