@@ -179,10 +179,10 @@ static void calcinterpoltab(void)
 		float x1=i/256.0;
 		float x2=x1*x1;
 		float x3=x1*x1*x1;
-		ct0[i]=-0.5*x3+x2-0.5*x1;
-		ct1[i]=1.5*x3-2.5*x2+1;
-		ct2[i]=-1.5*x3+2*x2+0.5*x1;
-		ct3[i]=0.5*x3-0.5*x2;
+		dwmixfa_state.ct0[i]=-0.5*x3+x2-0.5*x1;
+		dwmixfa_state.ct1[i]=1.5*x3-2.5*x2+1;
+		dwmixfa_state.ct2[i]=-1.5*x3+2*x2+0.5*x1;
+		dwmixfa_state.ct3[i]=0.5*x3-0.5*x2;
 	};
 }
 
@@ -191,17 +191,17 @@ static void calcstep(struct channel *c)
 {
 	int n=c->handle;
 	uint32_t rstep;
-	if (!(voiceflags[n]&MIXF_PLAYING))
+	if (!(dwmixfa_state.voiceflags[n]&MIXF_PLAYING))
 		return;
 	if (!c->orgdiv)
 		return;
 
-	rstep=imuldiv(imuldiv(c->orgfrq, c->orgrate, c->orgdiv)<<8, relpitch, samprate);
-	freqw[n]=rstep>>16;
-	freqf[n]=rstep<<16;
+	rstep=imuldiv(imuldiv(c->orgfrq, c->orgrate, c->orgdiv)<<8, relpitch, dwmixfa_state.samprate);
+	dwmixfa_state.freqw[n]=rstep>>16;
+	dwmixfa_state.freqf[n]=rstep<<16;
 
-	voiceflags[n]&=~(MIXF_INTERPOLATE|MIXF_INTERPOLATEQ);
-	voiceflags[n]|=interpolation?((interpolation>1)?MIXF_INTERPOLATEQ:MIXF_INTERPOLATE):0;
+	dwmixfa_state.voiceflags[n]&=~(MIXF_INTERPOLATE|MIXF_INTERPOLATEQ);
+	dwmixfa_state.voiceflags[n]|=interpolation?((interpolation>1)?MIXF_INTERPOLATEQ:MIXF_INTERPOLATE):0;
 }
 
 static void calcsteps(void)
@@ -214,7 +214,7 @@ static void calcsteps(void)
 static void calcspeed(void)
 {
 	if (channelnum)
-		newtickwidth=imuldiv(256*256*256, samprate, orgspeed*relspeed);
+		newtickwidth=imuldiv(256*256*256, dwmixfa_state.samprate, orgspeed*relspeed);
 }
 
 static void transformvol(struct channel *ch)
@@ -226,7 +226,7 @@ static void transformvol(struct channel *ch)
 	if (volopt^ch->volopt)
 		ch->vol[1]=-ch->vol[1];
 
-	if (voiceflags[n]&MIXF_MUTE)
+	if (dwmixfa_state.voiceflags[n]&MIXF_MUTE)
 	{
 		ch->dstvols[0]=ch->dstvols[1]=0;
 	} else if (!stereo)
@@ -244,7 +244,7 @@ static void transformvol(struct channel *ch)
 }
 
 static void calcvol(struct channel *chn)
-{                                    
+{
 	chn->orgvol[0]=chn->orgvolx*(0.5-chn->orgpan);
 	chn->orgvol[1]=chn->orgvolx*(0.5+chn->orgpan);
 	transformvol(chn);
@@ -256,7 +256,7 @@ static void calcvols(void)
 
 	float realamp=(1.0/65536.0)*amplify;
 	int i;
-	
+
 	vols[0][0]=vols[1][1]=mastervol*(0.5+masterpan);
 	vols[0][1]=vols[1][0]=mastervol*(0.5-masterpan);
 
@@ -284,19 +284,19 @@ static void calcvols(void)
 static void stopchan(struct channel *c)
 {
 	int n=c->handle;
-	if (!(voiceflags[n]&MIXF_PLAYING))
+	if (!(dwmixfa_state.voiceflags[n]&MIXF_PLAYING))
 		return;
 
 	/* cool end-of-sample-declicking */
-	if (!(voiceflags[n] & MIXF_QUIET))
+	if (!(dwmixfa_state.voiceflags[n] & MIXF_QUIET))
 	{
-		int offs=(voiceflags[n]&MIXF_INTERPOLATEQ)?1:0;
-		float ff2=ffreq[n]*ffreq[n];
-		fadeleft+=ff2*volleft[n]*smpposw[n][offs];
-		faderight+=ff2*volright[n]*smpposw[n][offs];
+		int offs = ( dwmixfa_state.voiceflags[n] & MIXF_INTERPOLATEQ ) ? 1 : 0;
+		float ff2 = dwmixfa_state.ffreq[n] * dwmixfa_state.ffreq[n];
+		dwmixfa_state.fadeleft += ff2*dwmixfa_state.volleft[n] * dwmixfa_state.smpposw[n][offs];
+		dwmixfa_state.faderight += ff2*dwmixfa_state.volright[n] * dwmixfa_state.smpposw[n][offs];
 	}
 
-	voiceflags[n]&=~MIXF_PLAYING;
+	dwmixfa_state.voiceflags[n]&=~MIXF_PLAYING;
 }
 
 
@@ -304,7 +304,7 @@ static void rstlbuf(struct channel *c)
 {
 	if (c->sbpos)
 	{
-	       	int i;
+		int i;
 		for (i=0; i<8; i++)
 			c->sbpos[i]=c->sbuf[i];
 		c->sbpos=0;
@@ -319,10 +319,10 @@ static void setlbuf(struct channel *c)
 	if (c->sbpos)
 		rstlbuf(c);
 
-	if (voiceflags[n]&MIXF_LOOPED)
+	if (dwmixfa_state.voiceflags[n]&MIXF_LOOPED)
 	{
-		float *dst=loopend[n];
-		float *src=dst-looplen[n];
+		float *dst=dwmixfa_state.loopend[n];
+		float *src=dst-dwmixfa_state.looplen[n];
 		int i;
 		for (i=0; i<8; i++)
 		{
@@ -350,12 +350,14 @@ static void mixmain(/*int min*/)
 	}
 
 
-/*	bufmin=imulshr16(min, samprate);
+/*
+	bufmin=imulshr16(min, samprate);
 	if (bufmin<0)
 		bufmin=0;*/
 
 	bufdeltatot=((buflen+(plrGetBufPos()>>(stereo+bit16))-bufpos)%buflen);
-/*	if (bufdeltatot<bufmin)
+/*
+	if (bufdeltatot<bufmin)
 		bufdeltatot=0;*/
 
 	if (dopause)
@@ -383,7 +385,7 @@ static void mixmain(/*int min*/)
 	{
 		unsigned int bufdelta=(bufdeltatot>MIXF_MIXBUFLEN)?MIXF_MIXBUFLEN:bufdeltatot;
 		uint32_t ticks2go;
-		float invt2g;
+		/* float invt2g; */
 		if (bufdelta>(buflen-bufpos))
 			bufdelta=buflen-bufpos;
 
@@ -392,48 +394,48 @@ static void mixmain(/*int min*/)
 		if (bufdelta>ticks2go)
 			bufdelta=ticks2go;
 
-		invt2g=1.0/(float)ticks2go;
+		/* invt2g=1.0/(float)ticks2go; */
 
 		/* set-up mixing core variables */
-		for (i=0; i<channelnum; i++) if (voiceflags[i]&MIXF_PLAYING)
+		for (i=0; i<channelnum; i++) if (dwmixfa_state.voiceflags[i]&MIXF_PLAYING)
 		{
 			struct channel *ch=&channels[i];
 
-			volleft[i]=frchk(volleft[i]);
-			volright[i]=frchk(volright[i]);
+			dwmixfa_state.volleft[i]=frchk(dwmixfa_state.volleft[i]);
+			dwmixfa_state.volright[i]=frchk(dwmixfa_state.volright[i]);
 
-			if (!volleft[i] && !volright[i] && !rampleft[i] && !rampright[i])
-				voiceflags[i]|=MIXF_QUIET;
+			if (!dwmixfa_state.volleft[i] && !dwmixfa_state.volright[i] && !dwmixfa_state.rampleft[i] && !dwmixfa_state.rampright[i])
+				dwmixfa_state.voiceflags[i]|=MIXF_QUIET;
 			else
-				voiceflags[i]&=~MIXF_QUIET;
+				dwmixfa_state.voiceflags[i]&=~MIXF_QUIET;
 
 
-			if (ffreq[i]!=1 || freso[i]!=0)
-				voiceflags[i]|=MIXF_FILTER;
+			if (dwmixfa_state.ffreq[i]!=1 || dwmixfa_state.freso[i]!=0)
+				dwmixfa_state.voiceflags[i]|=MIXF_FILTER;
 			else
-				voiceflags[i]&=~MIXF_FILTER;
+				dwmixfa_state.voiceflags[i]&=~MIXF_FILTER;
 
 			/* declick start of sample */
 			if (ch->newsamp)
 			{
-				if (!(voiceflags[i] & MIXF_QUIET))
+				if (!(dwmixfa_state.voiceflags[i] & MIXF_QUIET))
 				{
-					int offs=(voiceflags[i]&MIXF_INTERPOLATEQ)?1:0;
-					float ff2=ffreq[i]*ffreq[i];
-					fadeleft-=ff2*volleft[i]*smpposw[i][offs];
-					faderight-=ff2*volright[i]*smpposw[i][offs];
+					int offs = ( dwmixfa_state.voiceflags[i] & MIXF_INTERPOLATEQ ) ? 1 : 0;
+					float ff2 = dwmixfa_state.ffreq[i] * dwmixfa_state.ffreq[i];
+					dwmixfa_state.fadeleft -= ff2 * dwmixfa_state.volleft[i] * dwmixfa_state.smpposw[i][offs];
+					dwmixfa_state.faderight -= ff2 * dwmixfa_state.volright[i] * dwmixfa_state.smpposw[i][offs];
 				}
 				ch->newsamp=0;
 			}
 
 			/*voiceflags[i]|=isstereo; <- this was hard to track down*/
 		}
-		nsamples=bufdelta;
-		outbuf=((uint8_t *)(plrbuf))+(bufpos<<(stereo+bit16));
+		dwmixfa_state.nsamples=bufdelta;
+		dwmixfa_state.outbuf=((uint8_t *)(plrbuf))+(bufpos<<(stereo+bit16));
 
 		/* optionally turn off the declicking */
 		if (!declick)
-			fadeleft=faderight=0;
+			dwmixfa_state.fadeleft=dwmixfa_state.faderight=0;
 #ifdef MIXER_DEBUG
 		{
 			int i;
@@ -458,7 +460,7 @@ static void mixmain(/*int min*/)
 		{
 			float invt2g;
 			tickplayed-=tickwidth;
-			
+
 			playerproc();
 
 			cmdtimerpos+=tickwidth;
@@ -466,27 +468,27 @@ static void mixmain(/*int min*/)
 			invt2g=256.0/tickwidth;
 
 			/* set up volume ramping */
-			for (i=0; i<channelnum; i++) if (voiceflags[i]&MIXF_PLAYING)
+			for (i=0; i<channelnum; i++) if (dwmixfa_state.voiceflags[i]&MIXF_PLAYING)
 			{
 
 				struct channel *ch=&channels[i];
 				if (ch->dontramp)
 				{
-					volleft[i]=frchk(ch->dstvols[0]);
-					volright[i]=frchk(ch->dstvols[1]);
-					rampleft[i]=rampright[i]=0;
+					dwmixfa_state.volleft[i]=frchk(ch->dstvols[0]);
+					dwmixfa_state.volright[i]=frchk(ch->dstvols[1]);
+					dwmixfa_state.rampleft[i]=dwmixfa_state.rampright[i]=0;
 					if (volramp)
 						ch->dontramp=0;
 				} else {
-					rampleft[i]=frchk(invt2g*(ch->dstvols[0]-volleft[i]));
-					if (rampleft[i]==0)
-						volleft[i]=ch->dstvols[0];
-					rampright[i]=frchk(invt2g*(ch->dstvols[1]-volright[i]));
-					if (rampright[i]==0)
-						volright[i]=ch->dstvols[1];
+					dwmixfa_state.rampleft[i]=frchk(invt2g*(ch->dstvols[0]-dwmixfa_state.volleft[i]));
+					if (dwmixfa_state.rampleft[i]==0)
+						dwmixfa_state.volleft[i]=ch->dstvols[0];
+					dwmixfa_state.rampright[i]=frchk(invt2g*(ch->dstvols[1]-dwmixfa_state.volright[i]));
+					if (dwmixfa_state.rampright[i]==0)
+						dwmixfa_state.volright[i]=ch->dstvols[1];
 				}
 				/* filter resonance */
-				freso[i]=pow(ch->orgfrez,ffreq[i]);
+				dwmixfa_state.freso[i]=pow(ch->orgfrez,dwmixfa_state.ffreq[i]);
 			}
 		}
 		bufpos+=bufdelta;
@@ -525,13 +527,13 @@ static void SET(int ch, int opt, int val)
 				int reswasmute;
 				rstlbuf(chn);
 				stopchan(chn);
-				reswasmute=voiceflags[ch]&MIXF_MUTE;
+				reswasmute=dwmixfa_state.voiceflags[ch]&MIXF_MUTE;
 				memset(chn, 0, sizeof(struct channel));
 				chn->handle=ch;
-				voiceflags[ch]=reswasmute;
+				dwmixfa_state.voiceflags[ch]=reswasmute;
 			}
 			break;
-				
+
 		case mcpCInstrument:
 			{
 				struct sampleinfo *samp;
@@ -552,36 +554,36 @@ static void SET(int ch, int opt, int val)
 				chn->dontramp=1;
 				chn->newsamp=1;
 
-				voiceflags[ch]&=~(MIXF_PLAYING|MIXF_LOOPED);
+				dwmixfa_state.voiceflags[ch]&=~(MIXF_PLAYING|MIXF_LOOPED);
 
-				freqw[ch]=0;
-				freqf[ch]=0;
-				fl1[ch]=0;
-				fb1[ch]=0;
-				ffreq[ch]=1;
-				freso[ch]=0;
-				smpposf[ch]=0;
-				smpposw[ch]=(float *)chn->samp;
+				dwmixfa_state.freqw[ch]=0;
+				dwmixfa_state.freqf[ch]=0;
+				dwmixfa_state.fl1[ch]=0;
+				dwmixfa_state.fb1[ch]=0;
+				dwmixfa_state.ffreq[ch]=1;
+				dwmixfa_state.freso[ch]=0;
+				dwmixfa_state.smpposf[ch]=0;
+				dwmixfa_state.smpposw[ch]=(float *)chn->samp;
 
 				if (chn->samptype&mcpSampSLoop)
 				{
-					voiceflags[ch]|=MIXF_LOOPED;
+					dwmixfa_state.voiceflags[ch]|=MIXF_LOOPED;
 					chn->loopstart=chn->orgsloopstart;
 					chn->loopend=chn->orgsloopend;
 				} else if (chn->samptype&mcpSampLoop)
 				{
-					voiceflags[ch]|=MIXF_LOOPED;
+					dwmixfa_state.voiceflags[ch]|=MIXF_LOOPED;
 					chn->loopstart=chn->orgloopstart;
 					chn->loopend=chn->orgloopend;
 				}
-				
-				if (voiceflags[ch]&MIXF_LOOPED)
+
+				if (dwmixfa_state.voiceflags[ch]&MIXF_LOOPED)
 				{
-					looplen[ch]=chn->loopend-chn->loopstart;
-					loopend[ch]=(float *)chn->samp+chn->loopend;
+					dwmixfa_state.looplen[ch]=chn->loopend-chn->loopstart;
+					dwmixfa_state.loopend[ch]=(float *)chn->samp+chn->loopend;
 				} else {
-					looplen[ch]=chn->length;
-					loopend[ch]=(float *)chn->samp+chn->length-1;
+					dwmixfa_state.looplen[ch]=chn->length;
+					dwmixfa_state.loopend[ch]=(float *)chn->samp+chn->length-1;
 				}
 				setlbuf(chn);
 			}
@@ -590,17 +592,17 @@ static void SET(int ch, int opt, int val)
 			if (!val)
 				stopchan(chn);
 			else {
-				if (smpposw[ch] >= (float *)(chn->samp)+chn->length)
+				if (dwmixfa_state.smpposw[ch] >= (float *)(chn->samp)+chn->length)
 					break;
-				voiceflags[ch]|=MIXF_PLAYING;
+				dwmixfa_state.voiceflags[ch]|=MIXF_PLAYING;
 				calcstep(chn);
 			}
 			break;
 		case mcpCMute:
 			if (val)
-				voiceflags[ch]|=MIXF_MUTE;
+				dwmixfa_state.voiceflags[ch]|=MIXF_MUTE;
 			else
-				voiceflags[ch]&=~MIXF_MUTE;
+				dwmixfa_state.voiceflags[ch]&=~MIXF_MUTE;
 			calcvol(chn);
 			break;
 		case mcpCVolume:
@@ -619,7 +621,7 @@ static void SET(int ch, int opt, int val)
 			break;
 		case mcpCLoop:
 			rstlbuf(chn);
-			voiceflags[ch]&=~MIXF_LOOPED;
+			dwmixfa_state.voiceflags[ch]&=~MIXF_LOOPED;
 
 			if ((val==1)&&!(chn->samptype&mcpSampSLoop))
 				val=2;
@@ -628,24 +630,24 @@ static void SET(int ch, int opt, int val)
 
 			if (val==1)
 			{
-				voiceflags[ch]|=MIXF_LOOPED;
+				dwmixfa_state.voiceflags[ch]|=MIXF_LOOPED;
 				chn->loopstart=chn->orgsloopstart;
 				chn->loopend=chn->orgsloopend;
 			}
 			if (val==2)
 			{
-				voiceflags[ch]|=MIXF_LOOPED;
+				dwmixfa_state.voiceflags[ch]|=MIXF_LOOPED;
 				chn->loopstart=chn->orgloopstart;
 				chn->loopend=chn->orgloopend;
 			}
 
-			if (voiceflags[ch]&MIXF_LOOPED)
+			if (dwmixfa_state.voiceflags[ch]&MIXF_LOOPED)
 			{
-				looplen[ch]=chn->loopend-chn->loopstart;
-				loopend[ch]=(float *)chn->samp+chn->loopend;
+				dwmixfa_state.looplen[ch]=chn->loopend-chn->loopstart;
+				dwmixfa_state.loopend[ch]=(float *)chn->samp+chn->loopend;
 			} else {
-				looplen[ch]=chn->length;
-				loopend[ch]=(float *)chn->samp+chn->length-1;
+				dwmixfa_state.looplen[ch]=chn->length;
+				dwmixfa_state.loopend[ch]=(float *)chn->samp+chn->length-1;
 			}
 			setlbuf(chn);
 
@@ -653,16 +655,16 @@ static void SET(int ch, int opt, int val)
 		case mcpCPosition:
 			{
 				int poswasplaying;
-				poswasplaying=voiceflags[ch]&MIXF_PLAYING;
+				poswasplaying=dwmixfa_state.voiceflags[ch]&MIXF_PLAYING;
 				stopchan(chn);
 				chn->newsamp=1;
 				if (val<0)
 					val=0;
 				if ((unsigned)val>=chn->length)
 					val=chn->length-1;
-				smpposw[ch]=(float *)(chn->samp)+val;
-				smpposf[ch]=0;
-				voiceflags[ch]|=poswasplaying;
+				dwmixfa_state.smpposw[ch]=(float *)(chn->samp)+val;
+				dwmixfa_state.smpposf[ch]=0;
+				dwmixfa_state.voiceflags[ch]|=poswasplaying;
 			}
 			break;
 		case mcpCPitch:
@@ -690,22 +692,22 @@ static void SET(int ch, int opt, int val)
 			 */
 			if (!(val&128))
 			{
-				ffreq[ch]=1;
-				freso[ch]=0;
+				dwmixfa_state.ffreq[ch]=1;
+				dwmixfa_state.freso[ch]=0;
 				break;
 			}
-			ffreq[ch]=33075.0*pow(2,(val-255)/24.0)/samprate;
-			if (ffreq[ch]<0)
-				ffreq[ch]=0;
-			if (ffreq[ch]>1)
-				ffreq[ch]=1;
+			dwmixfa_state.ffreq[ch]=33075.0*pow(2,(val-255)/24.0)/dwmixfa_state.samprate;
+			if (dwmixfa_state.ffreq[ch]<0)
+				dwmixfa_state.ffreq[ch]=0;
+			if (dwmixfa_state.ffreq[ch]>1)
+				dwmixfa_state.ffreq[ch]=1;
 			break;
 		case mcpCFilterRez:
 			chn->orgfrez=val/300.0;
 			if (chn->orgfrez>1)
 				chn->orgfrez=1;
-			if (chn->orgfrez==0 && ffreq[ch]==0)
-				ffreq[ch]=1;
+			if (chn->orgfrez==0 && dwmixfa_state.ffreq[ch]==0)
+				dwmixfa_state.ffreq[ch]=1;
 			break;
 		case mcpGSpeed:
 			orgspeed=val;
@@ -761,25 +763,27 @@ static void SET(int ch, int opt, int val)
 
 static int GET(int ch, int opt)
 {
-/*	struct channel *chn;*/
+/*
+	struct channel *chn;*/
 	if (ch>=channelnum)
 		ch=channelnum-1;
 	if (ch<0)
 		ch=0;
-/*	chn=&channels[ch];*/   /* No commands currently use the channel itself */
+/*
+	chn=&channels[ch];*/   /* No commands currently use the channel itself */
 	switch (opt)
 	{
 		case mcpCStatus:
-			return !!(voiceflags[ch]&MIXF_PLAYING);
+			return !!(dwmixfa_state.voiceflags[ch]&MIXF_PLAYING);
 		case mcpCMute:
-			return !!(voiceflags[ch]&MIXF_MUTE);
+			return !!(dwmixfa_state.voiceflags[ch]&MIXF_MUTE);
 		case mcpGTimer:
 			if (dopause)
-				return imuldiv(playsamps, 65536, samprate);
+				return imuldiv(playsamps, 65536, dwmixfa_state.samprate);
 			else
-				return plrGetTimer()-imuldiv(pausesamps, 65536, samprate);
+				return plrGetTimer()-imuldiv(pausesamps, 65536, dwmixfa_state.samprate);
 		case mcpGCmdTimer:
-			return umuldiv(cmdtimerpos, 256, samprate);
+			return umuldiv(cmdtimerpos, 256, dwmixfa_state.samprate);
 		case mcpMasterReverb:
 			return masterrvb;
 		case mcpMasterChorus:
@@ -814,19 +818,19 @@ static void GetMixChannel(unsigned int ch, struct mixchannel *chn, uint32_t rate
 	chn->length=c->length;
 	chn->loopstart=c->loopstart;
 	chn->loopend=c->loopend;
-	chn->fpos=smpposf[ch]>>16;
-	chn->pos=smpposw[ch]-(float*)c->samp;
+	chn->fpos=dwmixfa_state.smpposf[ch]>>16;
+	chn->pos=dwmixfa_state.smpposw[ch]-(float*)c->samp;
 	chn->vol.volfs[0]=fabs(c->vol[0]);
 	chn->vol.volfs[1]=fabs(c->vol[1]);
-	chn->step=imuldiv((freqw[ch]<<16)|(freqf[ch]>>16), samprate, (signed)rate); 
+	chn->step=imuldiv((dwmixfa_state.freqw[ch]<<16)|(dwmixfa_state.freqf[ch]>>16), dwmixfa_state.samprate, (signed)rate);
 	chn->status=MIX_PLAYFLOAT;
-	if (voiceflags[ch]&MIXF_MUTE)
+	if (dwmixfa_state.voiceflags[ch]&MIXF_MUTE)
 		chn->status|=MIX_MUTE;
-	if (voiceflags[ch]&MIXF_LOOPED)
+	if (dwmixfa_state.voiceflags[ch]&MIXF_LOOPED)
 		chn->status|=MIX_LOOPED;
-	if (voiceflags[ch]&MIXF_PLAYING)
+	if (dwmixfa_state.voiceflags[ch]&MIXF_PLAYING)
 		chn->status|=MIX_PLAYING;
-	if (voiceflags[ch]&MIXF_INTERPOLATE)
+	if (dwmixfa_state.voiceflags[ch]&MIXF_INTERPOLATE)
 		chn->status|=MIX_INTERPOLATE;
 }
 
@@ -834,12 +838,12 @@ static void GetMixChannel(unsigned int ch, struct mixchannel *chn, uint32_t rate
 static void getrealvol(int ch, int *l, int *r)
 {
 	getchanvol(ch, 256);
-	if (voll<0)
-		voll=-voll;
-	*l=(voll>16319)?255:(voll/64.0);
-	if (volr<0)
-		volr=-volr;
-	*r=(volr>16319)?255:(volr/64.0);
+	if (dwmixfa_state.voll<0)
+		dwmixfa_state.voll=-dwmixfa_state.voll;
+	*l=(dwmixfa_state.voll>16319)?255:(dwmixfa_state.voll/64.0);
+	if (dwmixfa_state.volr<0)
+		dwmixfa_state.volr=-dwmixfa_state.volr;
+	*r=(dwmixfa_state.volr>16319)?255:(dwmixfa_state.volr/64.0);
 }
 
 static int LoadSamples(struct sampleinfo *sil, int n)
@@ -880,7 +884,7 @@ static int OpenPlayer(int chan, void (*proc)(void))
 
 	playerproc=proc;
 
-	if (!(tempbuf=malloc(sizeof(float)*(MIXF_MIXBUFLEN<<1))))
+	if (!(dwmixfa_state.tempbuf=malloc(sizeof(float)*(MIXF_MIXBUFLEN<<1))))
 		return 0;
 	if (!(channels=calloc(sizeof(struct channel), chan)))
 	{
@@ -892,7 +896,7 @@ static int OpenPlayer(int chan, void (*proc)(void))
 	mcpGetRealMasterVolume=plrGetRealMasterVolume;
 
 	if (!mixInit(GetMixChannel, 0, chan, amplify))
-		return 0; 
+		return 0;
 	mcpGetRealVolume=getrealvol;
 
 	calcvols();
@@ -900,7 +904,7 @@ static int OpenPlayer(int chan, void (*proc)(void))
 	for (i=0; i<chan; i++)
 	{
 		channels[i].handle=i;
-		voiceflags[i]=0;
+		dwmixfa_state.voiceflags[i]=0;
 	}
 
 
@@ -914,7 +918,7 @@ static int OpenPlayer(int chan, void (*proc)(void))
 	bit16=(plrOpt&PLR_16BIT)?1:0;
 	signedout=(plrOpt&PLR_SIGNEDOUT)?1:0;
 	reversestereo=!!(plrOpt&PLR_REVERSESTEREO);
-	samprate=plrRate;
+	dwmixfa_state.samprate=plrRate;
 	bufpos=0;
 	dopause=0;
 	orgspeed=12800;
@@ -923,9 +927,9 @@ static int OpenPlayer(int chan, void (*proc)(void))
 	mcpNChan=chan;
 	mcpIdle=Idle;
 
-	isstereo=stereo;
-	outfmt=(bit16<<1)|(!signedout);
-	nvoices=channelnum;
+	dwmixfa_state.isstereo=stereo;
+	dwmixfa_state.outfmt=(bit16<<1)|(!signedout);
+	dwmixfa_state.nvoices=channelnum;
 	prepare_mixer();
 
 	calcspeed();
@@ -945,32 +949,33 @@ static int OpenPlayer(int chan, void (*proc)(void))
 	{
 		struct mixfpostprocregstruct *mode;
 
-		for (mode=postprocs; mode; mode=mode->next)
-			if (mode->Init) mode->Init(samprate, stereo);
+		for (mode=dwmixfa_state.postprocs; mode; mode=mode->next)
+			if (mode->Init) mode->Init(dwmixfa_state.samprate, stereo);
 	}
 	return 1;
 }
 
 static void ClosePlayer()
 {
-	  struct mixfpostprocregstruct *mode;
+	struct mixfpostprocregstruct *mode;
 
-	  mcpNChan=0;
-	  mcpIdle=0;
+	mcpNChan=0;
+	mcpIdle=0;
 
-	  pollClose();
+	pollClose();
 
-	  plrClosePlayer();
+	plrClosePlayer();
 
-	  channelnum=0;
+	channelnum=0;
 
-	  mixClose();
+	mixClose();
 
-	  for (mode=postprocs; mode; mode=mode->next)
-		  if (mode->Close) mode->Close();
+	for (mode=dwmixfa_state.postprocs; mode; mode=mode->next)
+		if (mode->Close) mode->Close();
 
-	  free(channels);
-	  free(tempbuf);
+	free(channels);
+	free(dwmixfa_state.tempbuf);
+	dwmixfa_state.tempbuf = 0;
 }
 
 static int Init(const struct deviceinfo *dev)
@@ -1007,10 +1012,11 @@ static int Init(const struct deviceinfo *dev)
 			return 0;
 		}
 
-/*	if (mprotect((char *)(((int)remap_range1_start)&~(pagesize()-1)), (((char *)remap_range1_stop-(char *)remap_range1_start)+pagesize()-1)& ~(pagesize()-1), PROT_READ|PROT_WRITE|PROT_EXEC) )
+/*
+		if (mprotect((char *)(((int)remap_range1_start)&~(pagesize()-1)), (((char *)remap_range1_stop-(char *)remap_range1_start)+pagesize()-1)& ~(pagesize()-1), PROT_READ|PROT_WRITE|PROT_EXEC) )
 	    {
-			perror("Couldn't mprotect"); 
- 			return 0;
+			perror("Couldn't mprotect");
+			return 0;
 		}*/
 #ifdef MIXER_DEBUG
 		fprintf(stderr, "Done ?\n");
@@ -1035,14 +1041,14 @@ static int Init(const struct deviceinfo *dev)
 	masterpan=0;
 	mastersrnd=0;
 	channelnum=0;
-	
+
 	mcpLoadSamples=LoadSamples;
 	mcpOpenPlayer=OpenPlayer;
 	mcpClosePlayer=ClosePlayer;
 	mcpGet=GET;
 	mcpSet=SET;
 
-      	return 1;
+	return 1;
 }
 
 static void Close()
@@ -1056,10 +1062,12 @@ static int Detect(struct deviceinfo *c)
 	c->devtype=&mcpFMixer;
 	c->port=-1;
 	c->port2=-1;
-/*	c->irq=-1;
+/*
+	c->irq=-1;
 	c->irq2=-1;
 	c->dma=-1;
-	c->dma2=-1;*/
+	c->dma2=-1;
+*/
 	if (c->subtype==-1)
 		c->subtype=0;
 	c->chan=MIXF_MAXCHAN;
@@ -1089,8 +1097,8 @@ static uint32_t mixfGetOpt(const char *sec)
 
 void mixfRegisterPostProc(struct mixfpostprocregstruct *mode)
 {
-	mode->next=postprocs;
-	postprocs=mode;
+	mode->next=dwmixfa_state.postprocs;
+	dwmixfa_state.postprocs=mode;
 }
 
 static void mixfInit(const char *sec)
@@ -1099,7 +1107,7 @@ static void mixfInit(const char *sec)
 	const char *regs;
 
 	fprintf(stderr, "[devwmixf] INIT, ");
-#ifdef I386_ASM 
+#ifdef I386_ASM
 		fprintf(stderr, "using dwmixfa.c x86-asm version\n");
 #else
 #ifdef I386_ASM_EMU
@@ -1110,12 +1118,12 @@ static void mixfInit(const char *sec)
 #endif
 #endif
 
-	postprocs=0;
+	dwmixfa_state.postprocs=0;
 	regs=cfGetProfileString(sec, "postprocs", "");
 
 	while (cfGetSpaceListEntry(regname, &regs, 49))
 	{
-	       	void *reg=_lnkGetSymbol(regname);
+		void *reg=_lnkGetSymbol(regname);
 		if (reg)
 			mixfRegisterPostProc((struct mixfpostprocregstruct*)reg);
 	}
