@@ -329,7 +329,7 @@ static void SET(int ch, int opt, int val)
 			break;
 		case mcpMasterFilter:
 			filter=val;
-			break;	
+			break;
 	}
 }
 
@@ -467,10 +467,12 @@ static int Detect(struct deviceinfo *c)
 	c->devtype=&mcpNone;
 	c->port=-1;
 	c->port2=-1;
-/*	c->irq=-1;
+/*
+	c->irq=-1;
 	c->irq2=-1;
 	c->dma=-1;
-	c->dma2=-1;*/
+	c->dma2=-1;
+*/
 	c->subtype=-1;
 	c->chan=(MAXCHAN>99)?99:MAXCHAN;
 	c->mem=0;
