@@ -102,13 +102,13 @@ char adbInit(void)
 	int old=0;
 	unsigned int i;
 
-      	adbDirty=0;
+	adbDirty=0;
 	adbData=0;
 	adbNum=0;
 	if ((strlen(cfConfigDir)+10)>=PATH_MAX)
 		return 1; /* path is too long */
 	strcpy(path, cfConfigDir);
-      	strcat(path, "CPARCS.DAT");
+	strcat(path, "CPARCS.DAT");
 
 	if ((f=open(path, O_RDONLY))<0)
 		return 1;
@@ -207,7 +207,7 @@ void adbUpdate(void)
 	if ((strlen(cfConfigDir)+10)>=PATH_MAX)
 		return; /* path is too long */
 	strcpy(path, cfConfigDir);
-      	strcat(path, "CPARCS.DAT");
+	strcat(path, "CPARCS.DAT");
 
 	if ((f=open(path, O_WRONLY|O_CREAT, S_IREAD|S_IWRITE))<0)
 	{
@@ -302,7 +302,7 @@ int adbAdd(const struct arcentry *a)
 	{
 		void *t;
 		uint32_t j;
-		
+
 		adbNum+=256;
 		if (!(t=realloc(adbData, adbNum*sizeof(*adbData))))
 			return 0;
@@ -479,7 +479,7 @@ int adbCallArc(const char *cmd, const char *arc, const char *name, const char *d
 				argv[argc]=tmp;
 				argv[argc][len++]=*cmd;
 				argv[argc][len]=0;
-			}	
+			}
 		}
 		cmd++;
 	}
@@ -526,17 +526,21 @@ int isarchivepath(const char *p)
 {
 	char path[PATH_MAX+1];
 	char ext[NAME_MAX+1];
-/*	struct stat st;*/
+/*
+	struct stat st;
+*/
 
 	strcpy(path, p);
 	if (*p)
 		if (path[strlen(path)-1]=='/')
 			path[strlen(path)-1]=0;
-	
-/*	if (stat(path, &st))
+
+/*
+	if (stat(path, &st))
 		return 0;
 	if (!S_ISREG(st.st_mode))
-		return 0;*/
+		return 0;
+*/
 
 	_splitpath(path, 0, 0, 0, ext);
 
@@ -574,7 +578,7 @@ static signed char adbFindFirst(const char *path, unsigned long arclen, char *fi
 	strcat(arcname, ext);
 
 	ar=adbFind(arcname);
-	
+
 	if ((ar==0xFFFFFFFF)||(arclen!=(ar!=0xffffffff?adbData[ar].size:0)))
 	{
 		if (ar!=0xFFFFFFFF)
@@ -624,7 +628,7 @@ FILE *adb_ReadHandle(struct modlistentry *entry)
 	_splitpath(npath, NULL, dir, NULL, NULL);
 
 	/* TODO, logic here should work / for / and stat for dir/file */
-	
+
 	_makepath(path, 0, dir, 0, 0);
 	path[strlen(path)-1]=0; /* Remove / suffix */
 
@@ -633,7 +637,7 @@ FILE *adb_ReadHandle(struct modlistentry *entry)
 
 	if ((strlen(cfTempDir)+strlen("ocptmpXXXXXX"))>PATH_MAX)
 		return 0;
-	
+
 	_splitpath(path, 0, 0, 0, ext);
 
 	strcpy(temppath, cfTempDir);
@@ -697,7 +701,7 @@ int adb_Read(struct modlistentry *entry, char **mem, size_t *size)
 	} else {
 		*mem=realloc(*mem, *size);
 	}
-	
+
 	fclose(f);
 	return 0;
 }
@@ -712,12 +716,15 @@ static int arcReadDir(struct modlist *ml, const struct dmDrive *drive, const uin
 		return 1;
 
 	dirdbGetFullName(path, _path, DIRDB_FULLNAME_NOBASE);
-/*	dmGetPath(path, dirref);*/
-      	if (isarchivepath(_path))
-      	{
-/*		dmGetPath(path, dirref);
-	    	path[strlen(path)-1]=0;*/
-
+/*
+	dmGetPath(path, dirref);
+*/
+	if (isarchivepath(_path))
+	{
+/*
+		dmGetPath(path, dirref);
+		path[strlen(path)-1]=0;
+*/
 		size_t flength;
 		int tf;
 
@@ -725,7 +732,6 @@ static int arcReadDir(struct modlist *ml, const struct dmDrive *drive, const uin
 		signed char done;
 
 		char newfilepath[ARC_PATH_MAX+1];
-	
 #ifndef FNM_CASEFOLD
 		char *mask_upper;
 		char *iterate;
@@ -751,7 +757,7 @@ static int arcReadDir(struct modlist *ml, const struct dmDrive *drive, const uin
 		flength=filelength(tf);
 		close(tf);
 
-	    	for (done=adbFindFirst(_path, flength, newfilepath, &size, &adb_ref); !done; done=adbFindNext(newfilepath, &size, &adb_ref))
+		for (done=adbFindFirst(_path, flength, newfilepath, &size, &adb_ref); !done; done=adbFindNext(newfilepath, &size, &adb_ref))
 		{
 			char name[NAME_MAX+1];
 			char ext[NAME_MAX+1];
