@@ -43,4 +43,11 @@ extern const char adbsigv2[16];
 extern void adbRegister(struct adbregstruct *r);
 extern void adbUnregister(struct adbregstruct *r);
 
+#include <stdio.h>
+struct modlistentry;
+extern FILE *adb_ReadHandle(struct modlistentry *entry);
+extern int adb_ReadHeader(struct modlistentry *entry, char *mem, size_t *size);
+extern int adb_Read(struct modlistentry *entry, char **mem, size_t *size);
+
+
 #endif
