@@ -49,7 +49,7 @@ struct __attribute__((packed)) posix_header
 	char uid[8];                  /* 108 */
 	char gid[8];                  /* 116 */
 	char size[12];                /* 124 */
-       	char mtime[12];               /* 136 */
+	char mtime[12];               /* 136 */
 	char chksum[8];               /* 148 */
 	char typeflag;                /* 156 */
 	char linkname[100];           /* 157 */
@@ -139,7 +139,7 @@ static int pipe_uncompress(const char *program, char *const argv[], const char *
 {
 	int fds[2];
 	int fd;
-	
+
 	pipe_fd=-1;
 	if ((fd=open(source, O_RDONLY))<0)
 	{
@@ -152,7 +152,7 @@ static int pipe_uncompress(const char *program, char *const argv[], const char *
 		perror("arctar: pipe()");
 		return -1;
 	}
-	
+
 	if ((pipe_pid=fork()))
 	{
 		if (pipe_pid<0)
@@ -184,8 +184,8 @@ static int pipe_uncompress(const char *program, char *const argv[], const char *
 		exit(1);
 	}
 	close(fd);
-	
-	execvp(program, argv);	
+
+	execvp(program, argv);
 	perror("arctar: execlp(program, argv, NULL)");
 	exit(-1);
 }
@@ -195,7 +195,7 @@ static int adbTARScan(const char *path)
 {
 	uint32_t arcref;
 	struct arcentry a;
-	
+
 	int extfd;
 	char buffer[BUFFER_SIZE];
 	size_t bufferfill=0;
@@ -203,14 +203,16 @@ static int adbTARScan(const char *path)
 	size_t skip=0;
 	size_t requiredata=0;
 
-/*	fprintf(stderr, "adbTARScan, %s\n", path);*/
+	/* fprintf(stderr, "adbTARScan, %s\n", path);*/
 
 	if (!setupformat(path))
 		return 0;
-	
+
 	switch (format)
 	{
-/*		case 0:*/
+/*
+		case 0:
+*/
 		default: /* avoids warning -ss040902 */
 			extfd=open(path, O_RDONLY);
 			break;
@@ -253,7 +255,7 @@ static int adbTARScan(const char *path)
 		return 0;
 	}
 	bufferfill=retval;
-	
+
 	memset(a.name, 0, sizeof(a.name));
 	strncpy(a.name, arcname, sizeof(a.name)-1);
 	a.size=_filelength(path);
@@ -287,8 +289,9 @@ static int adbTARScan(const char *path)
 				pipe_done();
 				return 1;
 			}
-/*			fprintf(stderr, "arctar: Entry: %s\n", entry->name);*/
-
+/*
+			fprintf(stderr, "arctar: Entry: %s\n", entry->name);
+*/
 			size=char12tosize_t(entry->size);
 
 			_splitpath(entry->name, 0, 0, name, ext);
@@ -305,7 +308,7 @@ static int adbTARScan(const char *path)
 					)
 				)
 				{
-				/* TODO	if ((!strcasecmp(ext, MIF_EXT))&&size<65536)
+				/* TODO if ((!strcasecmp(ext, MIF_EXT))&&size<65536)
 						requiredata=size;
 					else*/ {
 						requiredata=1084;
@@ -314,7 +317,7 @@ static int adbTARScan(const char *path)
 					}
 					if (bufferfill<(sizeof(struct posix_header)+requiredata))
 						break; /* we need more data */
-	
+
 					strcpy(a.name, entry->name);
 					a.size=size;
 					a.flags=0;
@@ -324,17 +327,17 @@ static int adbTARScan(const char *path)
 						pipe_done();
 						return 0;
 					}
-			
+
 					strcpy(a.name, name);
-					strcat(a.name, ext);	
-					
+					strcat(a.name, ext);
+
 				        if (fsScanInArc)
 					{
 						char shortname[12];
 						uint32_t fileref;
 						struct moduleinfostruct mi;
 						fs12name(shortname, a.name);
-						fileref=mdbGetModuleReference(shortname, a.size);	
+						fileref=mdbGetModuleReference(shortname, a.size);
 						if (fileref==0xffffffff)
 						{
 							pipe_done();
@@ -382,7 +385,9 @@ static int adbTARScan(const char *path)
 
 static int adbTARCall(const int act, const char *apath, const char *fullname, const int fd)
 {
-/*	fprintf(stderr, "adbTARCall, %d %s %s %s\n", act, apath, file, dpath);*/
+/*
+	fprintf(stderr, "adbTARCall, %d %s %s %s\n", act, apath, file, dpath);
+*/
 	if (!setupformat(apath))
 			return 0;
 	switch (act)
@@ -413,7 +418,7 @@ static int adbTARCall(const int act, const char *apath, const char *fullname, co
 				argv[3]="-O";
 				argv[4]=(char *)fullname; /* dirty, but should be safe */
 				argv[5]=NULL;
-			
+
 				if (!(child=fork()))
 				{
 					close(1);
