@@ -68,7 +68,7 @@ static void try(const char *dev, const char *vdev)
 	if ((fd=open(dev, O_RDONLY|O_NONBLOCK))>=0)
 	{
 		int caps;
-		
+
 		if ((caps=ioctl(fd, CDROM_GET_CAPABILITY, 0))>=0)
 		{
 			temp=malloc(sizeof(struct cdrom_t));
@@ -184,7 +184,7 @@ static int cdint(void)
 	char dev[32], vdev[12];
 	char a;
 	root=0;
-	
+
 	mdbRegisterReadDir(&cdReadDirReg);
 
 	dmCDROM=RegisterDrive("cdrom:");
@@ -276,8 +276,10 @@ static int cdReadDir(struct modlist *ml, const struct dmDrive *drive, const uint
 					int i;
 					for (i=tochdr.cdth_trk0;i<=(tochdr.cdth_trk1);i++)
 					{
-/*						if (i>tochdr.cdth_trk1)
-							i=CDROM_LEADOUT;*/
+/*
+						if (i>tochdr.cdth_trk1)
+							i=CDROM_LEADOUT;
+*/
 						tocentry.cdte_track=i;
 						tocentry.cdte_format=CDROM_LBA; /* CDROM_MSF */
 						if (!ioctl(current->fd, CDROMREADTOCENTRY, &tocentry))
@@ -285,7 +287,8 @@ static int cdReadDir(struct modlist *ml, const struct dmDrive *drive, const uint
 							tocentryN.cdte_track=(i==tochdr.cdth_trk1)?CDROM_LEADOUT:i+1;
 							tocentryN.cdte_format=CDROM_LBA;
 							ioctl(current->fd, CDROMREADTOCENTRY, &tocentryN);
-/*							fprintf(stderr, "cdte_track:    %d%s\n", tocentry.cdte_track, (i==CDROM_LEADOUT)?" LEADOUT":"");
+/*
+							fprintf(stderr, "cdte_track:    %d%s\n", tocentry.cdte_track, (i==CDROM_LEADOUT)?" LEADOUT":"");
 							fprintf(stderr, "cdte_adr:      %d\n", tocentry.cdte_adr);
 							fprintf(stderr, "cdte_ctrl:     %d %s\n", tocentry.cdte_ctrl, (tocentry.cdte_ctrl&CDROM_DATA_TRACK)?"(DATA)":"AUDIO");
 							fprintf(stderr, "cdte_format:   %d\n", tocentry.cdte_format);
@@ -296,12 +299,13 @@ static int cdReadDir(struct modlist *ml, const struct dmDrive *drive, const uint
 							} else {
 								fprintf(stderr, "cdte_addr.lba:        %d\n", tocentry.cdte_addr.lba);
 							}
-							fprintf(stderr, "cdte_datamode: %d\n", tocentry.cdte_datamode);*/
+							fprintf(stderr, "cdte_datamode: %d\n", tocentry.cdte_datamode);
+*/
 							if (!(tocentry.cdte_ctrl&CDROM_DATA_TRACK))
 							{
 								char buffer[12];
 								struct moduleinfostruct mi;
-	
+
 								snprintf(buffer, 12, "TRACK%02d.CDA", i);
 
 								if (initlba<0)
