@@ -3,8 +3,10 @@
 
 #define DIRDB_NOPARENT 0xffffffff
 #define DIRDB_NO_MDBREF 0xffffffff
+#define DIRDB_NO_ADBREF 0xffffffff
 
 extern const char dirdbsigv1[60];
+extern const char dirdbsigv2[60];
 
 extern void dirdbFlush(void); /* removes all nodes that hasn't been ref'ed yet aswell */
 
@@ -22,10 +24,11 @@ extern void dirdbClose(void);
 extern uint32_t dirdbGetParentAndRef(uint32_t node);
 
 extern void dirdbTagSetParent(uint32_t node);
-extern void dirdbMakeMdbRef(uint32_t node, uint32_t mdbref);
+extern void dirdbMakeMdbAdbRef(uint32_t node, uint32_t mdbref, uint32_t adbref);
 extern void dirdbTagCancel(void);
 extern void dirdbTagRemoveUntaggedAndSubmit(void);
 
-extern int dirdbGetMdb(uint32_t *dirdbnode, uint32_t *mdbnode, int *first);
+extern int dirdbGetMdbAdb(uint32_t *dirdbnode, uint32_t *mdbnode, uint32_t *adbref, int *first);
+
 
 #endif
