@@ -236,7 +236,8 @@ void fs12name(char *shortname, const char *source)
 	int length=strlen(source);
 	strcpy(temppath, source);
 
-/*	if (length)
+/*
+	if (length)
 		if (temppath[length-1]=='/')
 		{
 			temppath[length-1]=0;
@@ -252,26 +253,32 @@ void fs12name(char *shortname, const char *source)
 			{
 				strcpy(temppath+length-8, ".tbz");
 				length-=4;
-/*				entry->flags=MODLIST_FLAG_ARC;*/
+/*
+				entry->flags=MODLIST_FLAG_ARC;
+*/
 			}
 		if (length>=7)
 			if (!strcasecmp(temppath+length-7, ".tar.gz"))
 			{
 				strcpy(temppath+length-7, ".tgz");
 				length-=3;
-/*				entry->flags=MODLIST_FLAG_ARC;*/
+/*
+				entry->flags=MODLIST_FLAG_ARC;
+*/
 			}
 		if (length>=6)
 			if (!strcasecmp(temppath+length-6, ".tar.Z"))
 			{
 				strcpy(temppath+length-6, ".tgz");
 				length-=2;
-/*				entry->flags=MODLIST_FLAG_ARC;*/
+/*
+				entry->flags=MODLIST_FLAG_ARC;
+*/
 			}
 #if 0
 	}
 #endif
-	
+
 	if ((lastdot=rindex(temppath+1, '.'))) /* we allow files to start with . */
 	{
 		int delta=lastdot-temppath;
