@@ -210,7 +210,7 @@ static int _fsMain(int argc, char *argv[])
 #ifdef DOS32
   /* TODO.. this can be done on xterm consoles, and proc titles*/
 	setwintitle("OpenCP");
-#endif 
+#endif
 
 	fsRescanDir();
 
@@ -218,7 +218,8 @@ static int _fsMain(int argc, char *argv[])
 	{
 		struct preprocregstruct *prep;
 
-/*		while (ekbhit())
+/*
+		while (ekbhit())
 		{
 			uint16_t key=egetch();
 			if ((key==0)||(key==3)||(key==27))
@@ -299,7 +300,8 @@ static int _fsMain(int argc, char *argv[])
 		if (plintr)
 		{
 
-/*			while (ekbhit())
+/*
+			while (ekbhit())
 				egetch();*/
 
 			while (!stop) /* != interfaceReturnContinue */
@@ -344,7 +346,8 @@ static int _fsMain(int argc, char *argv[])
 						stop=interfaceReturnContinue;
 						plDosShell();
 						conSave();
-/*						while (ekbhit())
+/*
+						while (ekbhit())
 							egetch();*/
 						break;
 				}
@@ -373,7 +376,7 @@ static int fspreint(void)
 	mdbRegisterReadDir(&plsReadDirReg);
 	mdbRegisterReadDir(&m3uReadDirReg);
 	mdbRegisterReadInfo(&fsReadInfoReg);
-	
+
 	fprintf(stderr, "initializing fileselector...\n");
 	if (!fsPreInit())
 	{
