@@ -92,12 +92,13 @@ void fsAddPlaylist(struct modlist *ml, const char *path, const char *mask, unsig
 	strncpy(retval.name, s3, NAME_MAX);
 	retval.name[NAME_MAX]=0;
 
-	retval.dirdbfullpath = dirdbResolvePathWithBaseAndRef(dmDrive->basepath, fullpath); 
-	fs12name(retval.shortname, s3);	
+	retval.dirdbfullpath = dirdbResolvePathWithBaseAndRef(dmDrive->basepath, fullpath);
+	fs12name(retval.shortname, s3);
 
 	if (S_ISREG(st.st_mode))
 	{
-/*		if (isarchivepath(fullpath))
+/*
+		if (isarchivepath(fullpath))
 		{
 			retval.flags=MODLIST_FLAG_ARC;
 			strncat(retval.fullname, "/", PATH_MAX-strlen(retval.fullname)-1);
@@ -117,7 +118,7 @@ void fsAddPlaylist(struct modlist *ml, const char *path, const char *mask, unsig
 				} else {
 					perror("pfsm3u.c: strdup() failed");
 					dirdbUnref(retval.dirdbfullpath);
-					return;	
+					return;
 				}
 
 				if (fnmatch(mask, name_upper, 0)||(!fsIsModule(curext)))
@@ -129,7 +130,7 @@ void fsAddPlaylist(struct modlist *ml, const char *path, const char *mask, unsig
 				free(name_upper);
 			}
 #else
-		      	if ((fnmatch(mask, retval.name, FNM_CASEFOLD))||(!fsIsModule(curext)))
+			if ((fnmatch(mask, retval.name, FNM_CASEFOLD))||(!fsIsModule(curext)))
 			{
 				dirdbUnref(retval.dirdbfullpath);
 				return;
@@ -141,7 +142,8 @@ void fsAddPlaylist(struct modlist *ml, const char *path, const char *mask, unsig
 		}
 	} else if (S_ISDIR(st.st_mode))
 	{
-	/*	if ((opt&RD_PUTSUBS))
+/*
+		if ((opt&RD_PUTSUBS))
 		{
 			retval.flags=MODLIST_FLAG_DIR;
 			strncat(retval.fullname, "/", PATH_MAX-strlen(retval.fullname)-1);
@@ -162,6 +164,6 @@ void fsAddPlaylist(struct modlist *ml, const char *path, const char *mask, unsig
 	retval.Read=dosfile_Read;
 	retval.ReadHeader=dosfile_ReadHeader;
 	retval.ReadHandle=dosfile_ReadHandle;
-	modlist_append(ml, &retval); 
+	modlist_append(ml, &retval);
 	dirdbUnref(retval.dirdbfullpath);
 }
