@@ -101,7 +101,8 @@ static int mlSubScan(const uint32_t dirdbnode, int mlTop)
 			if (strcmp(mle->name, "."))
 			if (strcmp(mle->name, "/"))
 			{
-/*				dirdbGetFullName(mle->dirdbfullpath, npath, DIRDB_FULLNAME_NOBASE|DIRDB_FULLNAME_ENDSLASH);
+/*
+				dirdbGetFullName(mle->dirdbfullpath, npath, DIRDB_FULLNAME_NOBASE|DIRDB_FULLNAME_ENDSLASH);
 				if (mlSubScan(npath, mlTop))*/
 				if (mlSubScan(mle->dirdbfullpath, mlTop))
 					return -1;
@@ -147,7 +148,7 @@ static FILE *mlSourcesAdd(struct modlistentry *entry)
 	char str[PATH_MAX+6];
 	unsigned int curpos;
 	unsigned int cmdlen;
-      	int insmode=1;
+	int insmode=1;
 	unsigned int scrolled=0;
 
 	strcpy(str, "file:/");
@@ -270,7 +271,7 @@ static FILE *mlSourcesAdd(struct modlistentry *entry)
 			case KEY_DOWN:
 				if ((editpath^=1))
 					setcurshape((insmode?1:2));
-				else 
+				else
 					setcurshape(0);
 				break;
 		}
@@ -304,13 +305,13 @@ static int mlReadDir(struct modlist *ml, const struct dmDrive *drive, const uint
 		entry.fileref=0xffffffff;
 		entry.adb_ref=0xffffffff;
 		entry.Read=0; entry.ReadHeader=0; entry.ReadHandle=0;
-	
+
 		strcpy(entry.shortname, "all");
 		fs12name(entry.shortname, "all");
 		strcpy(entry.name, "all");
 		entry.dirdbfullpath=dmall;
 		modlist_append(ml, &entry);
-	
+
 		strcpy(entry.shortname, "search");
 		strcpy(entry.name, "search");
 		fs12name(entry.shortname, "search");
@@ -340,7 +341,7 @@ static int mlReadDir(struct modlist *ml, const struct dmDrive *drive, const uint
 			fs12name(entry.shortname, cachefile);
 			strncpy(entry.name, cachefile, NAME_MAX);
 			entry.name[NAME_MAX]=0;
-					
+
 			entry.drive=dmFILE;
 			entry.dirdbfullpath=dirdbnode; /*dirdbResolvePathAndRef(files[i].name);*/
 			entry.flags=MODLIST_FLAG_FILE;
@@ -357,7 +358,8 @@ static int mlReadDir(struct modlist *ml, const struct dmDrive *drive, const uint
 				entry.ReadHandle=adb_ReadHandle;
 			}
 			modlist_append(ml, &entry);
-/*			dirdbUnref(entry.dirdbfullpath);*/
+/*
+			dirdbUnref(entry.dirdbfullpath);*/
 		}
 		goto out;
 	}
@@ -461,7 +463,7 @@ static int mlReadDir(struct modlist *ml, const struct dmDrive *drive, const uint
 
 						for (i=0;i<cmdlen;i++)
 							str[i]=toupper(str[i]);
-						
+
 						while (!dirdbGetMdbAdb(&dirdbnode, &mdbref, &adbref, &first))
 						{
 							char cachefile[NAME_MAX+1];
@@ -470,18 +472,18 @@ static int mlReadDir(struct modlist *ml, const struct dmDrive *drive, const uint
 							dirdbGetname(dirdbnode, cachefile);
 							strncpy(buffer, cachefile, sizeof(buffer));
 							buffer[sizeof(buffer)-1]=0;
-						
+
 							if (strstr(buffer, str))
 								goto add;
-							
+
 							mdbGetModuleInfo(&info, mdbref);
-							
+
 							for (j=0;j<sizeof(info.name);j++)
 								buffer[j]=toupper(info.name[j]);
 							buffer[j]=0;
 							if (strstr(buffer, str))
 								goto add;
-							
+
 							for (j=0;j<sizeof(info.modname);j++)
 								buffer[j]=toupper(info.modname[j]);
 							buffer[j]=0;
@@ -506,7 +508,7 @@ static int mlReadDir(struct modlist *ml, const struct dmDrive *drive, const uint
 								fs12name(entry.shortname, cachefile);
 								strncpy(entry.name, cachefile, NAME_MAX);
 								entry.name[NAME_MAX]=0;
-					
+
 								entry.drive=dmFILE;
 								entry.dirdbfullpath=dirdbnode; /*dirdbResolvePathAndRef(files[i].name);*/
 								entry.flags=MODLIST_FLAG_FILE;
@@ -523,7 +525,7 @@ static int mlReadDir(struct modlist *ml, const struct dmDrive *drive, const uint
 									entry.ReadHandle=adb_ReadHandle;
 								}
 								modlist_append(ml, &entry);
-					/*			dirdbUnref(entry.dirdbfullpath);*/
+								/* dirdbUnref(entry.dirdbfullpath);*/
 							}
 						}
 						goto out;
