@@ -55,17 +55,17 @@ static int new_ay_track=0;
 __attribute__ ((visibility ("internal"))) unsigned long ay_tstates,ay_tsmax;
 static int ay_current_reg=0;
 static int done_fade=0;
-static int fadetime=10;	/* fadeout time *after* that in sec, 0=none */
-static int stopafter=0; /* TODO */
-static int silent_max=4*50;	/* max frames of silence before skipping */
+static int fadetime=10;     /* fadeout time *after* that in sec, 0=none */
+static int stopafter=0;     /* TODO */
+static int silent_max=4*50; /* max frames of silence before skipping */
 static int ay_looped;
 
 /* the memory is a flat all-RAM 64k */
 __attribute__ ((visibility ("internal"))) unsigned char ay_mem[64*1024];
-#define AYLET_VER	"0.3"
-#define FRAME_STATES_48		(3500000/50)
-#define FRAME_STATES_128	(3546900/50)
-#define FRAME_STATES_CPC	(4000000/50)
+#define AYLET_VER               "0.3"
+#define FRAME_STATES_48         (3500000/50)
+#define FRAME_STATES_128        (3546900/50)
+#define FRAME_STATES_CPC        (4000000/50)
 static int do_cpc=0;
 
 
@@ -138,7 +138,7 @@ static void audio_pcm_s16(int16_t *dest, unsigned int nsamples, uint16_t *source
 	len = nsamples;
 	if (srnd)
 		xormask=0xffff;
-	
+
 	while (len--)
 	{
 		rs = *source;/*((*source) + ((*source)<<8))^0x8000;*/
@@ -194,29 +194,29 @@ write_dat:
 						if((h&0xc0)==0x80) goto write_dat;
 				}
 				break;
-				
+
 			case 0xfe:
 				do_cpc=-1;
 				sound_beeper(a&0x10);
 				break;
 		}
-	
+
 	if(do_cpc>-1)
 		switch(h)
 		{
 			case 0xf6:
 				switch(a&0xc0)
 				{
-					case 0x80:	/* write */
+					case 0x80: /* write */
 						sound_ay_write(ay_current_reg,cpc_f4,ay_tstates);
 						break;
-						
-					case 0xc0:	/* select */
+
+					case 0xc0: /* select */
 						ay_current_reg=(cpc_f4&15);
 						break;
 				}
 				break;
-				
+
 			case 0xf4:
 				cpc_f4=a;
 				if(!do_cpc)
@@ -229,8 +229,8 @@ write_dat:
 				}
 				break;
 		}
-	
-	return 0;	/* additional t-states */
+
+	return 0; /* additional t-states */
 }
 
 /* from main.c */
@@ -238,27 +238,27 @@ static void mem_init(int track)
 {
 	static uint8_t intz[]=
 	{
-		0xf3,		/* di */
-		0xcd,0,0,	/* call init */
-		0xed,0x5e,	/* loop: im 2 */
-		0xfb,		/* ei */
-		0x76,		/* halt */
-		0x18,0xfa	/* jr loop */
+		0xf3,           /* di */
+		0xcd,0,0,       /* call init */
+		0xed,0x5e,      /* loop: im 2 */
+		0xfb,           /* ei */
+		0x76,           /* halt */
+		0x18,0xfa       /* jr loop */
 	};
 	static uint8_t intnz[]=
 	{
-		0xf3,		/* di */
-		0xcd,0,0,	/* call init */
-		0xed,0x56,	/* loop: im 1 */
-		0xfb,		/* ei */
-		0x76,		/* halt */
-		0xcd,0,0,	/* call interrupt */
-		0x18,0xf7	/* jr loop */
+		0xf3,           /* di */
+		0xcd,0,0,       /* call init */
+		0xed,0x56,      /* loop: im 1 */
+		0xfb,           /* ei */
+		0x76,           /* halt */
+		0xcd,0,0,       /* call interrupt */
+		0x18,0xf7       /* jr loop */
 	};
 	int init,ay_1st_block,ourinit,interrupt;
 	uint8_t *ptr;
 	int addr,len,ofs;
-	
+
 #define GETWORD(x) (((*(x))<<8)|(*(x+1)))
 
 	init=GETWORD(aydata.tracks[track].data_stacketc+2);
@@ -268,7 +268,7 @@ static void mem_init(int track)
 	memset(ay_mem+0x0000,0xc9,0x0100);
 	memset(ay_mem+0x0100,0xff,0x3f00);
 	memset(ay_mem+0x4000,0x00,0xc000);
-	ay_mem[0x38]=0xfb;	/* ei */
+	ay_mem[0x38]=0xfb;      /* ei */
 
 	/* call first AY block if no init */
 	ourinit=(init?init:ay_1st_block);
@@ -293,7 +293,7 @@ static void mem_init(int track)
 		ofs=GETWORD(ptr+4);
 		if(ofs>=0x8000) ofs=-0x10000+ofs;
 
-	      	/* range check */
+		/* range check */
 		if(ptr-4-aydata.filedata+ofs>=aydata.filelen ||
 				ptr-4-aydata.filedata+ofs<0)
 		{
@@ -301,12 +301,12 @@ static void mem_init(int track)
 			continue;
 		}
 
-	      	/* fix any broken length */
+		/* fix any broken length */
 		if(ptr+4+ofs+len>=aydata.filedata+aydata.filelen)
 			len=aydata.filedata+aydata.filelen-(ptr+4+ofs);
 		if(addr+len>0x10000)
 			len=0x10000-addr;
-  
+
 		memcpy(ay_mem+addr,ptr+4+ofs,len);
 		ptr+=6;
 	}
@@ -349,7 +349,7 @@ static int read_ay_file(FILE *in)
 			}
 		}
 
-	      	memcpy(data+data_ofs,buf,ret);
+		memcpy(data+data_ofs,buf,ret);
 		data_ofs+=ret;
 	}
 
@@ -376,8 +376,8 @@ static int read_ay_file(FILE *in)
 
 	aydata.tracks=NULL;
 
-#define READWORD(x)	(x)=256*(*ptr++); (x)|=*ptr++
-#define READWORDPTR(x)	READWORD(tmp); \
+#define READWORD(x)     (x)=256*(*ptr++); (x)|=*ptr++
+#define READWORDPTR(x)  READWORD(tmp); \
 		if(tmp>=0x8000) tmp=-0x10000+tmp; \
 		if(ptr-data-2+tmp>=data_len || ptr-data-2+tmp<0) \
 		  { \
@@ -397,7 +397,7 @@ static int read_ay_file(FILE *in)
 	ptr=data+8;
 	aydata.filever=*ptr++;
 	aydata.playerver=*ptr++;
-	ptr+=2;		/* skip `custom player' stuff */
+	ptr+=2;  /* skip `custom player' stuff */
 	READWORDPTR(aydata.authorstr);
 	CHECK_ASCIIZ(aydata.authorstr);
 	READWORDPTR(aydata.miscstr);
@@ -434,7 +434,7 @@ static int read_ay_file(FILE *in)
 		ptr=aydata.tracks[f].data+10;
 		READWORDPTR(aydata.tracks[f].data_stacketc);
 		READWORDPTR(aydata.tracks[f].data_memblocks);
-  
+
 		ptr=aydata.tracks[f].data+4;
 		READWORD(aydata.tracks[f].fadestart);
 		READWORD(aydata.tracks[f].fadelen);
@@ -501,8 +501,9 @@ int __attribute__ ((visibility ("internal"))) ay_do_interrupt(void)
 		}
 		return 0;
 	}
-	
-/*	return(ui_frame());*/
+
+/*
+	return(ui_frame());*/
 	return 0;
 }
 
@@ -510,7 +511,8 @@ void __attribute__ ((visibility ("internal"))) ay_driver_frame(uint16_t *stereo_
 {
 	_buf8=stereo_samples;
 	_buf8_n=bytes>>1;
-/*	while (bytes)
+/*
+	while (bytes)
 	{
 		fprintf(stderr, "%02x ", *stereo_samples);
 		bytes--;
@@ -569,11 +571,12 @@ void __attribute__ ((visibility ("internal"))) ayIdle(void)
 	uint32_t bufdelta;
 	uint32_t pass2;
 	int quietlen=0;
-/*	uint32_t toloop;*/
+/*
+	uint32_t toloop;*/
 
 	if (clipbusy++)
 	{
-	       	clipbusy--;
+		clipbusy--;
 		return;
 	}
 
@@ -591,7 +594,7 @@ void __attribute__ ((visibility ("internal"))) ayIdle(void)
 		return;
 	}
 	ayIdler();
-  	/* if (aybuflen!=aylen)  this has with looping TODO */
+	/* if (aybuflen!=aylen)  this has with looping TODO */
 	{
 		uint32_t towrap=imuldiv((((aybuflen+aybufread-aybufpos-1)%aybuflen)>>(/*aystereo+*/1)), 65536, aybufrate);
 		if (bufdelta>towrap)
@@ -602,15 +605,15 @@ void __attribute__ ((visibility ("internal"))) ayIdle(void)
 	if (inpause)
 		quietlen=bufdelta;
 
-/*	TODO, this has with lopping todo
- *	toloop=imuldiv(((bufloopat-aybufpos)>>(1+aystereo)), 65536, aybufrate);
+/* TODO, this has with lopping todo
+	toloop=imuldiv(((bufloopat-aybufpos)>>(1+aystereo)), 65536, aybufrate);
 	if (looped)
 		toloop=0;*/
 
 	bufdelta-=quietlen;
 
-/*	TODO, this has with looping todo
- *	if (bufdelta>=toloop)
+/* TODO, this has with looping todo
+	if (bufdelta>=toloop)
 	{
 		looped=1;
 		if (donotloop)
@@ -633,7 +636,8 @@ void __attribute__ ((visibility ("internal"))) ayIdle(void)
 				if ((aybuflen-aybufpos)<w)
 					w=aybuflen-aybufpos;
 				memcpy(buf16+(o<<1), aybuf+(aybufpos<<2), w<<2);
-		/*		{
+		/*
+				{
 					unsigned char *c=aybuf+(aybufpos<<2);
 					int  a=w<<2;
 					while (a--)
@@ -984,7 +988,7 @@ int __attribute__ ((visibility ("internal"))) ayOpenPlayer(FILE *file)
 	if (!plrPlay)
 		return 0;
 
-    	if(!read_ay_file(file)) /* 0 meens error */
+	if(!read_ay_file(file)) /* 0 meens error */
 		return 0;
 
 	plrSetOptions(44100, (PLR_SIGNEDOUT|PLR_16BIT)|PLR_STEREO);
@@ -1008,7 +1012,8 @@ int __attribute__ ((visibility ("internal"))) ayOpenPlayer(FILE *file)
 	pan=64;
 	srnd=0;
 	aySetVolume(64, 0, 64, 0);
-/*	aySetAmplify(amplify);   TODO */
+/*
+	aySetAmplify(amplify);   TODO */
 	buf16=malloc(sizeof(uint16_t)*buflen*2);
 	if (!buf16)
 	{
@@ -1037,7 +1042,8 @@ int __attribute__ ((visibility ("internal"))) ayOpenPlayer(FILE *file)
 
 	ay_track=0;
 	ay_looped=0;
-/*	if(go_to_last)
+/*
+	if(go_to_last)
 	{
 		go_to_last=0;
 		ay_track=aydata.num_tracks-1;
@@ -1047,7 +1053,7 @@ int __attribute__ ((visibility ("internal"))) ayOpenPlayer(FILE *file)
 	{
 		free(buf16);
 		free(aybuf);
-			
+
 		if(aydata.tracks)
 			free(aydata.tracks);
 		if(aydata.filedata)
@@ -1062,16 +1068,16 @@ int __attribute__ ((visibility ("internal"))) ayOpenPlayer(FILE *file)
 	tunetime_reset();
 	ay_tsmax=FRAME_STATES_128;
 	do_cpc=0;
-     	ay_z80_init(aydata.tracks[ay_track].data,
- 	            aydata.tracks[ay_track].data_stacketc);
+	ay_z80_init(aydata.tracks[ay_track].data,
+	            aydata.tracks[ay_track].data_stacketc);
 
 	if (!pollInit(ayIdle))
 	{
 		sound_end();
-		
+
 		free(buf16);
 		free(aybuf);
-			
+
 		if(aydata.tracks)
 			free(aydata.tracks);
 		if(aydata.filedata)
@@ -1108,17 +1114,17 @@ int __attribute__ ((visibility ("internal"))) ayIsLooped(void)
 
 void __attribute__ ((visibility ("internal"))) aySetLoop(unsigned char s)
 {
-      	donotloop=!s;
+	donotloop=!s;
 }
 
 void __attribute__ ((visibility ("internal"))) ayPause(unsigned char p)
 {
-      	inpause=p;
+	inpause=p;
 }
 
 void __attribute__ ((visibility ("internal"))) aySetSpeed(uint16_t sp)
 {
-      	if (sp<32)
+	if (sp<32)
 		sp=32;
 	aybufrate=256*sp;
 }
