@@ -36,6 +36,7 @@
 #include "filesel/mdb.h"
 #include "filesel/pfilesel.h"
 #include "stuff/compat.h"
+#include "stuff/err.h"
 #include "stuff/poutput.h"
 #include "stuff/sets.h"
 #include "stuff/timer.h"
@@ -128,10 +129,14 @@ static void normalize(void)
 	srnd=set.srnd;
 	reverb=set.reverb;
 	chorus=set.chorus;
-/*	aySetAmplify(1024*amp);*/
+/*
+	aySetAmplify(1024*amp);
+*/
 	aySetVolume(vol, bal, pan, srnd);
 	aySetSpeed(speed);
-/*	wpSetMasterReverbChorus(reverb, chorus); */
+/*
+	wpSetMasterReverbChorus(reverb, chorus);
+*/
 }
 
 static void ayCloseFile()
@@ -152,9 +157,9 @@ static int ayLooped(void)
 
 static void ayDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 {
-      	long tim;
+	long tim;
 	struct ayinfo globinfo;
-	
+
 	ayGetInfo(&globinfo);
 
 	if (plPause)
@@ -162,7 +167,7 @@ static void ayDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 	else
 		tim=(dos_clock()-starttime)/DOS_CLK_TCK;
 
-      	if (plScrWidth<128)
+	if (plScrWidth<128)
 	{
 		memset(buf[0]+80, 0, (plScrWidth-80)*sizeof(uint16_t));
 		memset(buf[1]+80, 0, (plScrWidth-80)*sizeof(uint16_t));
@@ -182,7 +187,9 @@ static void ayDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 
 		writestring(buf[0], 57, 0x09, "amp: ...% filter: ...  ", 23);
 		_writenum(buf[0], 62, 0x0F, amp*100/64, 10, 3);
-/*		writestring(buf[0], 75, 0x0F, sidpGetFilter()?"on":"off", 3); */
+/*
+		writestring(buf[0], 75, 0x0F, sidpGetFilter()?"on":"off", 3);
+*/
 		writestring(buf[0], 75, 0x0F, "off", 3);
 
 		writestring(buf[1],  0, 0x09," song .. of ..                                   cpu: ...%",80);
@@ -272,6 +279,7 @@ static int ayProcessKey(uint16_t key)
 			startpausefade();
 			break;
 		case KEY_CTRL_P:
+			pausefadedirect=0;
 			if (plPause)
 				starttime=starttime+dos_clock()-pausetime;
 			else
@@ -317,7 +325,9 @@ static int ayProcessKey(uint16_t key)
 
 static int ayOpenFile(const char *path, struct moduleinfostruct *info, FILE *file)
 {
-/*	struct ayinfo ay;*/
+/*
+	struct ayinfo ay;
+*/
 	char _modname[NAME_MAX+1];
 	char _modext[NAME_MAX+1];
 
@@ -351,13 +361,18 @@ static int ayOpenFile(const char *path, struct moduleinfostruct *info, FILE *fil
 	}
 
 	starttime=dos_clock();
+	plPause=0;
 	normalize();
+	pausefadedirect=0;
 
-/*	ayGetInfo(&ay);
+
+/*
+	ayGetInfo(&ay);
 	aylen=inf.len;
-	ayrate=inf.rate;*/
+	ayrate=inf.rate;
+*/
 
-	return 0;
+	return errOk;
 }
 
 struct cpifaceplayerstruct ayPlayer = {ayOpenFile, ayCloseFile};
