@@ -16,7 +16,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
- */ 
+ */
 
 #include "config.h"
 #include <stdio.h>
@@ -40,19 +40,22 @@ static int ayReadMemInfo(struct moduleinfostruct *m, const char *buf, size_t len
 
 	unsigned int left;
 
-/*	uint8_t tracks, default_track;*/
+/*
+	uint8_t tracks, default_track;*/
 
 	/*int i;*/
-	
+
 	if (len<14)
 	{
-/*		fprintf(stderr, "len<14 (len=%d)\n", len);*/
+/*
+		fprintf(stderr, "len<14 (len=%d)\n", len);*/
 		return 0;
 	}
 
 	if (memcmp(buf, "ZXAYEMUL", 8))
 	{
-/*		fprintf(stderr, "AY header failed\n");*/
+/*
+		fprintf(stderr, "AY header failed\n");*/
 		return 0;
 	}
 
@@ -65,7 +68,8 @@ static int ayReadMemInfo(struct moduleinfostruct *m, const char *buf, size_t len
 
 	authorptr=256*(uint8_t)buf[12]+(uint8_t)buf[13] + 12;
 
-/*	fprintf(stderr, "authorptr=%x\n", authorptr);*/
+/*
+	fprintf(stderr, "authorptr=%x\n", authorptr);*/
 	authorstr=buf+authorptr;
 
 	miscptr=256*(uint8_t)buf[14]+(uint8_t)buf[15] + 14;
@@ -86,7 +90,7 @@ static int ayReadMemInfo(struct moduleinfostruct *m, const char *buf, size_t len
 	} else {
 		m->composer[0]=0;
 	}
-	
+
 	if ((left=len-(miscstr-buf))<=0) /* outside buffer-space */
 	{
 		m->comment[0]=0;
