@@ -67,7 +67,7 @@ static uint32_t cdbufread; /* actually this is the write head */
 static uint32_t cdbufpos;  /* read pos */
 static uint32_t cdbuffpos; /* read fine-pos.. when cdbufrate has a fraction */
 static uint32_t cdbufrate; /* re-sampling rate.. fixed point 0x10000 => 1.0 */
-static int clipbusy;
+static volatile int clipbusy;
 static int speed;
 static int doLoop;
 static int cdflushed; /* all is sent to devp */
@@ -88,7 +88,7 @@ static unsigned int rip_pcm_left;
 static void cdIdler(void)
 {
 	size_t clean;
-	
+
 	clean=(cdbufpos+cdbuflen-cdbufread)%cdbuflen;
 	if (clean<8)
 		return;
@@ -97,7 +97,7 @@ static void cdIdler(void)
 	while (clean)
 	{
 		size_t read=clean;
-		
+
 		if (!rip_pcm_left)
 		{
 			if (lba_next==lba_stop)
@@ -143,7 +143,7 @@ void __attribute__ ((visibility ("internal"))) cdIdle(void)
 
 	if (clipbusy++)
 	{
-	       	clipbusy--;
+		clipbusy--;
 		return;
 	}
 
@@ -173,7 +173,8 @@ void __attribute__ ((visibility ("internal"))) cdIdle(void)
 		cdflushed=!towrap; /* dirty hack to tell if all pcm-data has been sent.. */
 
 		if (bufdelta>towrap)
-		{	/* will the eof hit inside the delta? */
+		{
+			/* will the eof hit inside the delta? */
 			/*quietlen=bufdelta-towrap;*/
 			bufdelta=towrap;
 #if 0
@@ -206,13 +207,14 @@ void __attribute__ ((visibility ("internal"))) cdIdle(void)
 		} else { /* re-sample intil we don't have more target-buffer or source-buffer */
 			int32_t c0, c1, c2, c3, ls, rs, vm1,v1,v2, wpm1;
 			uint32_t wp1, wp2;
-/*			if ((bufdelta-=2)<0) bufdelta=0;  by my meening, this should be in place   TODO stian */
+/*
+			if ((bufdelta-=2)<0) bufdelta=0;  by my meening, this should be in place   TODO stian */
 			for (i=0; i<bufdelta; i++)
 			{
 				wpm1=cdbufpos-4; if (wpm1<0) wpm1+=cdbuflen;
 				wp1=cdbufpos+4; if (wp1>=cdbuflen) wp1-=cdbuflen;
 				wp2=cdbufpos+8; if (wp2>=cdbuflen) wp2-=cdbuflen;
-				
+
 				c0 = *(uint16_t *)(cdbuf+cdbufpos)^0x8000;
 				vm1= *(uint16_t *)(cdbuf+wpm1)^0x8000;
 				v1 = *(uint16_t *)(cdbuf+wp1)^0x8000;
@@ -230,7 +232,7 @@ void __attribute__ ((visibility ("internal"))) cdIdle(void)
 					ls=65535;
 				else if (ls<0)
 					ls=0;
-				
+
 				c0 = *(uint16_t *)(cdbuf+cdbufpos+2)^0x8000;
 				vm1= *(uint16_t *)(cdbuf+wpm1+2)^0x8000;
 				v1 = *(uint16_t *)(cdbuf+wp1+2)^0x8000;
@@ -250,7 +252,7 @@ void __attribute__ ((visibility ("internal"))) cdIdle(void)
 					rs=0;
 				buf16[2*i]=(uint16_t)ls^0x8000;
 				buf16[2*i+1]=(uint16_t)rs^0x8000;
-				
+
 				cdbuffpos+=cdbufrate;
 				cdbufpos+=(cdbuffpos>>16)*4;
 				cdbuffpos&=0xFFFF;
@@ -497,7 +499,7 @@ void __attribute__ ((visibility ("internal"))) cdIdle(void)
 		if (bufpos>=buflen)
 			bufpos-=buflen;
 	}
-	
+
 	bufdelta=quietlen;
 	if (bufdelta)
 	{
@@ -534,7 +536,7 @@ void __attribute__ ((visibility ("internal"))) cdSetSpeed(unsigned short sp)
 	if (!cfCDAdigital)
 		return;
 
-      	if (sp<32)
+	if (sp<32)
 		sp=32;
 
 	speed=sp;
@@ -569,7 +571,7 @@ void __attribute__ ((visibility ("internal"))) cdStop(int fd)
 		if (ioctl(fd, CDROMPAUSE))
 			perror("cdaplay: ioctl(fd, CDROMPAUSE)");
 	}
-	
+
 	if (device==1)
 		smpCloseSampler();
 	else if (device==2)
@@ -592,7 +594,7 @@ void __attribute__ ((visibility ("internal"))) cdStop(int fd)
 void __attribute__ ((visibility ("internal"))) cdRestart(int fd)
 {
 	doPause=0;
-	
+
 	if (!cfCDAdigital)
 	{
 		if (ioctl(fd, CDROMRESUME))
@@ -664,7 +666,7 @@ void __attribute__ ((visibility ("internal"))) cdRestartAt(int fd, unsigned long
 
 int __attribute__ ((visibility ("internal"))) cdPlay(int fd, unsigned long start, unsigned long len)
 {
-      	cfCDAtLineIn=cfGetProfileBool2(cfSoundSec, "sound", "cdsamplelinein", 0, 0); /* moved from global initclose */
+	cfCDAtLineIn=cfGetProfileBool2(cfSoundSec, "sound", "cdsamplelinein", 0, 0); /* moved from global initclose */
 	cfCDAdigital=cfGetProfileBool2(cfSoundSec, "sound", "digitalcd", 1, 1);
 
 	doPause=0;
@@ -674,7 +676,6 @@ int __attribute__ ((visibility ("internal"))) cdPlay(int fd, unsigned long start
 
 	if (cfCDAdigital)
 	{
-				
 		cd_fd=fd;
 		clipbusy=0;
 		rip_pcm_left=0;
@@ -685,7 +686,7 @@ int __attribute__ ((visibility ("internal"))) cdPlay(int fd, unsigned long start
 		cdbufpos=0;
 		cdbuffpos=0;
 		cdbufread=1<<(1/* stereo */+1 /*16bit*/);
-		
+
 		plGetMasterSample=plrGetMasterSample;
 		plGetRealMasterVolume=plrGetRealMasterVolume;
 
@@ -708,7 +709,7 @@ int __attribute__ ((visibility ("internal"))) cdPlay(int fd, unsigned long start
 			free(cdbuf);
 			cdbuf=NULL;
 			return -1;
-		}	
+		}
 		bufpos=0;
 
 		cdSetSpeed(256);
@@ -746,7 +747,7 @@ int __attribute__ ((visibility ("internal"))) cdPlay(int fd, unsigned long start
 		if (ioctl(fd, CDROMPLAYBLK, &blk))
 			perror("cdaplay: ioctl(fd, CDROMPLAYBLK, &blk)");
 	}
-	
+
 	return 0;
 }
 
