@@ -41,6 +41,7 @@
 #include "filesel/mdb.h"
 #include "stuff/compat.h"
 #include "stuff/poutput.h"
+#include "stuff/err.h"
 #include "stuff/sets.h"
 
 #include <curses.h>
@@ -156,7 +157,7 @@ static void cdaDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 	memset(buf[2]+80, 0, (plScrWidth-80)*sizeof(uint16_t));
 
 	writestring(buf[0], 0, 0x09, "  mode: ..........  ", 20);
-      	writestring(buf[0], 8, 0x0F, "cd-audio", 10);
+	writestring(buf[0], 8, 0x0F, "cd-audio", 10);
 	for (i=1; i<=cdpTrackNum; i++)
 		if (stat.position<cdpTrackStarts[i])
 			break;
@@ -228,6 +229,7 @@ static int cdaProcessKey(uint16_t key)
 			startpausefade();
 			break;
 		case KEY_CTRL_P:
+			pausefadedirect=0;
 			plPause=!plPause;
 			if (plPause)
 				cdPause(fileno(cdpDrive));
@@ -238,19 +240,21 @@ static int cdaProcessKey(uint16_t key)
 		case 't':
 			cdpViewSectors=!cdpViewSectors;
 			break;
-/*		case 0x2000:
+/*
+		case 0x2000:
 			cdpPlayMode=1;
 			setnewpos=0;
 			basesec=cdpTrackStarts[0];
 			length=cdpTrackStarts[cdpTrackNum]-basesec;
 			//    strcpy(name, "DISK");
-			break;*/
+			break;
+*/
 		case KEY_DOWN:
 			newpos-=75;
 			setnewpos=1;
 			break;
 		case KEY_UP:
-		    	newpos+=75;
+			newpos+=75;
 			setnewpos=1;
 			break;
 		case KEY_LEFT:
@@ -304,7 +308,8 @@ static int cdaProcessKey(uint16_t key)
 			newpos=cdpTrackStarts[i]-basesec;
 			setnewpos=1;
 			break;
-/* TODO-keys	case 0x7700: //ctrl-home
+/* TODO-keys
+		case 0x7700: //ctrl-home
 			newpos=0;
 			setnewpos=1;
 			break;*/
@@ -350,7 +355,7 @@ static int cdaLooped(void)
 		dopausefade();
 
 	cdSetLoop(fsLoopMods);
-	
+
 	cdIdle();
 
 	cdGetStatus(fileno(cdpDrive), &stat);
@@ -362,7 +367,7 @@ static int cdaLooped(void)
 
 	if (stat.looped)
 		return 1;
-	
+
 	if (setnewpos)
 	{
 		if (newpos<0)
@@ -381,7 +386,7 @@ static int cdaLooped(void)
 		setnewpos=0;
 	} else
 		newpos=stat.position-basesec;
-	
+
 	return 0;
 }
 
@@ -445,8 +450,9 @@ static int cdaOpenFile(const char *path, struct moduleinfostruct *info, FILE *fi
 		return -1;
 
 	normalize();
+	pausefadedirect=0;
 
-	return 0;
+	return errOk;
 }
 
 struct cpifaceplayerstruct cdaPlayer = {cdaOpenFile, cdaCloseFile};
