@@ -36,7 +36,7 @@
 #include "dev/plrasm.h"
 #include "flacplay.h"
 
-static int clipbusy=0;
+static volatile int clipbusy=0;
 
 /* options */
 static int inpause;
@@ -175,7 +175,7 @@ static FLAC__StreamDecoderWriteStatus write_callback (
 
 	if (srnd)
 		xormask=0xffff;
-	
+
 	for (i=0;i<frame->header.blocksize;i++)
 	{
 		int ls, rs;
@@ -226,7 +226,7 @@ static void metadata_callback(
 	fprintf(stderr, "metadata.channels: %d\n", metadata->data.stream_info.channels);
 	fprintf(stderr, "metadata.bits_per_sample: %d\n", metadata->data.stream_info.bits_per_sample);
 	fprintf(stderr, "metadata.total_samples: %lld\n", metadata->data.stream_info.total_samples);
-	
+
 	fprintf(stderr, "metadata_callback TODO\n");*/
 	return;
 }
@@ -383,7 +383,7 @@ int __attribute__ ((visibility ("internal"))) flacOpenPlayer(FILE *file)
 	flacrate=0;
 	flacstereo=1;
 
-#if !defined(FLAC_API_VERSION_CURRENT) || FLAC_API_VERSION_CURRENT <= 7	
+#if !defined(FLAC_API_VERSION_CURRENT) || FLAC_API_VERSION_CURRENT <= 7
 	FLAC__seekable_stream_decoder_set_md5_checking(decoder, 0);
 
 	FLAC__seekable_stream_decoder_set_read_callback(decoder, read_callback);
@@ -475,9 +475,9 @@ int __attribute__ ((visibility ("internal"))) flacOpenPlayer(FILE *file)
 	{
 		fprintf(stderr, "playflac: malloc() failed\n");
 		goto error_out;
-	}	
+	}
 	bufpos=0;
-	
+
 	if (!pollInit(flacIdle))
 	{
 		fprintf(stderr, "playflac: pollInit failed\n");
@@ -576,10 +576,10 @@ void __attribute__ ((visibility ("internal"))) flacIdle(void)
 	uint32_t i;
 	uint32_t flacfill;
 	uint32_t written=0;
-	
+
 	if (clipbusy++)
 	{
-	       	clipbusy--;
+		clipbusy--;
 		return;
 	}
 
@@ -672,7 +672,7 @@ void __attribute__ ((visibility ("internal"))) flacIdle(void)
 			wpm1=flacbufpos-1; if (wpm1<0) wpm1+=flacbuflen;
 			wp1=flacbufpos+1; if (wp1>=flacbuflen) wp1-=flacbuflen;
 			wp2=flacbufpos+2; if (wp2>=flacbuflen) wp2-=flacbuflen;
-			
+
 			c0 = (unsigned)(flacbuf[flacbufpos*2])^0x8000;
 			vm1= (unsigned)(flacbuf[wpm1*2])^0x8000;
 			v1 = (unsigned)(flacbuf[wp1*2])^0x8000;
@@ -690,7 +690,7 @@ void __attribute__ ((visibility ("internal"))) flacIdle(void)
 				ls=65535;
 			else if (ls<0)
 				ls=0;
-			
+
 			c0 = (unsigned)(flacbuf[flacbufpos*2+1])^0x8000;
 			vm1= (unsigned)(flacbuf[wpm1*2+1])^0x8000;
 			v1 = (unsigned)(flacbuf[wp1*2+1])^0x8000;
@@ -710,7 +710,7 @@ void __attribute__ ((visibility ("internal"))) flacIdle(void)
 				rs=0;
 			buf16[2*i]=(uint16_t)ls^0x8000;
 			buf16[2*i+1]=(uint16_t)rs^0x8000;
-	
+
 			written++;
 
 			flacbuffpos+=flacbufrate;
@@ -987,7 +987,7 @@ void __attribute__ ((visibility ("internal"))) flacSetAmplify(uint32_t amp)
 }
 void __attribute__ ((visibility ("internal"))) flacSetSpeed(uint16_t sp)
 {
-      	if (sp<32)
+	if (sp<32)
 		sp=32;
 	flacbufrate=imuldiv(256*sp, flacrate, plrRate);
 	fprintf(stderr, "flacbufrate=0x%08x\n", flacbufrate);
