@@ -8,33 +8,33 @@ enum
 
 struct gmdenvelope
 {
-	unsigned char *env;
-	unsigned short len;
-	unsigned short loops, loope;
-	unsigned short sloops, sloope;
-	unsigned char type;
-	unsigned char speed;
+	uint8_t *env;
+	uint16_t len;
+	uint16_t loops, loope;
+	uint16_t sloops, sloope;
+	uint8_t type;
+	uint8_t speed;
 };
 
 struct gmdsample
 {
 	char name[32];
-	unsigned short handle;
-	signed short normnote;
-	signed short stdvol;
-	signed short stdpan;
-	unsigned short opt;
+	uint16_t handle;
+	int16_t normnote;
+	int16_t stdvol;
+	int16_t stdpan;
+	uint16_t opt;
 #define MP_OFFSETDIV2 1
-	unsigned short volfade;
-	unsigned char pchint;
-	unsigned short volenv;
-	unsigned short panenv;
-	unsigned short pchenv;
-	unsigned char vibspeed;
-	unsigned char vibtype;
-	unsigned short vibrate;
-	unsigned short vibdepth;
-	unsigned short vibsweep;
+	uint16_t volfade;
+	uint8_t pchint;
+	uint16_t volenv;
+	uint16_t panenv;
+	uint16_t pchenv;
+	uint8_t vibspeed;
+	uint8_t vibtype;
+	uint16_t vibrate;
+	uint16_t vibdepth;
+	uint16_t vibsweep;
 };
 
 struct gmdinstrument
