@@ -85,12 +85,12 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 		uint8_t defrow;
 		uint16_t flags;
 	} hdr;
-	
+
 	uint16_t *ordlist=0;
 	struct sampleinfo **smps=0;
 	struct gmdsample **msmps=0;
 	unsigned int *instsampnum;
-	
+
 	unsigned int i,j,t;
 
 	uint8_t namelen;
@@ -139,7 +139,7 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 			 *  ||\\----- Pack byte samples
 			 *  \\------- MIDI channels are used in tune. */
 		} oldhdr;
-		
+
 		if (fread(&oldhdr, sizeof(oldhdr), 1, file) != 1)
 			fprintf(stderr, __FILE__ ": warning, read failed #4\n");
 		hdr.ins = oldhdr.ins;
@@ -216,7 +216,7 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 		} envs[3];
 		uint16_t envflags;
 
-		uint8_t vibsweep;
+		/* uint8_t vibsweep; */
 		uint8_t shadowinst;
 		uint16_t volfade;
 
@@ -272,13 +272,13 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 				fprintf(stderr, __FILE__ ": warning, read failed #11\n");
 		}
 
-		vibsweep=0;
+		/* vibsweep=0; */
 
 		if (fread(&shadowinst, sizeof(shadowinst), 1, file) != 1)
 			fprintf(stderr, __FILE__ ": warning, read failed #12\n");
 		if (filever==0x201)
 		{
-			vibsweep=shadowinst;
+			/* TODO? vibsweep=shadowinst; */
 			shadowinst=0;
 		}
 		shadowedby[i]=shadowinst;
@@ -305,7 +305,7 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 				int32_t sus;
 				int32_t lst;
 				int32_t lend;
-				
+
 				for (t=1; t<envs[j].points; t++)
 					envlen+=((envs[j].data[t][1]&1)<<8)|envs[j].data[t][0];
 
@@ -344,7 +344,7 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 				sus=-1;
 				lst=-1;
 				lend=-1;
-				
+
 				if (envflags&(2<<(3*j)))
 				{
 					sus=0;
@@ -360,7 +360,7 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 					for (t=1; t<envs[j].loopend; t++)
 						lend+=((envs[j].data[t][1]&1)<<8)|envs[j].data[t][0];
 				}
-				
+
 				m->envelopes[i*3+j].env=env;
 				m->envelopes[i*3+j].len=envlen;
 				m->envelopes[i*3+j].type=0;
@@ -408,7 +408,7 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 				uint8_t flags; /* bit 6: direction */
 			} amssmp;
 
-			
+
 			int k;
 			for (k=0; k<116; k++)
 				if (samptab[k]==j)
@@ -514,7 +514,7 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 		uint32_t patlen;
 		uint8_t maxrow;
 		uint8_t chan;
-		uint8_t maxcmd;
+		/* uint8_t maxcmd; */
 		char patname[11];
 		struct gmdpattern *pp;
 
@@ -544,13 +544,13 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 			retval=errFormStruc;
 			goto safeout;
 		}
-		
+
 		patlen-=3+namelen;
 
 		if (fread(patname, namelen, 1, file) != 1)
 			fprintf(stderr, __FILE__ ": warning, read failed #28\n");
 		patname[namelen]=0;
-		maxcmd=chan>>5;
+		/* maxcmd=chan>>5; */
 		chan&=0x1F;
 		chan++;
 		if (chan>m->channum)
@@ -597,7 +597,7 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 			int16_t pan;
 			struct gmdtrack *trk;
 			uint16_t len;
-		
+
 			while (row<=maxrow)
 			{
 				unsigned char *cp;
@@ -620,9 +620,10 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 				cmdnum=0;
 				vol=-1;
 				pan=-1;
-/*				if ((ordlist[0]==t)&&!row)
- *					pan=(i&1)?0xC0:0x40;
- */
+/*
+				if ((ordlist[0]==t)&&!row)
+					pan=(i&1)?0xC0:0x40;
+*/
 				if (!(*buf++&0x40))
 				{
 					anothercmd=*buf&0x80;
@@ -658,7 +659,7 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 				}
 				if (curchan!=i)
 					continue;
-				
+
 				cp=tp+2;
 
 				if ((ordlist[0]==t)&&!row)
@@ -1034,7 +1035,7 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 	ordlist=0;
 	temptrack=0;
 	buffer=0;
-	
+
 	if (!mpAllocSamples(m, m->sampnum)||!mpAllocModSamples(m, m->modsampnum))
 	{
 		retval=errAllocMem;
@@ -1046,7 +1047,8 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 
 	for (i=0; i<m->instnum; i++)
 	{
-/*		struct gmdinstrument *ip=&m->instruments[i];     NOT USED */
+/*
+		struct gmdinstrument *ip=&m->instruments[i];     NOT USED */
 		for (j=0; j<instsampnum[i]; j++)
 		{
 			m->modsamples[m->modsampnum++]=msmps[i][j];
@@ -1065,7 +1067,8 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 
 	for (i=0; i<m->instnum; i++)
 	{
-/*		struct gmdinstrument *ip=&m->instruments[i];  NOT USED */
+/*
+		struct gmdinstrument *ip=&m->instruments[i];  NOT USED */
 		if (shadowedby[i])
 		{
 			sampnum+=instsampnum[i];
@@ -1086,7 +1089,6 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 			uint8_t bitsel;
 			int8_t cursmp;
 
-		
 			if (!sip->length)
 				continue;
 
@@ -1108,7 +1110,7 @@ static int _mpLoadAMS(struct gmdmodule *m, FILE *file)
 			}
 			if (fread(packb, packlenb, 1, file) != 1)
 				fprintf(stderr, __FILE__ ": warning, read failed #33\n");
-			
+
 			p1=p2=0;
 
 			while (p2<packlena)
