@@ -79,7 +79,7 @@ static void readtree(void)
 	node=&huff[lastnode];
 	left=readbitsdmf(1);
 	right=readbitsdmf(1);
-	
+
 	lastnode=++nodenum;
 	if (left)
 	{
@@ -141,7 +141,7 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 		char composer[20];
 		char date[3];
 	} hdr;
-	
+
 	uint8_t sig[4];
 	uint32_t next;
 
@@ -154,7 +154,7 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 	uint8_t *patbuf = 0;
 	uint8_t **patadr = 0;
 	uint8_t (*temptrack)[3000] = 0;
-	
+
 	uint8_t *curadr;
 	uint_fast32_t i;
 
@@ -172,22 +172,11 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 
 	uint8_t smppack[256];
 
-	int safeout(int err)
-	{
-		if (orders)
-			free(orders);
-		if (patbuf)
-			free(patbuf);
-		if (patadr)
-			free(patadr);
-		if (temptrack)
-			free(temptrack);
-		return err;
-	}
+	int retval = 0;
 
 	mpReset(m);
 
-  	if (fread(&hdr, sizeof(hdr), 1, file) != 1)
+	if (fread(&hdr, sizeof(hdr), 1, file) != 1)
 		fprintf(stderr, __FILE__ ": warning, read failed #1\n");
 	if (memcmp(hdr.sig, "DDMF", 4))
 		return errFormSig;
@@ -224,7 +213,7 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 		char waste;
 		uint16_t msglen;
 		int16_t t;
-		int16_t i;	
+		int16_t i;
 		if (fread(&waste, 1, 1, file) != 1)
 			fprintf(stderr, __FILE__ ": warning, read failed #6\n");
 		msglen=(next-1)/40;
@@ -243,7 +232,7 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 				m->message[t]=*m->message+t*41;
 				if (fread(m->message[t], 40, 1, file) != 1)
 					fprintf(stderr, __FILE__ ": warning, read failed #7\n");
-        
+
 				for (i=0; i<40; i++)
 					if (!m->message[t][i])
 						m->message[t][i]=' ';
@@ -292,7 +281,10 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 	next = uint32_little (next);
 
 	if (memcmp(sig, "PATT", 4))
-		return safeout(errFormStruc);
+	{
+		retval = errFormStruc;
+		goto safeout;
+	}
 
 	if (fread(&patnum, sizeof(uint16_t), 1, file) != 1)
 		fprintf(stderr, __FILE__ ": warning, read failed #15\n");
@@ -305,7 +297,10 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 	patadr=malloc(sizeof(uint8_t *)*(patnum));
 	temptrack=malloc(sizeof(uint8_t)*(m->channum+1)*3000);
 	if (!patbuf||!patadr||!temptrack)
-		return safeout(errAllocMem);
+	{
+		retval = errAllocMem;
+		goto safeout;
+	}
 	if (fread(patbuf, next-3, 1, file) != 1)
 		fprintf(stderr, __FILE__ ": warning, read failed #17\n");
 
@@ -345,7 +340,10 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 	m->tracknum=ordnum*(m->channum+1);
 
 	if (!mpAllocTracks(m, m->tracknum)||!mpAllocPatterns(m, m->patnum)||!mpAllocOrders(m, m->ordnum))
-		return safeout(errAllocMem);
+	{
+		retval = errAllocMem;
+		goto safeout;
+	}
 
 	for (i=0; i<m->ordnum; i++)
 		m->orders[i]=i;
@@ -410,11 +408,8 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 				if (!pp)
 				{
 					fprintf(stderr, "playgmd: gmdldmf.c: pp not set\n");
-					free(orders);
-					free(patbuf);
-					free(patadr);
-					free(temptrack);
-					return safeout(errFormStruc);
+					retval = errFormStruc;
+					goto safeout;
 				}
 				info=*pp++;
 
@@ -634,7 +629,10 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 				trk->ptr=malloc(sizeof(uint8_t)*tlen);
 				trk->end=trk->ptr+tlen;
 				if (!trk->ptr)
-					return safeout(errAllocMem);
+				{
+					retval = errAllocMem;
+					goto safeout;
+				}
 				memcpy(trk->ptr, temptrack[j], tlen);
 			}
 		}
@@ -650,7 +648,10 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 			trk->ptr=malloc(sizeof(uint8_t)*tlen);
 			trk->end=trk->ptr+tlen;
 			if (!trk->ptr)
-				return safeout(errAllocMem);
+			{
+				retval = errAllocMem;
+				goto safeout;
+			}
 			memcpy(trk->ptr, temptrack[m->channum], tlen);
 		}
 	}
@@ -673,11 +674,11 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 
 	if (memcmp(sig, "SMPI", 4))
 		return errFormStruc;
-	
+
 	if (fread(&m->instnum, sizeof(uint8_t), 1, file) != 1)
 		fprintf(stderr, __FILE__ ": warning, read failed #19\n");
 	m->modsampnum=m->sampnum=m->instnum;
-	
+
 	if (!mpAllocInstruments(m, m->instnum)||!mpAllocSamples(m, m->sampnum)||!mpAllocModSamples(m, m->modsampnum))
 		return errAllocMem;
 
@@ -703,7 +704,6 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 
 		int j;
 
-		
 		if (fread(&namelen, sizeof(uint8_t), 1, file) != 1)
 			fprintf(stderr, __FILE__ ": warning, read failed #20\n");
 		if (namelen>31)
@@ -761,23 +761,24 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 
 	for (i=0; i<m->instnum; i++)
 	{
-/*		struct gmdinstrument *ip=&m->instruments[i];     NOT USED */
+/*
+		struct gmdinstrument *ip=&m->instruments[i];     NOT USED */
 		struct gmdsample *sp=&m->modsamples[i];
 		struct sampleinfo *sip=&m->samples[i];
 
 		uint32_t len;
-    		uint8_t *smpp;
-	
+		uint8_t *smpp;
+
 		if (fread(&len, sizeof(uint32_t), 1, file) != 1)
 			fprintf(stderr, __FILE__ ": warning, read failed #26\n");
 		len = uint32_little (len);
 
-	    	if (sp->handle==0xFFFF)
+		if (sp->handle==0xFFFF)
 		{
 			fseek(file, len, SEEK_CUR);
 			continue;
 		}
-		
+
 		smpp=malloc(sizeof(unsigned char)*len+4/* worst case padding */);
 		if (!smpp)
 			return errAllocMem;
@@ -795,11 +796,22 @@ static int _mpLoadDMF(struct gmdmodule *m, FILE *file)
 			free(smpp);
 			smpp=dbuf;
 		}
-		
+
 		sip->ptr=smpp;
 	}
 
 	return errOk;
+
+safeout:
+	if (orders)
+		free(orders);
+	if (patbuf)
+		free(patbuf);
+	if (patadr)
+		free(patadr);
+	if (temptrack)
+		free(temptrack);
+	return retval;
 }
 
 struct gmdloadstruct mpLoadDMF = { _mpLoadDMF };
