@@ -111,6 +111,32 @@ static inline void putcmd(unsigned char **p, unsigned char c, unsigned char d)
   *(*p)++=d;
 }
 
+struct LoadMDLResources
+{
+	struct gmdsample **msmps;
+	unsigned int *inssampnum;
+};
+
+static void FreeResources (struct LoadMDLResources *r)
+{
+	int j;
+	if (r->msmps)
+	{
+		for (j=0; j<255; j++)
+		{
+			if (r->msmps[j])
+				free(r->msmps[j]);
+		}
+		free(r->msmps);
+		r->msmps=0;
+	}
+	if (r->inssampnum)
+	{
+		free(r->inssampnum);
+		r->inssampnum=0;
+	}
+}
+
 static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 {
 	uint32_t waste1;
@@ -149,32 +175,13 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 	uint8_t packtype[255];
 
 	uint8_t inssav;
-	struct gmdsample **msmps = 0;
-	unsigned int *inssampnum = 0;
-	unsigned int maxins;
 	unsigned int smpnum;
 
-	void FreeResources(void)
-	{
-		int j;
-		if (msmps)
-		{
-			for (j=0; j<255; j++)
-			{
-				if (msmps[j])
-					free(msmps[j]);
-			}
-			free(msmps);
-			msmps=0;
-		}
-		if (inssampnum)
-		{
-			free(inssampnum);
-			inssampnum=0;
-		}
-	}
+	struct LoadMDLResources r;
+	r.msmps = 0;
+	r.inssampnum = 0;
 
-      	mpReset(m);
+	mpReset(m);
 
 	if (fread(&waste1, sizeof(uint32_t), 1, file)!=1)
 	{
@@ -399,7 +406,7 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 			uint8_t *trkptr=trackptrs[m->patterns[j].tracks[i]];
 			uint8_t *endptr=trackends[m->patterns[j].tracks[i]];
 			int row=0;
-			
+
 			while (trkptr<endptr)
 			{
 				uint8_t p=*trkptr++;
@@ -425,7 +432,7 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 				row++;
 			}
 		}
-		
+
 		for (i=0; i<m->channum; i++)
 			m->patterns[j].tracks[i]=j*(m->channum+1)+i;
 		m->patterns[j].gtrack=j*(m->channum+1)+m->channum;
@@ -437,7 +444,7 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 
 			struct gmdtrack *trk;
 			uint16_t len;
-			
+
 			int row;
 			for (row=0; row<m->patterns[j].patlen; row++, buf+=6)
 			{
@@ -470,13 +477,13 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 
 				if (!row&&(j==ordtab[0]))
 					putcmd(&cp, cmdPlayNote|cmdPlayPan, mdlhead.pan[i]*2);
-				
+
 				if (command1==0x8)
 					pan=data1*2;
-				
+
 				if (command2==0x8)
 					pan=data2*2;
-				
+
 				if ((command1==0x3)&&nte&&(nte!=255))
 					nte|=128;
 
@@ -513,7 +520,7 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 						*act|=cmdPlayDelay;
 						*cp++=data2;
 					}
-	
+
 					if (nte==255)
 						putcmd(&cp, cmdKeyOff, 0);
 				}
@@ -818,17 +825,15 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 	m->envnum=192;
 
 /*  envelope **envs=new envelope *[255]; */
-	msmps=calloc(sizeof(struct gmdsample *), 255);
-	inssampnum=calloc(sizeof(int), 255);
+	r.msmps=calloc(sizeof(struct gmdsample *), 255);
+	r.inssampnum=calloc(sizeof(int), 255);
 /*  int *insenvnum=new int [255]; */
-	if (/*!envs||!insenvnum||*/!inssampnum||!msmps||!mpAllocInstruments(m, m->instnum))
+	if (/*!envs||!insenvnum||*/!r.inssampnum||!r.msmps||!mpAllocInstruments(m, m->instnum))
 	{
-		FreeResources();
+		FreeResources(&r);
 		return errAllocMem;
 	}
 
-	maxins=0;
-
 /*  memset(envs, 0, 4*255); */
 /*  memset(insenvnum, 0, 4*255); */
 
@@ -838,40 +843,41 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 		struct gmdinstrument *ip;
 		int note;
 
-		
 		if (fread(&insnum, sizeof(uint8_t), 1, file) != 1)
 		{
 			fprintf(stderr, __FILE__ ": fread() failed #24\n");
-			FreeResources();
+			FreeResources(&r);
 			return errFormStruc;
 		}
 		insnum--;
-		
+
 		ip=&m->instruments[insnum];
 
-		if (fread(&inssampnum[j], sizeof(uint8_t), 1, file) != 1)
+		if (fread(&r.inssampnum[j], sizeof(uint8_t), 1, file) != 1)
 		{
 			fprintf(stderr, __FILE__ ": fread() failed #25\n");
-			FreeResources();
+			FreeResources(&r);
 			return errFormStruc;
 		}
 		if (fread(ip->name, 32, 1, file) != 1)
 		{
 			fprintf(stderr, __FILE__ ": fread() failed #26\n");
-			FreeResources();
+			FreeResources(&r);
 			return errFormStruc;
 		}
 		ip->name[31]=0;
-		msmps[j]=malloc(sizeof(struct gmdsample)*inssampnum[j]);
-/*    envs[insnum]=new envelope [inssampnum[j]]; */
-	    	if (!msmps[j]/*||!envs[insnum]*/)
+		r.msmps[j]=malloc(sizeof(struct gmdsample)*r.inssampnum[j]);
+/*
+		envs[insnum]=new envelope [r.inssampnum[j]];
+*/
+		if (!r.msmps[j]/*||!envs[insnum]*/)
 		{
-			FreeResources();
+			FreeResources(&r);
 			return errAllocMem;
 		}
 
 		note=0;
-		for (i=0; i<inssampnum[j]; i++)
+		for (i=0; i<r.inssampnum[j]; i++)
 		{
 			struct __attribute__((packed))
 			{
@@ -890,11 +896,11 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 				uint8_t pchenv;
 			} mdlmsmp;
 			struct gmdsample *sp;
-		
+
 			if (fread(&mdlmsmp, sizeof(mdlmsmp), 1, file) != 1)
 			{
 				fprintf(stderr, __FILE__ ": fread() failed #27\n");
-				FreeResources();
+				FreeResources(&r);
 				return errFormStruc;
 			}
 			mdlmsmp.fadeout = uint16_little (mdlmsmp.fadeout);
@@ -904,7 +910,7 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 				ip->samples[note++]=m->modsampnum;
 			m->modsampnum++;
 
-			sp=&msmps[j][i];
+			sp=&r.msmps[j][i];
 			*sp->name=0;
 			sp->handle=mdlmsmp.smp-1;
 			sp->normnote=0;
@@ -969,14 +975,14 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 	/*  int envnum=192; */
 	for (j=0; j<255; j++)
 	{
-		memcpy(m->modsamples+smpnum, msmps[j], sizeof (*m->modsamples)*inssampnum[j]);
-		smpnum+=inssampnum[j];
+		memcpy(m->modsamples+smpnum, r.msmps[j], sizeof (*m->modsamples)*r.inssampnum[j]);
+		smpnum+=r.inssampnum[j];
 /*!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  *    for (i=0; i<insenvnum[j]; i++)
  *      memcpy(&m.envelopes[envnum++], &envs[j][i], sizeof (*m.envelopes));*/
 /*    delete envs[j]; */
 	}
-	FreeResources();
+	FreeResources(&r);
 /*  delete envs;*/
 /*  delete insenvnum;*/
 
@@ -996,7 +1002,7 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 	if (blktype==0x4556)
 	{
 		uint8_t envnum;
-		
+
 		if (fread(&envnum, sizeof(uint8_t), 1, file) != 1)
 		{
 			fprintf(stderr, __FILE__ ": fread() failed #30\n");
@@ -1013,7 +1019,7 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 			} env;
 			struct gmdenvelope *e;
 			int k,l;
-		
+
 			if (fread(&env, sizeof(env), 1, file) != 1)
 			{
 				fprintf(stderr, __FILE__ ": fread() failed #31\n");
@@ -1177,7 +1183,7 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 
 			struct gmdenvelope *e;
 			int k,l;
-		
+
 			if (fread(&env, sizeof(env), 1, file) != 1)
 			{
 				fprintf(stderr, __FILE__ ": fread() failed #39\n");
@@ -1268,7 +1274,6 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 
 		struct sampleinfo *sip;
 
-		
 		if (fread(&mdlsmp, sizeof(mdlsmp), 1, file) != 1)
 		{
 			fprintf(stderr, __FILE__ ": fread() failed #43\n");
@@ -1335,7 +1340,7 @@ static int _mpLoadMDL(struct gmdmodule *m, FILE *file)
 		sip->ptr=malloc(sizeof(uint8_t)*((sip->length+8)<<bit16));
 		if (!sip->ptr)
 			return errAllocMem;
-				
+
 		if (packtype[i]==0)
 		{
 			if (fread(sip->ptr, sip->length<<bit16, 1, file) != 1)
