@@ -38,7 +38,7 @@
 
 static inline void putcmd(uint8_t **p, uint8_t c, uint8_t d)
 {
-      	*(*p)++=c;
+	*(*p)++=c;
 	*(*p)++=d;
 }
 
@@ -53,7 +53,7 @@ static int _mpLoadS3M(struct gmdmodule *m, FILE *file)
 	int16_t t2;
 	struct gmdpattern *pp;
 
-      	int bufsize;
+	int bufsize;
 	uint8_t *buffer;
 	uint8_t *temptrack;
 	char chanused[32];
@@ -127,7 +127,7 @@ static int _mpLoadS3M(struct gmdmodule *m, FILE *file)
 #endif
 	if (fread(orders, m->patnum, 1, file) != 1)
 		fprintf(stderr, __FILE__ ": warning, read failed #2\n");
-      	for (t=m->patnum-1; (signed)t>=0; t--)
+	for (t=m->patnum-1; (signed)t>=0; t--)
 	{
 		if (orders[t]<254)
 			break;
@@ -358,8 +358,10 @@ static int _mpLoadS3M(struct gmdmodule *m, FILE *file)
 		for (j=0; j<m->channum; j++)
 		{
 			char setorgpan=t==orders[0];
-/*			char setorgvwav=t==orders[0];
-			char setorgpwav=t==orders[0]; NOT USED */
+/*
+			char setorgvwav=t==orders[0];
+			char setorgpwav=t==orders[0]; NOT USED
+*/
 			int16_t row=0;
 
 			tp=temptrack;
@@ -606,7 +608,7 @@ static int _mpLoadS3M(struct gmdmodule *m, FILE *file)
 
 			trk=&m->tracks[t*(m->channum+1)+j];
 			len=tp-temptrack;
-			
+
 			if (!len)
 			{
 				trk->ptr=trk->end=0;
@@ -742,7 +744,8 @@ static int _mpLoadS3M(struct gmdmodule *m, FILE *file)
 
 	for (i=0; i<m->instnum; i++)
 	{
-/*		struct gmdinstrument *ip=&m->instruments[i];          NOT USED */
+/*
+		struct gmdinstrument *ip=&m->instruments[i];          NOT USED */
 		struct gmdsample *sp=&m->modsamples[i];
 		struct sampleinfo *sip=&m->samples[i];
 		int l;
