@@ -178,7 +178,7 @@ static void gmdDisplayIns132(unsigned short *buf, int n, int plInstMode)
 		} else if (plInstShowFreq==1)
 			writenum(buf, 90, col, mcpGetFreq8363(-sm->normnote), 10, 6, 1);
 		else
-		  	writenum(buf, 90, col, si->samprate, 10, 6, 1);
+			writenum(buf, 90, col, si->samprate, 10, 6, 1);
 
 		if (sm->stdvol!=-1)
 			writenum(buf, 98, col, sm->stdvol, 16, 2, 0);
@@ -313,9 +313,11 @@ void __attribute__ ((visibility ("internal"))) gmdInstSetup(const struct gmdinst
 
 	plInstShowFreq=type;
 	plInsDisplay.Clear=gmdInstClear;
-/*	plInsDisplay.n40=instnum;
+/*
+	plInsDisplay.n40=instnum;
 	plInsDisplay.n52=instnum;
-	plInsDisplay.n80=biginstlen;         TODO TODO TODO TODO TODO TODO */
+	plInsDisplay.n80=biginstlen;         TODO TODO TODO TODO TODO TODO
+*/
 	plInsDisplay.title80=plInstShowFreq?
 		" ##   instrument name / song message    length replen bit samprate vol pan  flgs":
 		" ##   instrument name / song message    length replen bit  base ft vol pan  flgs";
