@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
- 
+
 #include "config.h"
 #include <stdlib.h>
 #include <string.h>
@@ -27,6 +27,8 @@
 #include "types.h"
 #include "gmipat.h"
 
+static int i = 0;
+
 #if 0
 
 /*
@@ -38,7 +40,7 @@ static int ulaw_exp_table[] =
 	-32124,-31100,-30076,-29052,-28028,-27004,-25980,-24956,
 	-23932,-22908,-21884,-20860,-19836,-18812,-17788,-16764,
 	-15996,-15484,-14972,-14460,-13948,-13436,-12924,-12412,
-      	-11900,-11388,-10876,-10364, -9852, -9340, -8828, -8316,
+	-11900,-11388,-10876,-10364, -9852, -9340, -8828, -8316,
 	-7932, -7676, -7420, -7164, -6908, -6652, -6396, -6140,
 	-5884, -5628, -5372, -5116, -4860, -4604, -4348, -4092,
 	-3900, -3772, -3644, -3516, -3388, -3260, -3132, -3004,
@@ -211,7 +213,7 @@ void dump_patch(struct PATCHDATA *p)
 	fprintf(stderr, "Vibrato sweep: %d\n", p->vibrato_sweep);
 	fprintf(stderr, "Vibrato rate: %d\n", p->vibrato_rate);
 	fprintf(stderr, "Vibrato depth: %d\n", p->vibrato_depth);
-	fprintf(stderr, "Modes: \n");
+	fprintf(stderr, "Modes: (%d)\n", p->modes);
 	fprintf(stderr, "  %d-bit\n", (p->modes&1?16:8));
 	fprintf(stderr, "  %s\n", (p->modes&2?"Unsigned":"Signed"));
 	fprintf(stderr, "  Looping: %d\n", (p->modes&4?1:0));
@@ -309,6 +311,11 @@ int main(int argc, char *argv[])
 			dump_layer(&layer);
 			for (p=0;p<layer.samples;p++)
 			{
+				int fd;
+				char t[32];
+				snprintf(t, 32, "sample%03d.raw", i++);
+				fd = open(t, O_WRONLY | O_CREAT | O_TRUNC, S_IRUSR|S_IWUSR);
+
 				if (fread(&patch, sizeof(patch), 1, file)!=1)
 				{
 					perror("fread()");
@@ -323,7 +330,9 @@ int main(int argc, char *argv[])
 						perror("fread()");
 						return -1;
 					}
+					write (fd, &dummy, 1);
 				}
+				close (fd);
 			}
 		}
 	}
