@@ -44,7 +44,7 @@ static int ulaw_exp_table[] =
 	-32124,-31100,-30076,-29052,-28028,-27004,-25980,-24956,
 	-23932,-22908,-21884,-20860,-19836,-18812,-17788,-16764,
 	-15996,-15484,-14972,-14460,-13948,-13436,-12924,-12412,
-      	-11900,-11388,-10876,-10364, -9852, -9340, -8828, -8316,
+	-11900,-11388,-10876,-10364, -9852, -9340, -8828, -8316,
 	-7932, -7676, -7420, -7164, -6908, -6652, -6396, -6140,
 	-5884, -5628, -5372, -5116, -4860, -4604, -4348, -4092,
 	-3900, -3772, -3644, -3516, -3388, -3260, -3132, -3004,
@@ -108,7 +108,7 @@ struct __attribute__((packed)) FFF_ENVELOPE_POINT
 
 	union
 	{
-	       	uint16_t            rate;
+		uint16_t            rate;
 		uint16_t            time;
 	} data;
 };
@@ -279,7 +279,7 @@ static int loadFFF(FILE *file)
 {
 	struct FFF_CHUNK_HEADER  hd;
 	int                      i, j, matched;
-      	struct FFF_PTCH_LIST *l;
+	struct FFF_PTCH_LIST *l;
 
 	/* pass one: read the .FFF file */
 	if (fread(&hd, sizeof(hd), 1, file)!=1)
@@ -289,7 +289,7 @@ static int loadFFF(FILE *file)
 	}
 	FFF_CHUNK_HEADER_endian (&hd);
 
-      	if (memcmp(hd.id, "FFFF", 4))
+	if (memcmp(hd.id, "FFFF", 4))
 	{
 		fprintf(stderr, __FILE__ ": invalid header\n");
 		return 0;
@@ -307,7 +307,7 @@ static int loadFFF(FILE *file)
 		matched=0;
 
 #ifdef DEBUG
-	    	fprintf(stderr, "[FFF] got %c%c%c%c-chunk\n", hd.id[0], hd.id[1], hd.id[2], hd.id[3]);
+		fprintf(stderr, "[FFF] got %c%c%c%c-chunk\n", hd.id[0], hd.id[1], hd.id[2], hd.id[3]);
 #endif
 
 		if (!strncmp(hd.id, "ENVP", 4))
@@ -562,7 +562,7 @@ static int loadFFF(FILE *file)
 
 	/* pass 2: convert those IDs to pointers (yeeah) */
 
-      	l=ptch_list;
+	l=ptch_list;
 
 	while (l)
 	{
@@ -743,7 +743,9 @@ static int loadpatchFFF(struct minstrument *ins,
 	envelope[0]=(struct FFF_ENVP_CHUNK*)layer->penv.ptr;
 	envelope[1]=(struct FFF_ENVP_CHUNK*)layer->venv.ptr;
 
-/*	sprintf(ins->name, ".-.-.-", program); */
+/*
+	sprintf(ins->name, ".-.-.-", program);
+*/
 
 	if (program<128)
 		strcpy(ins->name, gmins_melo[program]);
@@ -831,7 +833,8 @@ static int loadpatchFFF(struct minstrument *ins,
 		/* todo: double check them again.
 		 * did it (and corrected 'em) (ryg)
 		 */
-/*		s->tremswp=(layer->tremolo.sweep-10)*2*64/45;
+/*
+		s->tremswp=(layer->tremolo.sweep-10)*2*64/45;
 		s->tremrte=((float)layer->tremolo.freq*7.0/3.0+15.0)*65536.0/(300.0*64.0);
 		s->tremdep=layer->tremolo.depth*19*4*256/255/2;
 
@@ -859,7 +862,9 @@ static int loadpatchFFF(struct minstrument *ins,
 		(*smps)[smp].type|=(wave->format&2)?0:mcpSampUnsigned;
 		(*smps)[smp].type|=(wave->format&8)?mcpSampLoop:0;
 		(*smps)[smp].type|=(wave->format&16)?mcpSampBiDi:0;
-/*		(*smps)[smp].type|=(wave->format&32)?mcpSampULaw:0; */
+/*
+		(*smps)[smp].type|=(wave->format&32)?mcpSampULaw:0;
+*/
 		(*smps)[smp].type|=(wave->format&32)?mcpSamp16Bit:0;
 
 		(*smps)[smp].ptr=calloc(wave->size*((wave->format&1)?1:2), ((wave->format&32)?2:1));
@@ -909,7 +914,7 @@ int __attribute__ ((visibility ("internal"))) midInitFFF(void)
 {
 	FILE *fff;
 	const char *fn=cfGetProfileString("midi", "fff", "midi.fff");
-      	char path[PATH_MAX+NAME_MAX+1];
+	char path[PATH_MAX+NAME_MAX+1];
 
 	_midClose=0;
 
