@@ -46,10 +46,12 @@ static void parse_config(FILE *input)
 	int type=0;
 	while (fgets(line, sizeof(line), input))
 	{
-/*		if ((pos=strchr(line, '\r')))
+/*
+		if ((pos=strchr(line, '\r')))
 			*pos=0;
 		if ((pos=strchr(line, '\n')))
-			*pos=0;*/
+			*pos=0;
+*/
 		if ((pos=strchr(line, '#')))
 			*pos=0;
 		base=line;
@@ -111,7 +113,7 @@ static int loadpatchFreePats( struct minstrument *ins,
                               struct sampleinfo **smps,
                               uint16_t           *samplenum)
 {
-      	FILE *file;
+	FILE *file;
 	int retval;
 	char path[PATH_MAX+NAME_MAX+1];
 
