@@ -65,7 +65,7 @@ static int16_t getnote(uint32_t frq)  /* frq=freq*1000, res=(oct*12+note)*256 (a
 	return x+i;
 }
 
-static 
+static
 int loadsamplePAT( FILE               *file,
                    struct minstrument *ins,
                    uint8_t             j,
@@ -144,15 +144,17 @@ int loadsamplePAT( FILE               *file,
 	sip->loopend=sh.end_loop;
 	sip->samprate=sh.sample_rate;
 	sip->type=((sh.modes&4)?(mcpSampLoop|((sh.modes&8)?mcpSampBiDi:0)):0)|(bit16?mcpSamp16Bit:0)|((sh.modes&2)?mcpSampUnsigned:0);
-/*	fprintf(stderr, "env: "); */
+	/* fprintf(stderr, "env: "); */
 	for (q=0; q<6; q++)
 	{
-/*		s->volrte[q]=((sh.envelope_rate[q]&63)<<(9-3*(sh.envelope_rate[q]>>6)))*1220*16/(64*vox)*2/3; */
+/*
+		s->volrte[q]=((sh.envelope_rate[q]&63)<<(9-3*(sh.envelope_rate[q]>>6)))*1220*16/(64*vox)*2/3; */
 		s->volrte[q]=((int)(((((int)sh.envelope_rate[q])&63)*11025))>>((int)3*((int)(sh.envelope_rate[q]>>6))))*14/(int)vox;
 		s->volpos[q]=((int)sh.envelope_offset[q])<<8;
-/*		if (q<s->end) fprintf(stderr, "%d:%d ", s->volrte[q], s->volpos[q]); */
+/*
+		if (q<s->end) fprintf(stderr, "%d:%d ", s->volrte[q], s->volpos[q]); */
 	}
-/*	fprintf(stderr, "\n"); */
+	/* fprintf(stderr, "\n"); */
 
 	s->end=(sh.modes&128)?3:6;
 	s->sustain=(sh.modes&32)?3:7;
@@ -163,7 +165,8 @@ int loadsamplePAT( FILE               *file,
 	s->tremrte=(((int)sh.tremolo_rate)*7+15)*65536/(300*64);
 	s->vibrte=(((int)sh.vibrato_rate)*7+15)*65536/(300*64);
 
-/*	fprintf(stderr, "   -> %d %d %d, %d %d %d\n", s->tremswp, s->tremrte, s->tremdep,
+/*
+	fprintf(stderr, "   -> %d %d %d, %d %d %d\n", s->tremswp, s->tremrte, s->tremdep,
 	                                              s->vibswp, s->vibrte, s->vibdep);
  */
 
@@ -190,9 +193,9 @@ loadpatchPAT( FILE               *file,
               struct sampleinfo **smps,
               uint16_t           *samplenum)
 {
-      	struct PATCHHEADER ph;
+	struct PATCHHEADER ph;
 	struct INSTRUMENTDATA ih;
-      	struct LAYERDATA lh;
+	struct LAYERDATA lh;
 	int i;
 	int cursamp=0;
 	uint8_t lowest;
@@ -322,7 +325,8 @@ addpatchPAT (FILE               *file,
 	{
 		int q;
 		uint8_t *smpp;
-/*		struct msample s=ins->samples[sn];  overkill */
+/*
+		struct msample s=ins->samples[sn];  overkill */
 
 		strcpy(s->name, "no sample");
 		s->handle=-1;
