@@ -42,7 +42,8 @@ static void drawchannel36(uint16_t *buf, int i)
 
 	unsigned char tcol=mute?0x08:0x0F;
 	unsigned char tcold=mute?0x08:0x07;
-/*	unsigned char tcolr=mute?0x08:0x0B;*/
+/*
+	unsigned char tcolr=mute?0x08:0x0B;*/
 
 	int j;
 
@@ -69,12 +70,13 @@ static void drawchannel62(uint16_t *buf, int i)
 
 	unsigned char tcol=mute?0x08:0x0F;
 	unsigned char tcold=mute?0x08:0x07;
-/*	unsigned char tcolr=mute?0x08:0x0B;*/
+/*
+	unsigned char tcolr=mute?0x08:0x0B;*/
 
 	int j;
 
 	midGetChanInfo(i, &ci);
-	
+
 	writestring(buf, 0, tcold, "                  -- -. \xfa\xfa\xfa \xfa\xfa\xfa \xfa\xfa\xfa \xfa\xfa\xfa \xfa\xfa\xfa \xfa\xfa\xfa \xfa\xfa\xfa \xfa\xfa\xfa \xfa\xfa\xfa ", 62);
 
 	if (!ci.notenum)
@@ -96,12 +98,13 @@ static void drawchannel76(uint16_t *buf, int i)
 
 	unsigned char tcol=mute?0x08:0x0F;
 	unsigned char tcold=mute?0x08:0x07;
-/*	unsigned char tcolr=mute?0x08:0x0B;*/
+/*
+	unsigned char tcolr=mute?0x08:0x0B;*/
 
 	int j;
 
 	midGetChanInfo(i, &ci);
-	
+
 	writestring(buf, 0, tcold, "               \xfa  \xfa \xfa \xfa\xfa\xfa \xfa\xfa  \xfa\xfa\xfa \xfa\xfa  \xfa\xfa\xfa \xfa\xfa  \xfa\xfa\xfa \xfa\xfa  \xfa\xfa\xfa \xfa\xfa  \xfa\xfa\xfa \xfa\xfa  \xfa\xfa\xfa \xfa\xfa", 76);
 
 	if (!ci.notenum)
@@ -125,7 +128,8 @@ static void drawchannel128(uint16_t *buf, int i)
 
 	unsigned char tcol=mute?0x08:0x0F;
 	unsigned char tcold=mute?0x08:0x07;
-/*	unsigned char tcolr=mute?0x08:0x0B;*/
+/*
+	unsigned char tcolr=mute?0x08:0x0B;*/
 
 	int j;
 
@@ -146,7 +150,7 @@ static void drawchannel128(uint16_t *buf, int i)
 	writenum(buf, 25, tcol, abs(ci.pitch), 16, 4, 0);
 	writenum(buf, 30, tcol, ci.reverb, 16, 2, 0);
 	writenum(buf, 33, tcol, ci.chorus, 16, 2, 0);
-  
+
 	if (ci.notenum>11)
 		ci.notenum=11;
 	for (j=0; j<ci.notenum; j++)
@@ -163,7 +167,8 @@ static void drawchannel44(uint16_t *buf, int i)
 
 	unsigned char tcol=mute?0x08:0x0F;
 	unsigned char tcold=mute?0x08:0x07;
-/*	unsigned char tcolr=mute?0x08:0x0B;*/
+/*
+	unsigned char tcolr=mute?0x08:0x0B;*/
 
 	int j;
 
@@ -180,7 +185,7 @@ static void drawchannel44(uint16_t *buf, int i)
 	writestring(buf,  8, tcol, " P"+(ci.pedal), 1);
 
 	if (ci.notenum>8)
-	    	ci.notenum=8;
+		ci.notenum=8;
 	for (j=0; j<ci.notenum; j++)
 		writestring(buf, 10+4*j, (ci.opt[j]&1)?tcol:0x08, plNoteStr[ci.note[j]+12], 3);
 }
