@@ -39,7 +39,7 @@ static const struct sampleinfo *plSamples;
 
 static void gmiDisplayIns40(uint16_t *buf, int n, int plInstMode)
 {
-       	char col=plInstMode?0x07:"\x08\x08\x0B\x0A"[plInstUsed[n]];
+	char col=plInstMode?0x07:"\x08\x08\x0B\x0A"[plInstUsed[n]];
 	writestring(buf, 0, col, (!plInstMode&&plInstUsed[n])?"\376##: ":" ##: ", 5);
 	writenum(buf, 1, col, plMInstr[n].prognum, 16, 2, 0);
 	writestring(buf, 5, col, plMInstr[n].name, 35);
@@ -57,7 +57,7 @@ static void gmiDisplayIns52(uint16_t *buf, int n, int plInstMode)
 {
 	int i,j;
 	char col;
-      	const struct minstrument *ins;
+	const struct minstrument *ins;
 	const struct msample *sm;
 
 	for (i=0; n>=plInstSampNum[i+1]; i++);
@@ -224,7 +224,8 @@ static void gmiMarkIns(void)
 		{
 			plInstUsed[ci.ins]=((plSelCh==i)||(plInstUsed[ci.ins]==3))?3:2;
 			for (j=0; j<ci.notenum; j++)
-/*				if (ci.opt[j]&1) */
+/*
+				if (ci.opt[j]&1) */
 					plSampUsed[plInstSampNum[ci.ins]+plMInstr[ci.ins].note[ci.note[j]]]=((plSelCh==i)||(plSampUsed[plInstSampNum[ci.ins]+plMInstr[ci.ins].note[ci.note[j]]]==3))?3:2;
 		}
 	}
@@ -255,9 +256,11 @@ void __attribute__ ((visibility ("internal"))) gmiInsSetup(const struct midifile
 	plInsDisplay.Clear=gmiClearInst;
 	plInsDisplay.height=plInstNum;
 	plInsDisplay.bigheight=plSampNum;
-/*	plInsDisplay.n40=plInstNum;
+/*
+	plInsDisplay.n40=plInstNum;
 	plInsDisplay.n52=plSampNum;
-	plInsDisplay.n80=plSampNum;*/
+	plInsDisplay.n80=plSampNum;
+*/
 	plInsDisplay.title80=plInsDisplay.title132=" ##   instrument name                       length replen bit  samprate  basenote    ";
 	plInsDisplay.Mark=gmiMarkIns;
 	plInsDisplay.Display=gmiDisplayIns;
