@@ -166,7 +166,7 @@ static inline uint8_t getlinvolg(uint16_t v)
 
 static uint16_t logvoltab[16]=
 {
-      	32768, 34219, 35734, 37316,
+	32768, 34219, 35734, 37316,
 	38968, 40693, 42495, 44376,
 	46341, 48393, 50535, 52773,
 	55109, 57549, 60097, 62757
@@ -284,7 +284,7 @@ static void noteoff(uint8_t chan, uint8_t note)
 {
 	struct mchandata *mc=&mchan[chan];
 	int i;
- 
+
 	if (note>=sizeof(instr[mc->ins].note))
 	{
 		fprintf(stderr, "[gmiplay] #2 note out of range: %d\n", note);
@@ -314,7 +314,7 @@ static void holdnotesoff(uint8_t chan)
 {
 	struct mchandata *mc=&mchan[chan];
 	int i;
-  
+
 	for (i=0; i<MAXCHANNOTE; i++)
 		if (mc->pch[i]!=0xFF && pchan[mc->pch[i]].hold)
 		{
@@ -333,7 +333,7 @@ static void setnotevol(uint8_t chan,
 {
 	struct mchandata *mc=&mchan[chan];
 	int i;
-	
+
 	for (i=0; i<MAXCHANNOTE; i++)
 		if (mc->note[i]==note)
 			break;
@@ -554,7 +554,8 @@ static void PlayTick(void)
 					stepover=1;
 				}
 			}
-/*			pc->resvol=(getlinvolg(pc->curvol)*(getlinvol((mc->vol[pc->notenum]-0x80)*8)>>8)*mc->gvol)>>14; */
+/*
+			pc->resvol=(getlinvolg(pc->curvol)*(getlinvol((mc->vol[pc->notenum]-0x80)*8)>>8)*mc->gvol)>>14; */
 			pc->resvol=(((uint32_t)getlinvolg(pc->curvol))*((int)mc->vol[pc->notenum])*((int)mc->gvol))>>14;
 			pc->resfrq=((int)mc->noteval[pc->notenum])+((((int)mc->pitch)*((int)mc->pitchsens))>>5);
 			if ((pc->epos+1)>=e->sustain)
