@@ -118,19 +118,20 @@ static void itDisplayIns80(uint16_t *buf, int n, int plInstMode)
 				writenum(buf, 60, col, si->samprate, 10, 6, 1);
 
 		writenum(buf, 68, col, sm->vol, 16, 2, 0);
-/*		if (ins->stdpan!=-1)
- *				writenum(buf, 72, col, ins->stdpan, 16, 2, 0);
- *			else
- *				writestring(buf, 72, col, " -", 2);
- *		if (ins->volenv!=0xFFFF)
- *			writestring(buf, 76, col, "v", 1);
- *		if (ins->panenv!=0xFFFF)
- *			writestring(buf, 77, col, "p", 1);
- *		if (ins->vibdepth&&sm.vibrate)
- *			writestring(buf, 78, col, "~", 1);
- *		if (ins->fadeout)
- *			writestring(buf, 79, col, "\x19", 1);
- */
+/*
+		if (ins->stdpan!=-1)
+				writenum(buf, 72, col, ins->stdpan, 16, 2, 0);
+			else
+				writestring(buf, 72, col, " -", 2);
+		if (ins->volenv!=0xFFFF)
+			writestring(buf, 76, col, "v", 1);
+		if (ins->panenv!=0xFFFF)
+			writestring(buf, 77, col, "p", 1);
+		if (ins->vibdepth&&sm.vibrate)
+			writestring(buf, 78, col, "~", 1);
+		if (ins->fadeout)
+			writestring(buf, 79, col, "\x19", 1);
+*/
 	}
 }
 
@@ -180,22 +181,23 @@ static void itDisplayIns132(uint16_t *buf, int n, int plInstMode)
 			writenum(buf, 90, col, si->samprate, 10, 6, 1);
 
 		writenum(buf, 98, col, sm->vol, 16, 2, 0);
-/*		if (ins->stdpan!=-1)
- *			writenum(buf, 102, col, ins->stdpan, 16, 2, 0);
- *		else
- *			writestring(buf, 102, col, " -", 2);
+/*
+		if (ins->stdpan!=-1)
+			writenum(buf, 102, col, ins->stdpan, 16, 2, 0);
+		else
+			writestring(buf, 102, col, " -", 2);
 
- *		if (ins->volenv!=0xFFFF)
- *			writestring(buf, 106, col, "v", 1);
- *		if (ins->panenv!=0xFFFF)
- *			writestring(buf, 107, col, "p", 1);
- *		if (ins->vibdepth&&ins->vibrate)
- *			writestring(buf, 108, col, "~", 1);
+		if (ins->volenv!=0xFFFF)
+			writestring(buf, 106, col, "v", 1);
+		if (ins->panenv!=0xFFFF)
+			writestring(buf, 107, col, "p", 1);
+		if (ins->vibdepth&&ins->vibrate)
+			writestring(buf, 108, col, "~", 1);
 
- *		if (ins->fadeout)
- *			writenum(buf, 110, col, ins->fadeout, 16, 4, 1);
- *		else
- *			writestring(buf, 113, col, "-", 1);
+		if (ins->fadeout)
+			writenum(buf, 110, col, ins->fadeout, 16, 4, 1);
+		else
+			writestring(buf, 113, col, "-", 1);
  */
 	}
 }
@@ -281,7 +283,7 @@ void __attribute__ ((visibility ("internal"))) itpInstSetup(const struct it_inst
 		return;
 
 	itpInstClear();
-	
+
 	Mark=MarkyBoy;
 
 	plInstr=ins;
@@ -332,9 +334,11 @@ void __attribute__ ((visibility ("internal"))) itpInstSetup(const struct it_inst
 
 	plInstShowFreq=type;
 	plInsDisplay.Clear=itpInstClear;
-/*	plInsDisplay.n40=instnum;
+/*
+	plInsDisplay.n40=instnum;
 	plInsDisplay.n52=instnum;
-	plInsDisplay.n80=biginstlen;*/
+	plInsDisplay.n80=biginstlen;
+*/
 	plInsDisplay.height=instnum;
 	plInsDisplay.bigheight=biginstlen;
 	plInsDisplay.title80=plInstShowFreq?
