@@ -19,7 +19,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
- 
+
 #include "config.h"
 #include <assert.h>
 #include <errno.h>
@@ -54,22 +54,22 @@ struct charset_t __attribute__ ((visibility ("internal"))) id3v2_charsets[MAX_CH
 {
 	{
 		strlen_8bit,
-/*		print_iso8859_1,*/
+		/* print_iso8859_1,*/
 		read_iso8859_1,
 		"ISO8859-1"
 	},{
 		strlen_16bit,
-/*		print_unicode,*/
+		/* print_unicode,*/
 		read_unicode,
 		"unicode/utf-16"
 	},{
 		strlen_16bit,
-/*		print_unicode_be,*/
+		/* print_unicode_be,*/
 		read_unicode_be,
 		"unicode_be/utf-16be"
 	},{
 		strlen_8bit,
-/*		print_utf8,*/
+		/* print_utf8,*/
 		read_utf8,
 		"utf-8"
 	}
@@ -231,7 +231,8 @@ static void print_unicode(uint8_t *src_, uint_fast32_t length)
 						tgsize=oldtgsize;
 						break;
 					}
-				/*	if (res==(size_t)(-1))
+				/*
+					if (res==(size_t)(-1))
 						perror("iconv()");*/
 				}
 				if ((res==(size_t)(-1))/*&&(errno==EILSEQ)*/)
@@ -295,7 +296,8 @@ static void print_unicode_be(uint8_t *src_, uint_fast32_t length)
 						tgsize=oldtgsize;
 						break;
 					}
-				/*	if (res==(size_t)(-1))
+				/*
+					if (res==(size_t)(-1))
 						perror("iconv()");*/
 				}
 				if ((res==(size_t)(-1))/*&&(errno==EILSEQ)*/)
@@ -358,7 +360,8 @@ static void print_utf8(uint8_t *src_, uint_fast32_t length)
 						tgsize=oldtgsize;
 						break;
 					}
-				/*	if (res==(size_t)(-1))
+				/*
+					if (res==(size_t)(-1))
 						perror("iconv()");*/
 				}
 				if ((res==(size_t)(-1))/*&&(errno==EILSEQ)*/)
@@ -604,6 +607,7 @@ static void detect_glibc_bug_4936(void)
 	srcsize = 2;
 	src = bom;
 	assert(iconv(fromunicode, &src, &srcsize, &dst, &dstsize)!=(size_t)(-1));
+	iconv(fromunicode, 0, 0, 0, 0);
 	srcsize = 2;
 	src = bom;
 	if (iconv(fromunicode, &src, &srcsize, &dst, &dstsize)==(size_t)(-1))
@@ -614,7 +618,7 @@ static void detect_glibc_bug_4936(void)
 	}
 }
 static void glibc_bug_4936_workaround(void)
-{	
+{
 	if (!glibc_bug_4936_detected)
 		return;
 	iconv_close(fromunicode);
@@ -633,7 +637,7 @@ void  __attribute__((constructor)) id3v2_charset_init(void)
 		TOCODE = strdup(temp);
 	else
 		TOCODE = strdup("CP437");
-	
+
         fromiso8859_1 = iconv_open(TOCODE, "ISO8859-1");
 	if (fromiso8859_1==(iconv_t)(-1))
 	{
