@@ -4,7 +4,9 @@
 struct charset_t
 {
 	uint_fast32_t (*strlen_with_term)(uint8_t *src, uint_fast32_t available_space, int require_term); /* return (uint_fast32_t)(-1) if termination is missing */
-/*	void (*print)(uint8_t *src, uint_fast32_t length);*/
+/*
+	void (*print)(uint8_t *src, uint_fast32_t length);
+*/
 	void (*readstring)(const uint8_t *source, uint_fast32_t sourcelength, char *target, int targetlength);
 	const char *name;
 };
