@@ -132,10 +132,10 @@ do { \
 static inline mad_fixed_t clip(mad_fixed_t sample)
 {
 	enum {
-  		MIN = -MAD_F_ONE,
+		MIN = -MAD_F_ONE,
 		MAX =  MAD_F_ONE - 1
 	};
-	
+
 	if (sample > MAX)
 		sample = MAX;
 	else if (sample < MIN)
@@ -150,7 +150,7 @@ static inline signed long audio_linear_round(unsigned int bits, mad_fixed_t samp
 
 	/* clip */
 	sample=clip(sample);
-	      
+
 	/* quantize and scale */
 	return sample >> (MAD_F_FRACBITS + 1 - bits);
 }
@@ -165,7 +165,7 @@ static void audio_pcm_s16(unsigned char *_data, unsigned int nsamples, mad_fixed
 	len = nsamples;
 	if (srnd)
 		xormask=0xffff;
-	
+
 	if (right) /* stereo */
 		while (len--)
 		{
@@ -218,7 +218,8 @@ static int stream_for_frame(void)
 
 	if (GuardPtr&&(stream.this_frame==GuardPtr))
 	{
-	/*	fprintf(stderr, "EOF-KNOCKING\n");*/
+	/*
+		fprintf(stderr, "EOF-KNOCKING\n");*/
 		return 0;
 	}
 	while(1)
@@ -254,8 +255,8 @@ static int stream_for_frame(void)
 						assert(MPEG_BUFSZ - data_length >= MAD_BUFFER_GUARD);
 						while (len < MAD_BUFFER_GUARD)
 							data[data_length + len++] = 0;
-	
-/*						fprintf(stderr, "Guard set len to %d\n", len);*/
+/*
+						fprintf(stderr, "Guard set len to %d\n", len);*/
 					} else {
 						eof=0;
 						datapos = newpos = 0;
@@ -263,7 +264,7 @@ static int stream_for_frame(void)
 						return 0;
 					}
 				}
-    			} else {
+			} else {
 				GuardPtr=0;
 				datapos += len;
 				newpos += len;
@@ -285,12 +286,14 @@ static int stream_for_frame(void)
 			}
 			if (!MAD_RECOVERABLE(stream.error))
 			{
-/*				fprintf(stderr, "!MAD_RECOVERABLE\n");*/
+/*
+				fprintf(stderr, "!MAD_RECOVERABLE\n");*/
 				return 0;
 			}
 			if (stream.error==MAD_ERROR_BADCRC)
 			{
-/*				fprintf(stderr, "Bad CRC\n");*/
+/*
+				fprintf(stderr, "Bad CRC\n");*/
 				mad_frame_mute(&frame);
 				continue;
 			} else if (stream.error==MAD_ERROR_LOSTSYNC)
@@ -304,9 +307,11 @@ static int stream_for_frame(void)
 					mad_stream_skip(&stream, tagsize);
 					continue;
 				}
-/*				fprintf(stderr, "MAD_ERROR_LOSTSYNC\n");*/
+/*
+				fprintf(stderr, "MAD_ERROR_LOSTSYNC\n");*/
 			}
-/*			fprintf(stderr, "error: %s\n", mad_stream_errorstr(&stream));*/
+/*
+			fprintf(stderr, "error: %s\n", mad_stream_errorstr(&stream));*/
 
 			continue;
 		}
@@ -341,7 +346,7 @@ static void mpegIdler(void)
 				break;
 		if (read>(data_in_synth<<2)) /* 16bit + stereo as always */
 			read=data_in_synth<<2;
-		
+
 		if ((mpegbufread+read)>mpegbuflen)
 			read=mpegbuflen-mpegbufread;
 		if (synth.pcm.channels==1)
@@ -363,7 +368,7 @@ void __attribute__ ((visibility ("internal"))) mpegIdle(void)
 
 	if (clipbusy++)
 	{
-	       	clipbusy--;
+		clipbusy--;
 		return;
 	}
 
@@ -390,7 +395,8 @@ void __attribute__ ((visibility ("internal"))) mpegIdle(void)
 	{           /* should not the crap below match up easy with imuldiv(mpeglen>>2, 65536, mpegbufrate) ??? TODO */
 		uint32_t towrap=imuldiv((((mpegbuflen+mpegbufread-mpegbufpos-1)%mpegbuflen)>>(1 /* we are always given stereo */ + 1 /* we are always given 16bit */)), 65536, mpegbufrate);
 		if (bufdelta>towrap)
-		{	/* will the eof hit inside the delta? */
+		{
+			/* will the eof hit inside the delta? */
 			if (eof) /* make sure we did hit eof, and just not out of data situasion due to streaming latency */
 			{
 				quietlen=bufdelta-towrap;
@@ -428,7 +434,7 @@ void __attribute__ ((visibility ("internal"))) mpegIdle(void)
 				wpm1=mpegbufpos-4; if (wpm1<0) wpm1+=mpegbuflen;
 				wp1=mpegbufpos+4; if (wp1>=mpegbuflen) wp1-=mpegbuflen;
 				wp2=mpegbufpos+8; if (wp2>=mpegbuflen) wp2-=mpegbuflen;
-				
+
 				c0 = *(uint16_t *)(mpegbuf+mpegbufpos)^0x8000;
 				vm1= *(uint16_t *)(mpegbuf+wpm1)^0x8000;
 				v1 = *(uint16_t *)(mpegbuf+wp1)^0x8000;
@@ -446,7 +452,7 @@ void __attribute__ ((visibility ("internal"))) mpegIdle(void)
 					ls=65535;
 				else if (ls<0)
 					ls=0;
-				
+
 				c0 = *(uint16_t *)(mpegbuf+mpegbufpos+2)^0x8000;
 				vm1= *(uint16_t *)(mpegbuf+wpm1+2)^0x8000;
 				v1 = *(uint16_t *)(mpegbuf+wp1+2)^0x8000;
@@ -466,7 +472,7 @@ void __attribute__ ((visibility ("internal"))) mpegIdle(void)
 					rs=0;
 				buf16[2*i]=(uint16_t)ls^0x8000;
 				buf16[2*i+1]=(uint16_t)rs^0x8000;
-				
+
 				mpegbuffpos+=mpegbufrate;
 				mpegbufpos+=(mpegbuffpos>>16)*4;
 				mpegbuffpos&=0xFFFF;
@@ -713,7 +719,7 @@ void __attribute__ ((visibility ("internal"))) mpegIdle(void)
 		if (bufpos>=buflen)
 			bufpos-=buflen;
 	}
-	
+
 	bufdelta=quietlen;
 	if (bufdelta)
 	{
@@ -751,10 +757,11 @@ unsigned char __attribute__ ((visibility ("internal"))) mpegOpenPlayer(FILE *mpe
 #if 0
 	unsigned char data[_MPEG_BUFSZ];
 	mad_timer_t timer;
-#endif	
+#endif
 	if (!(file=mpeg))
 		return 0;
-/*	if (fcntl(fileno(file), F_SETFD, FD_CLOEXEC))
+/*
+	if (fcntl(fileno(file), F_SETFD, FD_CLOEXEC))
 		perror("WARNING: mpplay.c: fcntl(file, FSET_FD, FD_CLOEXEC)");*/
 	ofs=offset;
 	fl=fsize;
@@ -804,7 +811,7 @@ unsigned char __attribute__ ((visibility ("internal"))) mpegOpenPlayer(FILE *mpe
 			{
 				if ((feof(file))||!target)
 					eof=1;
-    			} else {
+			} else {
 				GuardPtr=0;
 				datapos += len;
 			}
@@ -856,11 +863,11 @@ unsigned char __attribute__ ((visibility ("internal"))) mpegOpenPlayer(FILE *mpe
 	stream.buffer=0;
 	stream.this_frame=0;
 	fseek(file, 0, SEEK_SET);
-	
+
 	if (!stream_for_frame())
 		goto error_out;
 	mpegrate=synth.pcm.samplerate;
-	
+
 	plrSetOptions(mpegrate, (PLR_SIGNEDOUT|PLR_16BIT)|PLR_STEREO);
 
 	stereo=!!(plrOpt&PLR_STEREO);
@@ -877,7 +884,7 @@ unsigned char __attribute__ ((visibility ("internal"))) mpegOpenPlayer(FILE *mpe
 	mpegbuffpos=0;
 	mpegbufread=1<<(1/* stereo */+1 /*16bit*/);
 	GuardPtr=0;
-	
+
 	if (!plrOpenPlayer(&plrbuf, &buflen, plrBufSize))
 		goto error_out;
 
@@ -885,9 +892,9 @@ unsigned char __attribute__ ((visibility ("internal"))) mpegOpenPlayer(FILE *mpe
 	{
 		plrClosePlayer();
 		goto error_out;
-	}	
+	}
 	bufpos=0;
-	
+
 	if (!pollInit(mpegIdle))
 	{
 		free(buf16);
@@ -916,7 +923,7 @@ void __attribute__ ((visibility ("internal"))) mpegClosePlayer(void)
 	{
 		pollClose();
 		plrClosePlayer();
-		
+
 		mad_synth_finish(&synth);
 		mad_frame_finish(&frame);
 		mad_stream_finish(&stream);
@@ -937,7 +944,7 @@ void __attribute__ ((visibility ("internal"))) mpegClosePlayer(void)
 
 void __attribute__ ((visibility ("internal"))) mpegSetLoop(uint8_t s)
 {
-      	donotloop=!s;
+	donotloop=!s;
 }
 char __attribute__ ((visibility ("internal"))) mpegIsLooped(void)
 {
@@ -953,7 +960,7 @@ void __attribute__ ((visibility ("internal"))) mpegSetAmplify(uint32_t amp)
 }
 void __attribute__ ((visibility ("internal"))) mpegSetSpeed(uint16_t sp)
 {
-      	if (sp<32)
+	if (sp<32)
 		sp=32;
 	mpegbufrate=imuldiv(256*sp, mpegrate, plrRate);
 }
