@@ -23,6 +23,6 @@ extern void __attribute__ ((visibility ("internal"))) mpegSetSpeed(uint16_t sp);
 extern void __attribute__ ((visibility ("internal"))) mpegSetVolume(uint8_t vol, int8_t bal, int8_t pan, uint8_t opt);
 extern void __attribute__ ((visibility ("internal"))) mpegGetInfo(struct mpeginfo *);
 extern int32_t __attribute__ ((visibility ("internal"))) mpegGetPos(void);
-extern void __attribute__ ((visibility ("internal"))) mpegSetPos(int32_t pos);
+extern void __attribute__ ((visibility ("internal"))) mpegSetPos(uint32_t pos);
 
 #endif
