@@ -36,6 +36,13 @@
 #include "filesel/mdb.h"
 #include "charset.h"
 
+#ifdef ID3_DEBUG
+# define PRINT(fmt, args...) fprintf(stderr, fmt, ##args)
+#else
+# define PRINT(a, ...) do {} while(0)
+#endif
+
+
 #define VBRFRAMES      15
 
 static char *mpstyles[]=
@@ -70,7 +77,7 @@ static void handle_T__(const uint8_t *p, uint_fast32_t size, char *target, int t
 		}
 	}
 	temp_p[j++]=0;
-	fprintf(stderr, "handle_T__(*p=(charset=%d;data=\"%s\"), size=%d, target=%p, targetsize=%d\n", p[0], temp_p, size, target, targetsize);
+	PRINT ("handle_T__(*p=(charset=%d;data=\"%s\"), size=%d, target=%p, targetsize=%d\n", p[0], temp_p, size, target, targetsize);
 	free(temp_p);
 #endif
 	target[0]=0;
@@ -98,8 +105,8 @@ static void handle_T___(const uint8_t *p, uint_fast32_t size, char *target, int
 		}
 	}
 	temp_p[j++]=0;
-	fprintf(stderr, "handle_T___(*p=(charset=%d;data=\"%s\"), size=%d, target=%p, targetsize=%d) ", p[0], temp_p, size, target, targetsize);
-	fprintf(stderr, "forwarding to handle_T__\n");
+	PRINT("handle_T___(*p=(charset=%d;data=\"%s\"), size=%d, target=%p, targetsize=%d) ", p[0], temp_p, size, target, targetsize);
+	PRINT("forwarding to handle_T__\n");
 	free(temp_p);
 #endif
 	handle_T__(p, size, target, targetsize);
@@ -121,7 +128,7 @@ static void parseid3v1(struct moduleinfostruct *m, const unsigned char *tag)
 		}
 	}
 	temp_tag[j++]=0;
-	fprintf(stderr, "parseid3v1(m=%p, tag=%s) ", m, temp_tag);
+	PRINT("parseid3v1(m=%p, tag=%s) ", m, temp_tag);
 #endif
 	if (!memcmp(tag, "TAG", 3))
 	{
@@ -133,9 +140,7 @@ static void parseid3v1(struct moduleinfostruct *m, const unsigned char *tag)
 			m->modname[30]=0;
 			while (strlen(m->modname)&&(m->modname[strlen(m->modname)-1]==' '))
 				m->modname[strlen(m->modname)-1]=0;*/
-#ifdef ID3_DEBUG
-			fprintf(stderr, "m->modname=\"%s\"\n", m->modname);
-#endif
+			PRINT("m->modname=\"%s\"\n", m->modname);
 		}
 		if (memcmp(tag+33, "                              ", 30))
 		{
@@ -144,10 +149,8 @@ static void parseid3v1(struct moduleinfostruct *m, const unsigned char *tag)
 			/*memcpy(m->composer, tag+33, 30);
 			m->composer[30]=0;
 			while (strlen(m->composer)&&(m->composer[strlen(m->composer)-1]==' '))
-		      		m->composer[strlen(m->composer)-1]=0;*/
-#ifdef ID3_DEBUG
-			fprintf(stderr, "m->composer=\"%s\"\n", m->composer);
-#endif
+				m->composer[strlen(m->composer)-1]=0;*/
+			PRINT("m->composer=\"%s\"\n", m->composer);
 		}
 		if (memcmp(tag+63, "                              ", 30)||memcmp(tag+97, "                              ", 30))
 		{
@@ -158,17 +161,13 @@ static void parseid3v1(struct moduleinfostruct *m, const unsigned char *tag)
 			memcpy(m->comment+32, tag+97, 30);
 			m->comment[62]=0;
 			while (strlen(m->comment)&&(m->comment[strlen(m->comment)-1]==' '))
-		      		m->comment[strlen(m->comment)-1]=0;
-#ifdef ID3_DEBUG
-			fprintf(stderr, "m->comment=\"%s\"\n", m->comment);
-#endif
+				m->comment[strlen(m->comment)-1]=0;
+			PRINT("m->comment=\"%s\"\n", m->comment);
 		}
 		if (tag[127]<43)
 		{
 			strcpy(m->style, mpstyles[tag[127]]);
-#ifdef ID3_DEBUG
-			fprintf(stderr, "m->style=\"%s\"\n", m->style);
-#endif
+			PRINT("m->style=\"%s\"\n", m->style);
 		}
 		if (memcmp(tag+93, "    ", 4))
 		{
@@ -176,9 +175,7 @@ static void parseid3v1(struct moduleinfostruct *m, const unsigned char *tag)
 			memcpy(i, tag+93, 4);
 			i[4]=0;
 			m->date=atoi(i)<<16;
-#ifdef ID3_DEBUG
-			fprintf(stderr, "m->date=%d\n", m->date);
-#endif
+			PRINT("m->date=%d\n", m->date);
 		}
 	}
 }
@@ -187,14 +184,10 @@ static inline uint_fast32_t unsync(uint8_t *src, uint_fast32_t orgsize)
 {
 	uint_fast32_t retval = 0;
 	uint8_t *dst, *end = src+orgsize-1;
-#ifdef ID3_DEBUG
-	fprintf(stderr, "unsync(src=%p, orgsize=%d) =", src, orgsize);
-#endif
+	PRINT("unsync(src=%p, orgsize=%d) = ", src, orgsize);
 	if (!orgsize)
 	{
-#ifdef ID3_DEBUG
-		fprintf(stderr, "0\n");
-#endif
+		PRINT("0\n");
 		return 0;
 	}
 
@@ -211,74 +204,50 @@ static inline uint_fast32_t unsync(uint8_t *src, uint_fast32_t orgsize)
 	*(dst++)=*src;
 	retval++;
 
-#ifdef ID3_DEBUG
-	fprintf(stderr, "%d\n", retval);
-#endif
+	PRINT("%d\n", retval);
 	return retval;
 }
 
 static int parseid3v20(struct moduleinfostruct *m, const uint8_t *id3v2header, uint8_t *id3v2data, uint_fast32_t len)
 {
-#ifdef ID3_DEBUG
-	fprintf(stderr, "parseid3v20(m, id3v2header = %p (not used), id3v3data = %p, len = %d\n", id3v2header, id3v2data, len);
-#endif
+	PRINT("parseid3v20(m, id3v2header = %p (not used), id3v3data = %p, len = %d\n", id3v2header, id3v2data, len);
 	while (1)
 	{
 		uint_fast32_t size;
-#ifdef ID3_DEBUG
-		fprintf(stderr, "// parseid3v20, iterate, len = %d\n", len);
-#endif
+		PRINT("// parseid3v20, iterate, len = %d\n", len);
 		if (len<1)
 		{
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v20 len<1, return\n");
-#endif
+			PRINT("// parseid3v20 len<1, return\n");
 			return 1; /* out of data */
-	 	}
+		}
 		if (id3v2data[0]==0)
 		{
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v20 padding reached, return\n");
-#endif
+			PRINT("// parseid3v20 padding reached, return\n");
 			return 0; /* padding reached */
 		}
 		if (len<6)
 		{
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v20 len<6, return\n");
-#endif
+			PRINT("// parseid3v20 len<6, return\n");
 			return 1; /* out of data */
 		}
 		size = (id3v2data[3]<<16)|(id3v2data[4]<<8)|(id3v2data[5]);
-#ifdef ID3_DEBUG
-		fprintf(stderr, "// parseid3v20 size=%06x (computed from id3v2data[3]=%02x id3v2data[4]=%02x id3v2data[5]=%02x)\n", size, id3v2data[3], id3v2data[4], id3v2data[5]);
-#endif
+		PRINT("// parseid3v20 size=%06x (computed from id3v2data[3]=%02x id3v2data[4]=%02x id3v2data[5]=%02x)\n", size, id3v2data[3], id3v2data[4], id3v2data[5]);
 		if (len<(size+6))
 		{
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v20 len<(size+6), return\n");
-#endif
+			PRINT("// parseid3v20 len<(size+6), return\n");
 			return 1; /* out of data */
 		}
-#ifdef ID3_DEBUG
-		fprintf(stderr, "// parseid3v20 tag=\"%c%c%c\"\n", id3v2data[0], id3v2data[1], id3v2data[2]);
-#endif
+		PRINT("// parseid3v20 tag=\"%c%c%c\"\n", id3v2data[0], id3v2data[1], id3v2data[2]);
 		if (!memcmp(id3v2data, "TP1", 3))
 		{
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v20 store into m->composer (size=%d)\n", sizeof(m->composer));
-#endif
+			PRINT("// parseid3v20 store into m->composer (size=%d)\n", sizeof(m->composer));
 			handle_T__(id3v2data+6, size, m->composer, sizeof(m->composer));
 		} else if (!memcmp(id3v2data, "TT2", 3))
 		{
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v20 store into m->modname (size=%d)\n", sizeof(m->modname));
-#endif
+			PRINT("// parseid3v20 store into m->modname (size=%d)\n", sizeof(m->modname));
 			handle_T__(id3v2data+6, size, m->modname, sizeof(m->modname));
 		}
-#ifdef ID3_DEBUG
-		fprintf(stderr, "// parseid3v20 skipping 6+size into id3v2data/len\n");
-#endif
+		PRINT("// parseid3v20 skipping 6+size into id3v2data/len\n");
 		len-=(size+6);
 		id3v2data+=(size+6);
 	}
@@ -286,57 +255,39 @@ static int parseid3v20(struct moduleinfostruct *m, const uint8_t *id3v2header, u
 
 static int parseid3v23(struct moduleinfostruct *m, const uint8_t *id3v2header, uint8_t *id3v2data, uint_fast32_t len)
 {
-#ifdef ID3_DEBUG
-	fprintf(stderr, "parseid3v23(m, id3v2header = %p (not used), id3v3data = %p, len = %d\n", id3v2header, id3v2data, len);
-#endif
+	PRINT("parseid3v23(m, id3v2header = %p (not used), id3v3data = %p, len = %d\n", id3v2header, id3v2data, len);
 	while (1)
 	{
 		uint_fast32_t size;
 
-#ifdef ID3_DEBUG
-		fprintf(stderr, "// parseid3v23, iterate, len = %d\n", len);
-#endif
+		PRINT("// parseid3v23, iterate, len = %d\n", len);
 		if (len<1)
 		{
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v23 len<1, return\n");
-#endif
+			PRINT("// parseid3v23 len<1, return\n");
 			return 1; /* out of data */
-	 	}
+		}
 		if (id3v2data[0]==0)
 		{
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v23 padding reached, return\n");
-#endif
+			PRINT("// parseid3v23 padding reached, return\n");
 			return 0; /* padding reached */
 		}
 		if (len<10)
 		{
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v23 len<10, return\n");
-#endif
+			PRINT("// parseid3v23 len<10, return\n");
 			return 1; /* out of data */
 		}
 
 		size = (id3v2data[4]<<24)|(id3v2data[5]<<16)|(id3v2data[6]<<8)|(id3v2data[7]);
-#ifdef ID3_DEBUG
-		fprintf(stderr, "// parseid3v23 size=%08x (computed from id3v2data[4]=%02x id3v2data[5]=%02x id3v2data[6]=%02x id3v2data[7]=%02x)\n", size, id3v2data[4], id3v2data[5], id3v2data[6], id3v2data[7]);
-#endif
+		PRINT("// parseid3v23 size=%08x (computed from id3v2data[4]=%02x id3v2data[5]=%02x id3v2data[6]=%02x id3v2data[7]=%02x)\n", size, id3v2data[4], id3v2data[5], id3v2data[6], id3v2data[7]);
 		if (len<(size+10))
 		{
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v23 len<(size+10), return\n");
-#endif	
+			PRINT("// parseid3v23 len<(size+10), return\n");
 			return 1; /* out of data */
 		}
-#ifdef ID3_DEBUG
-		fprintf(stderr, "// parseid3v23 flags: id3v2data[8]=%02x id3v2data[9]=%02x\n", id3v2data[8], id3v2data[9]);
-#endif
+		PRINT("// parseid3v23 flags: id3v2data[8]=%02x id3v2data[9]=%02x\n", id3v2data[8], id3v2data[9]);
 		if ((id3v2data[8]&0x8f)||(id3v2data[9]&0xfc))
 		{ /* TODO, we now silently ignore entries with flags, so zlib compressed tag-pages will fail */
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v23 unsupported flag detected (like zlib compression etc.)\n");
-#endif
+			PRINT("// parseid3v23 unsupported flag detected (like zlib compression etc.)\n");
 		} else {
 			int offset=10;
 			uint_fast32_t _size = size;
@@ -344,42 +295,30 @@ static int parseid3v23(struct moduleinfostruct *m, const uint8_t *id3v2header, u
 			if (id3v2data[9]&0x02)
 			{
 				_size = unsync(id3v2data+offset, size);
-#ifdef ID3_DEBUG
-				fprintf(stderr, "// parseid3v23 unsync bit set, size updated to %d\n", size);
-#endif
+				PRINT("// parseid3v23 unsync bit set, size updated to %d\n", size);
 			}
 			if (id3v2data[9]&0x01)
 			{
-#ifdef ID3_DEBUG
-				fprintf(stderr, "// parseid3v23 size-validation check, ignoring, skipping 4 bytes\n");
-#endif
+				PRINT("// parseid3v23 size-validation check, ignoring, skipping 4 bytes\n");
 				offset+=4; /* we ignore the size-validation check here */
 				if (_size < 4)
 					_size = 0;
 				else
 					_size -= 4;
 			}
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v23 tag=\"%c%c%c%c\"\n", id3v2data[0], id3v2data[1], id3v2data[2], id3v2data[3]);
-#endif
-	
+			PRINT("// parseid3v23 tag=\"%c%c%c%c\"\n", id3v2data[0], id3v2data[1], id3v2data[2], id3v2data[3]);
+
 			if (!memcmp(id3v2data, "TPE1", 4))
 			{
-#ifdef ID3_DEBUG
-				fprintf(stderr, "// parseid3v23 storing into m->composer\n");
-#endif
+				PRINT("// parseid3v23 storing into m->composer\n");
 				handle_T___(id3v2data+offset, _size, m->composer, sizeof(m->composer));
 			} else if (!memcmp(id3v2data, "TIT2", 4))
 			{
-#ifdef ID3_DEBUG
-				fprintf(stderr, "// parseid3v23 storing into m->modname\n");
-#endif
+				PRINT("// parseid3v23 storing into m->modname\n");
 				handle_T___(id3v2data+offset, _size, m->modname, sizeof(m->modname));
 			}
 		}
-#ifdef ID3_DEBUG
-		fprintf(stderr, "// parseid3v23 skipping 10+size into id3v2data/len\n");
-#endif
+		PRINT("// parseid3v23 skipping 10+size into id3v2data/len\n");
 		len-=(size+10);
 		id3v2data+=(size+10);
 	}
@@ -389,31 +328,23 @@ static int parseid3v23(struct moduleinfostruct *m, const uint8_t *id3v2header, u
 /* returns 1 on ok */
 static int parseid3v2(struct moduleinfostruct *m, const uint8_t *id3v2header, uint8_t *id3v2data, uint_fast32_t len)
 {
-#ifdef ID3_DEBUG
-	fprintf(stderr, "parseid3v2(m, id3v2header = %p, id3v3data = %p, len = %d\n", id3v2header, id3v2data, len);
-	fprintf(stderr, "// parseid3v2 tag version 2.%d\n", id3v2header[3]);
-#endif
+	PRINT("parseid3v2(m, id3v2header = %p, id3v3data = %p, len = %d\n", id3v2header, id3v2data, len);
+	PRINT("// parseid3v2 tag version 2.%d\n", id3v2header[3]);
 
 	if ((id3v2header[5]&0x80))
 	{
 		len = unsync(id3v2data, len);
-#ifdef ID3_DEBUG
-		fprintf(stderr, "// parseid3v2 global unsync bit set, new len = %d\n", len);
-#endif
+		PRINT("// parseid3v2 global unsync bit set, new len = %d\n", len);
 	}
 	/*fprintf(stderr, "Version 2.%d\n", id3v2header[3]);*/
 	if (id3v2header[3]<4)
 	{
 		if (id3v2header[5]&0x40)
 		{
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v2 TAG version lower than 2.4, and extended tag flaged, trying to skip it (len is fixed to 10 bytes)\n");
-#endif
+			PRINT("// parseid3v2 TAG version lower than 2.4, and extended tag flaged, trying to skip it (len is fixed to 10 bytes)\n");
 			if (len<10)
 			{
-#ifdef ID3_DEBUG
-				fprintf(stderr, "// parseid3v2 to little data to skip, return \n");
-#endif
+				PRINT("// parseid3v2 to little data to skip, return \n");
 				return 1; /* failed to parse */
 			}
 			len-=10;
@@ -423,26 +354,18 @@ static int parseid3v2(struct moduleinfostruct *m, const uint8_t *id3v2header, ui
 		if (id3v2header[5]&0x40)
 		{
 			uint_fast32_t esize;
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v2 TAG version greater or equal to 2.4, and extended tag flaged, trying  to skip it\n");
-#endif
+			PRINT("// parseid3v2 TAG version greater or equal to 2.4, and extended tag flaged, trying  to skip it\n");
 			/*fprintf(stderr, "Removing extended header\n");*/
 			if (len<6)
 			{
-#ifdef ID3_DEBUG
-				fprintf(stderr, "// parseid3v2 to little data available to calculate extended header length (len<6), return\n");
-#endif
+				PRINT("// parseid3v2 to little data available to calculate extended header length (len<6), return\n");
 				return 1; /* failed to parse */
 			}
 			esize = (id3v2data[0]<<21)|(id3v2data[1]<<14)|(id3v2data[2]<<7)|(id3v2data[3]);
-#ifdef ID3_DEBUG
-			fprintf(stderr, "// parseid3v2 extended header size=%08x, calculated from id3v2data[0]=%02x, id3v2data[1]=%02x, id3v2data[2]=%02x, id3v2data=%02x\n", esize, id3v2data[0], id3v2data[1], id3v2data[2], id3v2data[3]);
-#endif
+			PRINT("// parseid3v2 extended header size=%08x, calculated from id3v2data[0]=%02x, id3v2data[1]=%02x, id3v2data[2]=%02x, id3v2data=%02x\n", esize, id3v2data[0], id3v2data[1], id3v2data[2], id3v2data[3]);
 			if (len<esize)
 			{
-#ifdef ID3_DEBUG
-				fprintf(stderr, "// parseid3v2 skipping extended header failed, to little data available (len<size), return\n");
-#endif
+				PRINT("// parseid3v2 skipping extended header failed, to little data available (len<size), return\n");
 				return 1; /* failed to parse */
 			}
 			len-=esize;
@@ -450,9 +373,7 @@ static int parseid3v2(struct moduleinfostruct *m, const uint8_t *id3v2header, ui
 		}
 	}
 
-#ifdef ID3_DEBUG
-	fprintf(stderr, "// parseid3v2, calling sub-parser based on version\n");
-#endif
+	PRINT("// parseid3v2, calling sub-parser based on version\n");
 	if (id3v2header[3]<=2)
 		return parseid3v20(m, id3v2header, id3v2data, len);
 	else
@@ -766,7 +687,7 @@ static int ampegpReadInfo(struct moduleinfostruct *m, FILE *f, const char *buf,
 	int ver;
 	int rateidx;
 	int frqidx;
-	int stereo;
+	/* int stereo; */
 	int rate;
 	/*int gottag = 0;*/
 
@@ -937,7 +858,7 @@ static int ampegpReadInfo(struct moduleinfostruct *m, FILE *f, const char *buf,
 		return 0;
 	rateidx=(hdr>>20)&15;
 	frqidx=(hdr>>18)&3;
-	stereo="\x01\x01\x02\x00"[(hdr>>30)&3];
+	/* stereo="\x01\x01\x02\x00"[(hdr>>30)&3]; */
 	if (frqidx==3)
 		return 0;
 	if (!ver)
