@@ -196,7 +196,7 @@ void __attribute__ ((visibility ("internal"))) oggIdle(void)
 
 	if (clipbusy++)
 	{
-	       	clipbusy--;
+		clipbusy--;
 		return;
 	}
 
@@ -640,7 +640,8 @@ void __attribute__ ((visibility ("internal"))) oggIdle(void)
 
 void __attribute__ ((visibility ("internal"))) oggSetAmplify(uint32_t amp)
 {
-/*       	amplify=amp;
+/*
+	amplify=amp;
 	float v[9];
 	float ampf=(float)vols[9]*(amplify/65536.0)/65536.0;
 	int i;
@@ -715,7 +716,8 @@ int __attribute__ ((visibility ("internal"))) oggOpenPlayer(FILE *oggf)
 	pan=64;
 	srnd=0;
 	oggSetVolume(64, 0, 64, 0);
-/*	oggSetAmplify(amplify);   TODO */
+/*
+	oggSetAmplify(amplify);   TODO */
 
 	buf16=malloc(sizeof(uint16_t)*buflen*2);
 	if (!buf16)
@@ -738,7 +740,7 @@ int __attribute__ ((visibility ("internal"))) oggOpenPlayer(FILE *oggf)
 
 void __attribute__ ((visibility ("internal"))) oggClosePlayer(void)
 {
-      	active=0;
+	active=0;
 
 	pollClose();
 
@@ -754,22 +756,22 @@ void __attribute__ ((visibility ("internal"))) oggClosePlayer(void)
 
 char __attribute__ ((visibility ("internal"))) oggLooped(void)
 {
-      	return looped;
+	return looped;
 }
 
 void __attribute__ ((visibility ("internal"))) oggSetLoop(uint8_t s)
 {
-      	donotloop=!s;
+	donotloop=!s;
 }
 
 void __attribute__ ((visibility ("internal"))) oggPause(uint8_t p)
 {
-      	inpause=p;
+	inpause=p;
 }
 
 void __attribute__ ((visibility ("internal"))) oggSetSpeed(uint16_t sp)
 {
-      	if (sp<32)
+	if (sp<32)
 		sp=32;
 	oggbufrate=imuldiv(256*sp, oggrate, samprate);
 }
@@ -787,7 +789,7 @@ void __attribute__ ((visibility ("internal"))) oggSetVolume(uint8_t vol_, int8_t
 
 uint32_t __attribute__ ((visibility ("internal"))) oggGetPos(void)
 {
-      	if (ogglen==oggbuflen)
+	if (ogglen==oggbuflen)
 		return oggbufpos>>(oggstereo+1);
 	else
 		return ((oggpos+ogglen-oggbuflen+((oggbufpos-oggbufread+oggbuflen)%oggbuflen))%ogglen)>>(oggstereo+1);
@@ -796,7 +798,7 @@ uint32_t __attribute__ ((visibility ("internal"))) oggGetPos(void)
 void __attribute__ ((visibility ("internal"))) oggGetInfo(struct ogginfo *i)
 {
 	static int lastsafe=0;
-      	i->pos=oggGetPos();
+	i->pos=oggGetPos();
 	i->len=ogglen>>(oggstereo+1);
 	i->rate=oggrate;
 	i->stereo=oggstereo;
@@ -810,7 +812,7 @@ void __attribute__ ((visibility ("internal"))) oggGetInfo(struct ogginfo *i)
 
 void __attribute__ ((visibility ("internal"))) oggSetPos(uint32_t pos)
 {
-      	pos=((pos<<(1+oggstereo))+ogglen)%ogglen;
+	pos=((pos<<(1+oggstereo))+ogglen)%ogglen;
 	if (ogglen==oggbuflen)
 		oggbufpos=pos;
 	else
