@@ -36,6 +36,7 @@ extern "C"
 #include "boot/plinkman.h"
 #include "boot/psetting.h"
 #include "stuff/compat.h"
+#include "stuff/err.h"
 #include "stuff/poutput.h"
 #include "stuff/sets.h"
 #include "stuff/timer.h"
@@ -144,7 +145,7 @@ static void drawvolbar(uint16_t *buf, int, unsigned char st)
 	l=ci.vol;
 	r=ci.vol;
 	logvolbar(l, r);
-	
+
 	l=(l+4)>>3;
 	r=(r+4)>>3;
 	if (plPause)
@@ -186,16 +187,16 @@ static void drawlongvolbar(uint16_t *buf, int, unsigned char st)
 
 static void oplDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 {
-      	long tim;
+	long tim;
 
-       	mcpDrawGStrings(buf);
+	mcpDrawGStrings(buf);
 
 	if (plPause)
 		tim=(pausetime-starttime)/DOS_CLK_TCK;
 	else
 		tim=(dos_clock()-starttime)/DOS_CLK_TCK;
 
-      	if (plScrWidth<128)
+	if (plScrWidth<128)
 	{
 		writestring(buf[1],  0, 0x09, " song .. of .. title: .......................... cpu:...% ",58);
 
@@ -210,7 +211,8 @@ static void oplDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 		if (globinfo.author[0])
 			writestring(buf[2], 27, 0x0F, globinfo.author, 39);
 
-/*		writestring(buf[2],  6, 0x0F, currentmodname, _MAX_FNAME);
+/*
+		writestring(buf[2],  6, 0x0F, currentmodname, _MAX_FNAME);
 		writestring(buf[2], 14, 0x0F, currentmodext, _MAX_EXT);*/
 		if (plPause)
 			writestring(buf[2], 60, 0x0C, "paused", 6);
@@ -229,7 +231,8 @@ static void oplDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 			writestring(buf[1], 25, 0x0F, globinfo.title, 57);
 
 		writestring(buf[2],  0, 0x09, "    file \372\372\372\372\372\372\372\372.\372\372\372 author: ...................................................................                    time: ..:..   ", 132);
-/*		writestring(buf[2],  9, 0x0F, currentmodname, _MAX_FNAME);
+/*
+		writestring(buf[2],  9, 0x0F, currentmodname, _MAX_FNAME);
 		writestring(buf[2], 17, 0x0F, currentmodext, _MAX_EXT);*/
 		if (globinfo.author[0])
 			writestring(buf[2], 30, 0x0F, globinfo.author, 67);
@@ -262,7 +265,7 @@ static void drawchannel(uint16_t *buf, int len, int i) /* TODO */
 			break;
 		case 128:
 			writestring(buf, 0, tcold, "                   \263        \263       \263       \263                \263               \263   \372\372\372\372\372\372\372\372\372\372\372\372\372\372\372\372 \372\372\372\372\372\372\372\372\372\372\372\372\372\372\372\372", 128);
-			break;                                                                      
+			break;
 		case 76:
 			writestring(buf, 0, tcold, "                  \263      \263     \263     \263     \263             \263 \372\372\372\372\372\372\372\372 \372\372\372\372\372\372\372\372", 76);
 			break;
@@ -293,7 +296,8 @@ static void drawchannel(uint16_t *buf, int len, int i) /* TODO */
 		case 36:
 			writestring(buf+1, 0, tcol, waves4[ci.wave], 4);
 			writestring(buf+6, 0, tcol, nchar, 3);
-/*			writenum(buf+10, 0, tcol, ci.pulse>>4, 16, 2, 0);
+/*
+			writenum(buf+10, 0, tcol, ci.pulse>>4, 16, 2, 0);
 			if (ci.filtenabled && ftype)
 				writenum(buf+13, 0, tcol, ftype, 16, 1, 0);
 			if (efx)
@@ -302,10 +306,12 @@ static void drawchannel(uint16_t *buf, int len, int i) /* TODO */
 			break;
 		case 44:
 			writestring(buf+1, 0, tcol, waves4[ci.wave], 4);
-/*			writenum(buf+6, 0, tcol, ci.ad, 16, 2, 0);
+/*
+			writenum(buf+6, 0, tcol, ci.ad, 16, 2, 0);
 			writenum(buf+8, 0, tcol, ci.sr, 16, 2, 0);*/
 			writestring(buf+11, 0, tcol, nchar, 3);
-/*			writenum(buf+15, 0, tcol, ci.pulse>>4, 16, 2, 0);
+/*
+			writenum(buf+15, 0, tcol, ci.pulse>>4, 16, 2, 0);
 			if (ci.filtenabled && ftype)
 				writestring(buf+18, 0, tcol, filters3[ftype], 3);
 			if (efx)
@@ -314,10 +320,12 @@ static void drawchannel(uint16_t *buf, int len, int i) /* TODO */
 			break;
 		case 62:
 			writestring(buf+1, 0, tcol, waves16[ci.wave], 16);
-/*			writenum(buf+18, 0, tcol, ci.ad, 16, 2, 0);
+/*
+			writenum(buf+18, 0, tcol, ci.ad, 16, 2, 0);
 			writenum(buf+20, 0, tcol, ci.sr, 16, 2, 0);*/
 			writestring(buf+23, 0, tcol, nchar, 3);
-/*			writenum(buf+27, 0, tcol, ci.pulse, 16, 3, 0);
+/*
+			writenum(buf+27, 0, tcol, ci.pulse, 16, 3, 0);
 			if (ci.filtenabled && ftype)
 				writestring(buf+31, 0, tcol, filters3[ftype], 3);
 			if (efx)
@@ -326,10 +334,12 @@ static void drawchannel(uint16_t *buf, int len, int i) /* TODO */
 			break;
 		case 76:
 			writestring(buf+1, 0, tcol, waves16[ci.wave], 16);
-/*			writenum(buf+20, 0, tcol, ci.ad, 16, 2, 0);
+/*
+			writenum(buf+20, 0, tcol, ci.ad, 16, 2, 0);
 			writenum(buf+22, 0, tcol, ci.sr, 16, 2, 0);*/
 			writestring(buf+27, 0, tcol, nchar, 3);
-/*			writenum(buf+33, 0, tcol, ci.pulse, 16, 3, 0);
+/*
+			writenum(buf+33, 0, tcol, ci.pulse, 16, 3, 0);
 			if (ci.filtenabled && ftype)
 				writestring(buf+39, 0, tcol, filters3[ftype], 3);
 			writestring(buf+45, 0, tcol, fx11[efx], 11);*/
@@ -337,16 +347,18 @@ static void drawchannel(uint16_t *buf, int len, int i) /* TODO */
 			break;
 		case 128:
 			writestring(buf+1, 0, tcol, waves16[ci.wave], 16);
-/*			writenum(buf+22, 0, tcol, ci.ad, 16, 2, 0);
+/*
+			writenum(buf+22, 0, tcol, ci.ad, 16, 2, 0);
 			writenum(buf+24, 0, tcol, ci.sr, 16, 2, 0);*/
 			writestring(buf+31, 0, tcol, nchar, 3);
-/*			writenum(buf+39, 0, tcol, ci.pulse, 16, 3, 0);
+/*
+			writenum(buf+39, 0, tcol, ci.pulse, 16, 3, 0);
 			if (ci.filtenabled && ftype)
 				writestring(buf+47, 0, tcol, filters12[ftype], 12);
 			writestring(buf+64, 0, tcol, fx11[efx], 11);*/
 			drawlongvolbar(buf+81, i, st);
 			break;
-	}			
+	}
 }
 
 
@@ -369,6 +381,7 @@ static int oplProcessKey(uint16_t key)
 			startpausefade();
 			break;
 		case KEY_CTRL_P:
+			pausefadedirect=0;
 			if (plPause)
 				starttime=starttime+dos_clock()-pausetime;
 			else
@@ -453,7 +466,7 @@ static int oplOpenFile(const char *path, struct moduleinfostruct *info, FILE *fi
 	int fd;
 
 	_splitpath(path, NULL, NULL, NULL, ext);
-	
+
 	while (1)
 	{
 		snprintf(_path, sizeof(_path), "%splayOPLtemp%08d%s", cfTempDir, n++, ext);
@@ -479,7 +492,7 @@ static int oplOpenFile(const char *path, struct moduleinfostruct *info, FILE *fi
 		}
 	}
 	close(fd);
-		
+
 	fprintf(stderr, "loading %s via %s...\n", path, _path);
 
 	plIsEnd=oplLooped;
@@ -487,16 +500,18 @@ static int oplOpenFile(const char *path, struct moduleinfostruct *info, FILE *fi
 	plDrawGStrings=oplDrawGStrings;
 	plGetMasterSample=plrGetMasterSample;
 	plGetRealMasterVolume=plrGetRealMasterVolume;
-	
+
 	if (!oplOpenPlayer(_path))
 	{
 		unlink(_path);
 		return -1;
 	}
 	unlink(_path);
-	
+
 	starttime=dos_clock();
+	plPause=0;
 	normalize();
+	pausefadedirect=0;
 
 	plNLChan=plNPChan=18;
 	plUseChannels(drawchannel);
@@ -504,7 +519,7 @@ static int oplOpenFile(const char *path, struct moduleinfostruct *info, FILE *fi
 
 	oplpGetGlobInfo(globinfo);
 
-	return 0;
+	return errOk;
 }
 
 extern "C"
