@@ -85,17 +85,17 @@ static volatile int clipbusy=0;
 
 static void calccliptab(int32_t ampl, int32_t ampr)
 {
-      	clipbusy++;
-	
+	clipbusy++;
+
 	if (!stereo)
 	{
 		ampl=(abs(ampl)+abs(ampr))>>1;
 		ampr=0;
 	}
-	
+
 	mixCalcClipTab(cliptabl, abs(ampl));
 	mixCalcClipTab(cliptabr, abs(ampr));
-	
+
 	int i;
 	if (signedout)
 		for (i=0; i<256; i++)
@@ -103,7 +103,7 @@ static void calccliptab(int32_t ampl, int32_t ampr)
 			cliptabl[i+512]^=0x8000;
 			cliptabr[i+512]^=0x8000;
 		}
-	
+
 	clipbusy--;
 }
 
@@ -112,14 +112,16 @@ static void calccliptab(int32_t ampl, int32_t ampr)
 
 static void timerproc()
 {
-      	if (clipbusy)
+	if (clipbusy++)
+	{
+		clipbusy--;
 		return;
-	clipbusy++;
-	
+	}
+
 	uint32_t bufplayed=plrGetBufPos()>>(stereo+bit16);
 	uint32_t bufdelta;
 	uint32_t pass2;
-	
+
 	if (bufplayed==bufpos)
 	{
 		clipbusy--;
@@ -129,19 +131,19 @@ static void timerproc()
 	}
 	int quietlen=0;
 	bufdelta=(buflen+bufplayed-bufpos)%buflen;
-	
+
 	if (inpause)
 		quietlen=bufdelta;
-	
+
 	bufdelta-=quietlen;
-	
+
 	if (bufdelta)
 	{
 		if ((bufpos+bufdelta)>buflen)
 			pass2=bufpos+bufdelta-buflen;
 		else
 			pass2=0;
-		
+
 		plrClearBuf(buf16, bufdelta*2, 1);
 
     //sidplay nach buf16
@@ -151,7 +153,7 @@ static void timerproc()
 		if (stereo && srnd)
 			for (uint32_t i=0; i<bufdelta; i++)
 				buf16[2*i]^=0xFFFF;
-		
+
 		if (bit16)
 		{
 			if (stereo)
@@ -183,7 +185,7 @@ static void timerproc()
 		if (bufpos>=buflen)
 			bufpos-=buflen;
 	}
-	
+
 	bufdelta=quietlen;
 	if (bufdelta)
 	{
@@ -206,7 +208,7 @@ static void timerproc()
 		if (bufpos>=buflen)
 			bufpos-=buflen;
 	}
-	
+
 	plrAdvanceTo(bufpos<<(stereo+bit16));
 
 	if (plrIdle)
@@ -218,7 +220,7 @@ static void timerproc()
 
 static void updateconf()
 {
-      	clipbusy++;
+	clipbusy++;
 	myEmuEngine->setConfig(*myEmuConfig);
 	clipbusy--;
 }
@@ -226,12 +228,12 @@ static void updateconf()
 
 void __attribute__ ((visibility ("internal"))) sidpIdle(void)
 {
-      	timerproc();
+	timerproc();
 }
 
 unsigned char __attribute__ ((visibility ("internal"))) sidpOpenPlayer(FILE *f)
 {
-      	if (!plrPlay)
+	if (!plrPlay)
 		return 0;
 
 	fseek(f, 0, SEEK_END);
@@ -245,10 +247,10 @@ unsigned char __attribute__ ((visibility ("internal"))) sidpOpenPlayer(FILE *f)
 	}
 	mySidTune = new sidTune(buf, length);
 	delete [] buf;
-	
+
 	cliptabl=new unsigned short[1793];
 	cliptabr=new unsigned short[1793];
-	
+
 	if (!cliptabl||!cliptabr)
 	{
 		delete[] cliptabl;
@@ -270,7 +272,7 @@ unsigned char __attribute__ ((visibility ("internal"))) sidpOpenPlayer(FILE *f)
 		delete myEmuConfig;
 		return 0;
 	}
-	
+
 	int playrate=cfGetProfileInt("commandline_s", "r", cfGetProfileInt2(cfSoundSec, "sound", "mixrate", 44100, 10), 10);
 	if (playrate<66)
 	{
@@ -279,29 +281,29 @@ unsigned char __attribute__ ((visibility ("internal"))) sidpOpenPlayer(FILE *f)
 		else
 			playrate=playrate*11025/11;
 	}
-	
+
 	plrSetOptions(playrate, PLR_STEREO|PLR_16BIT);
 	if (!plrOpenPlayer(&plrbuf, &buflen, plrBufSize))
 		return 0;
-	
+
 	stereo=!!(plrOpt&PLR_STEREO);
 	bit16=!!(plrOpt&PLR_16BIT);
 	signedout=!!(plrOpt&PLR_SIGNEDOUT);
 	reversestereo=!!(plrOpt&PLR_REVERSESTEREO);
 	samprate=plrRate;
 	srnd=0;
-	
+
 	myEmuEngine->getConfig(*myEmuConfig);
-	
+
 	myEmuConfig->frequency=samprate;
 	myEmuConfig->bitsPerSample=SIDEMU_16BIT;
 	myEmuConfig->sampleFormat=SIDEMU_UNSIGNED_PCM;
 	myEmuConfig->channels=stereo?SIDEMU_STEREO:SIDEMU_MONO;
 	myEmuConfig->sidChips=1;
-	
+
 	myEmuConfig->volumeControl=SIDEMU_FULLPANNING;
 	myEmuConfig->autoPanning=SIDEMU_CENTEREDAUTOPANNING;
-	
+
 	myEmuConfig->mos8580=0;
 	myEmuConfig->measuredVolume=0;
 	myEmuConfig->emulateFilter=1;
@@ -314,17 +316,17 @@ unsigned char __attribute__ ((visibility ("internal"))) sidpOpenPlayer(FILE *f)
 	myEmuConfig->digiPlayerScans=10;
 
 	myEmuEngine->setConfig(*myEmuConfig);
-	
+
 	memset(sidpmute,0,4);
-	
+
 	inpause=0;
 	amplify=65536;
 	voll=256;
 	volr=256;
 	calccliptab((amplify*voll)>>8, (amplify*volr)>>8);
-	
+
 	buf16=new uint16_t [buflen*2];
-	
+
 	if (!buf16)
 	{
 		plrClosePlayer();
@@ -336,14 +338,14 @@ unsigned char __attribute__ ((visibility ("internal"))) sidpOpenPlayer(FILE *f)
 		delete myEmuConfig;
 		return 0;
 	}
-	
+
 	bufpos=0;
-	
+
 	mySidTune->getInfo(*mySidTuneInfo);
 	sidEmuInitializeSong(*myEmuEngine,*mySidTune,mySidTuneInfo->startSong);
 	sidEmuFastForwardReplay(100);
 	mySidTune->getInfo(*mySidTuneInfo);
-	
+
 	// construct song message
 	{
 		int i,j;
@@ -362,26 +364,26 @@ unsigned char __attribute__ ((visibility ("internal"))) sidpOpenPlayer(FILE *f)
 			msg[i++]=(char*)(mySidTuneInfo->speedString);
 		plUseMessage(msg);
 	}
-	
+
 	if (!pollInit(timerproc))
 	{
 		plrClosePlayer();
 		return 0;
 	}
-	
+
 	active=1;
-	
+
 	return 1;
 }
 
 void __attribute__ ((visibility ("internal"))) sidpClosePlayer(void)
 {
-      	active=0;
-	
+	active=0;
+
 	pollClose();
-	
+
 	plrClosePlayer();
-	
+
 	delete myEmuEngine;
 	delete myEmuConfig;
 	delete mySidTune;
@@ -395,18 +397,18 @@ void __attribute__ ((visibility ("internal"))) sidpClosePlayer(void)
 
 void __attribute__ ((visibility ("internal"))) sidpPause(unsigned char p)
 {
-      	inpause=p;
+	inpause=p;
 }
 
 void __attribute__ ((visibility ("internal"))) sidpSetAmplify(unsigned long amp)
 {
-      	amplify=amp;
+	amplify=amp;
 	calccliptab((amplify*voll)>>8, (amplify*volr)>>8);
 }
 
 void __attribute__ ((visibility ("internal"))) sidpSetVolume(unsigned char vol, signed char bal, signed char pan, unsigned char opt)
 {
-      	pan=pan;
+	pan=pan;
 	voll=vol*4;
 	volr=vol*4;
 	if (bal<0)
@@ -419,12 +421,12 @@ void __attribute__ ((visibility ("internal"))) sidpSetVolume(unsigned char vol,
 
 void __attribute__ ((visibility ("internal"))) sidpGetGlobInfo(sidTuneInfo &si)
 {
-      	mySidTune->getInfo(si);
+	mySidTune->getInfo(si);
 }
 
 void __attribute__ ((visibility ("internal"))) sidpStartSong(char sng)
 {
-      	if (sng<1)
+	if (sng<1)
 		sng=1;
 	if (sng>mySidTuneInfo->songs)
 		sng=mySidTuneInfo->songs;
@@ -439,45 +441,45 @@ void __attribute__ ((visibility ("internal"))) sidpStartSong(char sng)
 
 void __attribute__ ((visibility ("internal"))) sidpToggleVideo(void)
 {
-      	int &cs=myEmuConfig->clockSpeed;
+	int &cs=myEmuConfig->clockSpeed;
 	cs=(cs==SIDTUNE_CLOCK_PAL)?SIDTUNE_CLOCK_NTSC:SIDTUNE_CLOCK_PAL;
 	updateconf();
 }
 
 char __attribute__ ((visibility ("internal"))) sidpGetVideo(void)
 {
-      	int &cs=myEmuConfig->clockSpeed;
+	int &cs=myEmuConfig->clockSpeed;
 	return (cs==SIDTUNE_CLOCK_PAL);
 }
 
 char __attribute__ ((visibility ("internal"))) sidpGetFilter(void)
 {
-      	return myEmuConfig->emulateFilter;
+	return myEmuConfig->emulateFilter;
 }
 
 
 void __attribute__ ((visibility ("internal"))) sidpToggleFilter(void)
 {
-      	myEmuConfig->emulateFilter^=1;
+	myEmuConfig->emulateFilter^=1;
 	updateconf();
 }
 
 
 char __attribute__ ((visibility ("internal"))) sidpGetSIDVersion(void)
 {
-      	return myEmuConfig->mos8580;
+	return myEmuConfig->mos8580;
 }
 
 
 void __attribute__ ((visibility ("internal"))) sidpToggleSIDVersion(void)
 {
-      	myEmuConfig->mos8580^=1;
+	myEmuConfig->mos8580^=1;
 	updateconf();
 }
 
 void __attribute__ ((visibility ("internal"))) sidpMute(int i, int m)
 {
-      	sidpmute[i]=m;
+	sidpmute[i]=m;
 }
 
 
@@ -485,7 +487,7 @@ void __attribute__ ((visibility ("internal"))) sidpMute(int i, int m)
 
 void __attribute__ ((visibility ("internal"))) sidpGetChanInfo(int i, sidChanInfo &ci)
 {
-      	sidOperator ch;
+	sidOperator ch;
 	switch (i)
 	{
 		case 0: ch=optr1; break;
@@ -552,7 +554,7 @@ void __attribute__ ((visibility ("internal"))) sidpGetChanInfo(int i, sidChanInf
 
 void __attribute__ ((visibility ("internal"))) sidpGetDigiInfo(sidDigiInfo &di)
 {
-      	short vv=abs(v4outl)>>7;
+	short vv=abs(v4outl)>>7;
 	if (vv>di.l)
 		di.l=vv;
 	else
