@@ -74,13 +74,13 @@ static sidDigiInfo di;
 
 static void sidpDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 {
-      	long tim;
+	long tim;
 	if (plPause)
 		tim=(pausetime-starttime)/DOS_CLK_TCK;
 	else
 		tim=(dos_clock()-starttime)/DOS_CLK_TCK;
 
-      	if (plScrWidth<128)
+	if (plScrWidth<128)
 	{
 		memset(buf[0]+80, 0, (plScrWidth-80)*sizeof(uint16_t));
 		memset(buf[1]+80, 0, (plScrWidth-80)*sizeof(uint16_t));
@@ -274,7 +274,9 @@ static void drawchannel(uint16_t *buf, int len, int i)
 
 	unsigned char tcol=st?0x08:0x0F;
 	unsigned char tcold=st?0x08:0x07;
-/*	unsigned char tcolr=st?0x08:0x0B;  unused */
+/*
+	unsigned char tcolr=st?0x08:0x0B;  unused
+*/
 
 	if (i<3)
 	{
@@ -288,7 +290,7 @@ static void drawchannel(uint16_t *buf, int len, int i)
 				break;
 			case 128:
 				writestring(buf, 0, tcold, "                   \263        \263       \263       \263                \263               \263   \372\372\372\372\372\372\372\372\372\372\372\372\372\372\372\372 \372\372\372\372\372\372\372\372\372\372\372\372\372\372\372\372", 128);
-				break;                                                                      
+				break;
 			case 76:
 				writestring(buf, 0, tcold, "                  \263      \263     \263     \263     \263             \263 \372\372\372\372\372\372\372\372 \372\372\372\372\372\372\372\372", 76);
 				break;
@@ -298,7 +300,7 @@ static void drawchannel(uint16_t *buf, int len, int i)
 		}
 
 		sidpGetChanInfo(i,ci);
-	    	if (!ci.leftvol && !ci.rightvol)
+		if (!ci.leftvol && !ci.rightvol)
 			return;
 		uint8_t nte=convnote(ci.freq);
 		char nchar[4];
@@ -385,7 +387,7 @@ static void drawchannel(uint16_t *buf, int len, int i)
 				break;
 			case 128:
 				writestring(buf, 0, tcold, " pcm samples or galway noises                                                \263   \372\372\372\372\372\372\372\372\372\372\372\372\372\372\372\372 \372\372\372\372\372\372\372\372\372\372\372\372\372\372\372\372", 128);
-				break;                                                                      
+				break;
 			case 76:
 				writestring(buf, 0, tcold, " pcm samples or galway noises                            \263 \372\372\372\372\372\372\372\372 \372\372\372\372\372\372\372\372", 76);
 				break;
@@ -415,7 +417,7 @@ static void drawchannel(uint16_t *buf, int len, int i)
 			case 128:
 				drawlongvolbar(buf+81, i, st);
 				break;
-		}	
+		}
 	}
 }
 
@@ -487,7 +489,7 @@ static int sidpProcessKey(uint16_t key)
 		case KEY_CTRL_DOWN:
 		/* case 0x9100: //ctrl-down */
 			break;
-#endif			
+#endif
 		case '<':
 		case KEY_CTRL_LEFT:
 		/* case 0x7300: //ctrl-left */
@@ -510,7 +512,7 @@ static int sidpProcessKey(uint16_t key)
 			}
 			sidpGetGlobInfo(globinfo);
 			break;
-/*		case 0x7700: //ctrl-home TODO KEYS
+		/* case 0x7700: //ctrl-home TODO KEYS
 			sidpStartSong(globinfo.currentSong);
 			starttime=dos_clock();
 			sidpGetGlobInfo(globinfo);
@@ -641,10 +643,10 @@ static int sidpProcessKey(uint16_t key)
 
 static int sidLooped()
 {
-  sidpIdle();
-  if (plrIdle)
-    plrIdle();
-  return 0;
+	sidpIdle();
+	if (plrIdle)
+		plrIdle();
+	return 0;
 }
 
 static int sidpOpenFile(const char *path, struct moduleinfostruct *info, FILE *sidf)
