@@ -21,6 +21,6 @@ extern void __attribute__ ((visibility ("internal"))) wpSetSpeed(uint16_t sp);
 extern void __attribute__ ((visibility ("internal"))) wpSetVolume(unsigned char vol, signed char bal, signed char pan, unsigned char opt);
 extern void __attribute__ ((visibility ("internal"))) wpGetInfo(struct waveinfo *);
 extern uint32_t __attribute__ ((visibility ("internal"))) wpGetPos(void);
-extern void __attribute__ ((visibility ("internal"))) wpSetPos(int32_t pos);
+extern void __attribute__ ((visibility ("internal"))) wpSetPos(uint32_t pos);
 
 #endif
