@@ -37,12 +37,17 @@
 #include "stuff/imsrtns.h"
 #include "stuff/poll.h"
 
+#ifdef WAVE_DEBUG
+# define PRINT(fmt, args...) fprintf(stderr, "%s %s: " fmt, __FILE__, __func__, ##args)
+#else
+# define PRINT(a, ...) do {} while(0)
+#endif
+
 static uint8_t stereo;
 static uint8_t bit16;
 static uint8_t signedout;
 static uint32_t samprate;
 static uint8_t reversestereo;
-
 static uint16_t *buf16=0;
 static uint32_t bufpos;
 static uint32_t buflen;
@@ -82,7 +87,8 @@ static uint32_t bufloopat;
 
 static int pause;
 
-static int clipbusy=0;
+static volatile int clipbusy=0;
+static volatile int readbusy=0;
 
 #ifdef WAVE_DEBUG
 static const char *compression_code_str(uint_fast16_t code)
@@ -192,64 +198,75 @@ do { \
 
 static void timerproc(void)
 {
-	uint32_t bufplayed;
-	uint32_t bufdelta;
-	uint32_t pass2;
-	int quietlen;
-	uint32_t toloop;
+	uint_fast32_t bufplayed;
+	uint_fast32_t bufdelta;
+	uint_fast32_t pass2;
+	uint_fast32_t quietlen = 0;
+	uint_fast32_t toloop;
 
 	if (clipbusy++)
 	{
 		clipbusy--;
 		return;
 	}
-	
+
 	bufplayed=plrGetBufPos()>>(stereo+bit16);
+	/* if (bufplayed == bufpos), there is no more room for data. This is a special case */
 	if (bufplayed==bufpos)
 	{
+		//PRINT ("%s %s: devp buffer was full, so no write performed\n", __FILE__, __FUNCTION__);
 		clipbusy--;
 		if (plrIdle)
 			plrIdle();
 		return;
 	}
+	/* fill up wave file buffer */
 	wpIdle();
-	
+
 	quietlen=0;
 	bufdelta=(buflen+bufplayed-bufpos)%buflen;
+
 	if (wavebuflen!=wavelen)
 	{
-		uint32_t towrap=(unsigned)imuldiv((((wavebuflen+wavebufread-wavebufpos-1)%wavebuflen)>>(wavestereo+wave16bit)), 65536, wavebufrate);
+		uint_fast32_t towrap=(unsigned)imuldiv((((wavebuflen+wavebufread-wavebufpos-1)%wavebuflen)>>(wavestereo+wave16bit)), 65536, wavebufrate);
 		if (bufdelta>towrap)
-			/*quietlen=bufdelta-towrap;*/
+		{
+			PRINT ("We were going to read past the end of the wavebuffer, bufdelta shrunk from %d to %d\n", bufdelta, towrap);
 			bufdelta=towrap;
+		}
 	}
 
 	if (pause)
-		quietlen=bufdelta;
-
-	toloop=(unsigned)imuldiv(((bufloopat-wavebufpos)>>(wave16bit+wavestereo)), 65536, wavebufrate);
-	if (looped)
-		toloop=0;
-
-	bufdelta-=quietlen;
-
-	if (bufdelta>=toloop)
 	{
-		looped=1;
-		if (donotloop)
+		quietlen=bufdelta;
+	}
+
+	/* when pitching low, the wave file can appear to be VERY long in samples, cauding overflow, thereby we first need this check */
+	if ((wavebufpos + imuldiv(bufdelta, wavebufrate, 65536) + 2) > bufloopat)
+	{
+		toloop=(unsigned)imuldiv(((bufloopat-wavebufpos)>>(wave16bit+wavestereo)), 65536, wavebufrate);
+		if (looped)
+			toloop=0;
+
+		if (bufdelta>=toloop)
 		{
-			quietlen+=bufdelta-toloop;
-			bufdelta=toloop;
+			looped=1;
+			if (donotloop)
+				bufdelta=toloop;
 		}
 	}
 
 	if (bufdelta)
 	{
 		unsigned int i;
+
 		if ((bufpos+bufdelta)>buflen)
 			pass2=bufpos+bufdelta-buflen;
 		else
 			pass2=0;
+
+		//PRINT ("bufdelta=0x%04x pass2=0x%04x wavebufpos=0x%08x\n", bufdelta, pass2, wavebufpos);
+
 		plrClearBuf(buf16, bufdelta*2, 1);
 
 		if (wave16bit)
@@ -425,9 +442,9 @@ static void timerproc(void)
 		if (bufpos>=buflen)
 			bufpos-=buflen;
 	}
-	
+
 	plrAdvanceTo(bufpos<<(stereo+bit16));
-	
+
 	if (plrIdle)
 		plrIdle();
 
@@ -439,11 +456,22 @@ void __attribute__ ((visibility ("internal"))) wpIdle(void)
 	uint32_t bufplayed=plrGetBufPos()>>(stereo+bit16);
 	uint32_t bufdelta=(buflen+bufplayed-bufpos)%buflen;
 	uint32_t clean;
+
 	if (bufdelta>(buflen>>3))
 		timerproc();
 
-	if ((wavelen==wavebuflen)||!active)
+	if (readbusy++)
+	{
+		PRINT ("readbusy kicked us out\n");
+		readbusy--;
 		return;
+	}
+
+	if ((wavelen==wavebuflen)||!active)
+	{
+		readbusy--;
+		return;
+	}
 
 	clean=(wavebufpos+wavebuflen-wavebufread)%wavebuflen;
 	if (clean*8>wavebuflen)
@@ -463,6 +491,7 @@ void __attribute__ ((visibility ("internal"))) wpIdle(void)
 			}
 			if (read>0x10000)
 				read=0x10000;
+			PRINT ("fread %d\n", read);
 			result=fread(wavebuf+wavebufread, 1, read, rawwave);
 			if (result<=0)
 				break;
@@ -471,6 +500,8 @@ void __attribute__ ((visibility ("internal"))) wpIdle(void)
 			clean-=result;
 		}
 	}
+
+	readbusy--;
 }
 
 uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int tostereo, int tolerance)
@@ -478,7 +509,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 	uint32_t temp;
 	uint32_t fmtlen;
 	uint16_t sh;
-	
+
 	if (!plrPlay)
 		return 0;
 
@@ -503,9 +534,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 		fprintf(stderr, __FILE__ ": fread failed #1\n");
 		return 0;
 	}
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": comparing header for RIFF: 0x%08x 0x%08x\n", temp, uint32_little(0x46464952));
-#endif
+	PRINT("comparing header for RIFF: 0x%08x 0x%08x\n", temp, uint32_little(0x46464952));
 	if (temp!=uint32_little(0x46464952))
 		return 0;
 
@@ -514,24 +543,19 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 		fprintf(stderr, __FILE__ ": fread failed #2\n");
 		return 0;
 	}
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": ignoring next 32bit: 0x%08x\n", temp);
-#endif
+	PRINT("ignoring next 32bit: 0x%08x\n", temp);
 
 	if (fread(&temp, sizeof(temp), 1, wavefile) != 1)
 	{
 		fprintf(stderr, __FILE__ ": fread failed #3\n");
 		return 0;
 	}
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": comparing next header for WAVE: 0x%08x 0x%08x\n", temp, uint32_little(0x45564157));
-#endif
+	PRINT("comparing next header for WAVE: 0x%08x 0x%08x\n", temp, uint32_little(0x45564157));
+
 	if (temp!=uint32_little(0x45564157))
 		return 0;
 
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": going to locate \"fmt \" header\n");
-#endif
+	PRINT("going to locate \"fmt \" header\n");
 	while (1)
 	{
 		if (fread(&temp, sizeof(temp), 1, wavefile) != 1)
@@ -539,9 +563,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 			fprintf(stderr, __FILE__ ": fread failed #4\n");
 			return 0;
 		}
-#ifdef WAVE_DEBUG
-		fprintf(stderr, __FILE__ ":  checking 0x%08x 0x%08x\n", temp, uint32_little(0x20746d66));
-#endif
+		PRINT("checking 0x%08x 0x%08x\n", temp, uint32_little(0x20746d66));
 		if (temp==uint32_little(0x20746D66))
 			break;
 		if (fread(&temp, sizeof(temp), 1, wavefile) != 1)
@@ -550,9 +572,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 			return 0;
 		}
 		temp = uint32_little(temp);
-#ifdef WAVE_DEBUG
-		fprintf(stderr, __FILE__ ": failed, skiping next %d bytes\n", temp);
-#endif
+		PRINT("failed, skiping next %d bytes\n", temp);
 		fseek(wavefile, temp, SEEK_CUR);
 	}
 	if (fread(&fmtlen, sizeof(fmtlen), 1, wavefile) != 1)
@@ -561,9 +581,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 		return 0;
 	}
 	fmtlen = uint32_little(fmtlen);
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": fmtlen=%d (must be bigger or equal to 16)\n", fmtlen);
-#endif
+	PRINT("fmtlen=%d (must be bigger or equal to 16)\n", fmtlen);
 	if (fmtlen<16)
 		return 0;
 	if (fread(&sh, sizeof(uint16_t), 1, wavefile) != 1)
@@ -572,9 +590,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 		return 0;
 	}
 	sh = uint16_little (sh);
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": compression code (only 1/pcm is supported): %d %s\n", sh, compression_code_str(sh));
-#endif
+	PRINT("compression code (only 1/pcm is supported): %d %s\n", sh, compression_code_str(sh));
 	if ((sh!=1))
 	{
 		fprintf(stderr, __FILE__ ": not uncomressed raw pcm data\n");
@@ -587,9 +603,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 		return 0;
 	}
 	sh = uint16_little (sh);
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": number of channels: %d\n", (int)sh);
-#endif
+	PRINT("number of channels: %d\n", (int)sh);
 	if ((sh==0)||(sh>2))
 	{
 		fprintf(stderr, __FILE__ ": unsupported number of channels: %d\n", sh);
@@ -603,9 +617,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 		return 0;
 	}
 	waverate = uint32_little (waverate);
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": waverate %d\n", (int)waverate);
-#endif
+	PRINT("waverate %d\n", (int)waverate);
 
 	if (fread(&temp, sizeof(uint32_t), 1, wavefile) != 1)
 	{
@@ -621,9 +633,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 		fprintf(stderr, __FILE__ ": fread failed #11\n");
 		return 0;
 	}
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": block align: %d\n", (int)(uint16_little(sh)));
-#endif
+	PRINT("block align: %d\n", (int)(uint16_little(sh)));
 
 	if (fread(&sh, sizeof(uint16_t), 1, wavefile) != 1)
 	{
@@ -631,9 +641,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 		return 0;
 	}
 	sh = uint16_little (sh);
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": bits per sample: %d\n", (int)sh);
-#endif
+	PRINT("bits per sample: %d\n", (int)sh);
 	if ((sh!=8)&&(sh!=16))
 	{
 		fprintf(stderr, __FILE__ ": unsupported bits per sample: %d\n", (int)sh);
@@ -642,9 +650,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 	wave16bit=(sh==16);
 	fseek(wavefile, fmtlen-16, SEEK_CUR);
 
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": going to locate \"data\" header\n");
-#endif
+	PRINT("going to locate \"data\" header\n");
 	while (1)
 	{
 		if (fread(&temp, sizeof(uint32_t), 1, wavefile) != 1)
@@ -652,9 +658,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 			fprintf(stderr, __FILE__ ": fread failed #13\n");
 			return 0;
 		}
-#ifdef WAVE_DEBUG
-		fprintf(stderr, __FILE__ ":  checking 0x%08x 0x%08x\n", temp, uint32_little(0x61746164));
-#endif
+		PRINT("checking 0x%08x 0x%08x\n", temp, uint32_little(0x61746164));
 		if (temp==uint32_little(0x61746164))
 			break;
 		if (fread(&temp, sizeof(uint32_t), 1, wavefile) != 1)
@@ -663,9 +667,7 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 			return 0;
 		}
 		temp = uint32_little (temp);
-#ifdef WAVE_DEBUG
-		fprintf(stderr, __FILE__ ": failed, skiping next %d bytes\n", temp);
-#endif
+		PRINT("failed, skiping next %d bytes\n", temp);
 		fseek(wavefile, temp, SEEK_CUR);
 	}
 
@@ -675,13 +677,9 @@ uint8_t __attribute__ ((visibility ("internal"))) wpOpenPlayer(FILE *wav, int to
 		return 0;
 	}
 	wavelen = uint32_little (wavelen);
-#ifdef WAVE_DEBUG
-		fprintf(stderr, __FILE__ ": datalength: %d\n", (int)wavelen);
-#endif	
+	PRINT("datalength: %d\n", (int)wavelen);
 	waveoffs=ftell(wavefile);
-#ifdef WAVE_DEBUG
-	fprintf(stderr, __FILE__ ": waveoffs: %d\n", waveoffs);
-#endif
+	PRINT("waveoffs: %d\n", waveoffs);
 	/*rawwave.open(*wavefile, waveoffs, wavelen);*/
 	/*fseek(wavefile, waveoffs, SEEK_CUR); */
 
@@ -764,9 +762,7 @@ void __attribute__ ((visibility ("internal"))) wpClosePlayer(void)
 {
 	active=0;
 
-#ifdef WAVE_DEBUG
-		fprintf(stderr, __FILE__ ": Freeing resources\n");
-#endif
+	PRINT("Freeing resources\n");
 
 	pollClose();
 
@@ -783,7 +779,8 @@ void __attribute__ ((visibility ("internal"))) wpClosePlayer(void)
 	buf16=0;
 	cliptabl=0;
 	cliptabr=0;
-/*	fclose(rawwave);*/
+/*
+	fclose(rawwave);*/
 }
 
 char __attribute__ ((visibility ("internal"))) wpLooped(void)
@@ -844,6 +841,7 @@ void __attribute__ ((visibility ("internal"))) wpGetInfo(struct waveinfo *i)
 
 void __attribute__ ((visibility ("internal"))) wpSetPos(uint32_t pos)
 {
+	PRINT("wpSetPos called for pos %lu", (unsigned long)pos);
 	pos=((pos<<(wave16bit+wavestereo))+wavelen)%wavelen;
 	if (wavelen==wavebuflen)
 		wavebufpos=pos;
