@@ -72,7 +72,8 @@ static int loadmod(struct xmodule *m, FILE *file, int chan, int sig, int opt)
 	uint16_t t;
 	uint8_t *temppat;
 
-/*	fprintf(stderr, "loadmod enter, chan=%d sig=%d opt=%d\n", chan, sig, opt);*/
+/*
+	fprintf(stderr, "loadmod enter, chan=%d sig=%d opt=%d\n", chan, sig, opt);*/
 
 	m->envelopes=0;
 	m->samples=0;
@@ -125,7 +126,7 @@ static int loadmod(struct xmodule *m, FILE *file, int chan, int sig, int opt)
 		case 0x375A4454: m->nchan=7; break;
 		case 0x385A4454: m->nchan=8; break;
 		case 0x395A4454: m->nchan=9; break;
-				 
+
 		case 0x4E484331: m->nchan=1; break; /* 1CHN... */
 		case 0x4E484332: m->nchan=2; break;
 		case 0x4E484333: m->nchan=3; break;
@@ -179,7 +180,7 @@ static int loadmod(struct xmodule *m, FILE *file, int chan, int sig, int opt)
 #ifdef XM_LOAD_DEBUG
 	fprintf(stderr, __FILE__ ": channels=%d\n", m->nchan);
 	fprintf(stderr, __FILE__ ": ninst=%d\n", m->ninst);
-#endif	
+#endif
 
 	m->nsampi=m->ninst;
 	m->nsamp=m->ninst;
@@ -346,7 +347,8 @@ static int loadmod(struct xmodule *m, FILE *file, int chan, int sig, int opt)
 	for (i=0; i<m->nord; i++)
 		m->orders[i]=orders[i];
 
-/*	memset(m->patterns, 0, sizeof(*m->patterns)*m->npat);*/
+/*
+	memset(m->patterns, 0, sizeof(*m->patterns)*m->npat);*/
 
 	for (i=0; i<m->npat; i++)
 	{
@@ -408,7 +410,8 @@ static int loadmod(struct xmodule *m, FILE *file, int chan, int sig, int opt)
 
 			if ((opt&8) && (dp[3]==15) && (dp[4]==0)) /* barbarian.mod and some few others has some broken "end" commands here and there */
 				dp[3]=0;
-/*				fprintf(stderr, "dp[3]=%d dp[4]=%d\n", dp[3], dp[4]); */
+/*
+			fprintf(stderr, "dp[3]=%d dp[4]=%d\n", dp[3], dp[4]); */
 
 			sp+=4;
 			dp+=5;
@@ -421,7 +424,8 @@ static int loadmod(struct xmodule *m, FILE *file, int chan, int sig, int opt)
 #endif
 	for (i=0; i<m->ninst; i++)
 	{
-/*		struct xmpinstrument *ip=&m->instruments[i];*/
+/*
+		struct xmpinstrument *ip=&m->instruments[i];*/
 		struct xmpsample *sp=&m->samples[i];
 		struct sampleinfo *sip=&m->sampleinfos[i];
 		size_t result;
