@@ -161,7 +161,7 @@ void __attribute__ ((visibility ("internal"))) ymClosePlayer(void)
 
 		ymMusicStop(pMusic);
 		ymMusicDestroy(pMusic);
-		
+
 		active=0;
 	}
 }
@@ -274,7 +274,7 @@ int __attribute__ ((visibility ("internal"))) ymOpenPlayer(FILE *file)
 	}
 
 	free(buffer);
-	
+
 	ymbufrate=0x10000; /* 1.0 */
 	ymbufpos=0;
 	ymbuffpos=0;
@@ -293,7 +293,7 @@ int __attribute__ ((visibility ("internal"))) ymOpenPlayer(FILE *file)
 		goto error_out;
 	}
 	devp_bufpos=0;
-	
+
 	if (!pollInit(ymIdle))
 	{
 		fprintf(stderr, "[ymplay.cpp]: pollInit() failed\n");
@@ -316,7 +316,7 @@ error_out:
 void __attribute__ ((visibility ("internal"))) ymSetLoop(int loop)
 {
 	pMusic->setLoopMode(loop);
-      	donotloop=!loop;
+	donotloop=!loop;
 }
 
 int __attribute__ ((visibility ("internal"))) ymIsLooped(void)
@@ -336,7 +336,7 @@ void __attribute__ ((visibility ("internal"))) ymSetAmplify(uint32_t amp)
 
 void __attribute__ ((visibility ("internal"))) ymSetSpeed(uint16_t sp)
 {
-      	if (sp<32)
+	if (sp<32)
 		sp=32;
 	ymbufrate=256*sp;
 }
@@ -380,7 +380,7 @@ static void ymIdler(void)
 			looped=1;
 
 		if (((timeslot_head_ym+1)%TIMESLOTS)!=timeslot_tail_devp)
-		{	
+		{
 			timeslots[timeslot_head_ym].buffer=1;
 			timeslots[timeslot_head_ym].buffer_offset = ymbufread+read;
 			timeslots[timeslot_head_ym].registers[0] = pMusic->readYmRegister(0)|(pMusic->readYmRegister(1)<<8); /* frequency A */
@@ -421,7 +421,7 @@ static void ymIdler(void)
 				base_pre+=1;
 				base_post+=2;
 				len--;
-			}	
+			}
 		}
 		ymbufread=(ymbufread+read)%YMBUFLEN;
 		clean-=read;
@@ -432,9 +432,13 @@ static void ymIdler(void)
 static struct channel_info_t Registers;
 static void ymUpdateRegisters(void)
 {
-	int bufplayed;
+#if 0
+/*	int bufplayed;
 
-	bufplayed=plrGetBufPos()>>(devp_stereo+devp_bit16);
+	bufplayed=plrGetBufPos()>>(devp_stereo+devp_bit16);*/
+#else
+	plrGetBufPos();
+#endif
 	while (1)
 	{
 		if (timeslot_tail_devp == timeslot_head_devp)
@@ -448,7 +452,7 @@ static void ymUpdateRegisters(void)
 X    X   X
 */
 			if (timeslots[timeslot_tail_devp].buffer_offset > ymbufpos)
-				break;		
+				break;
 		} else {
 /*
 0123456789
@@ -457,8 +461,8 @@ X    X   X
 */
 		/* this logic might be faulty */
 			if ((timeslots[timeslot_tail_devp].buffer_offset > ymbufpos) && (timeslots[timeslot_tail_devp].buffer_offset < ymbufread))
-				break;		
-		
+				break;
+
 		}
 		if (timeslots[timeslot_tail_devp].registers[0]==0)
 			Registers.frequency_a = 0;
@@ -512,7 +516,7 @@ void __attribute__ ((visibility ("internal"))) ymIdle(void)
 
 	if (clipbusy++)
 	{
-	       	clipbusy--;
+		clipbusy--;
 		return;
 	}
 
@@ -541,7 +545,8 @@ void __attribute__ ((visibility ("internal"))) ymIdle(void)
 	{
 		uint32_t towrap=imuldiv(((YMBUFLEN+ymbufread-ymbufpos-1)%YMBUFLEN), 65536, ymbufrate);
 		if (bufdelta>towrap)
-		{	/* will the eof hit inside the delta? */
+		{
+			/* will the eof hit inside the delta? */
 			/*quietlen=bufdelta-towrap;*/
 			bufdelta=towrap;
 			if ((looped==1)&&(towrap==0))
@@ -590,13 +595,14 @@ void __attribute__ ((visibility ("internal"))) ymIdle(void)
 			unsigned int pre_pos;
 			int32_t c0, c1, c2, c3, ls, rs, vm1, v1, v2, wpm1;
 			uint32_t wp1, wp2;
-/*			if ((bufdelta-=2)<0) bufdelta=0;  by my meening, this should be in place   TODO stian */
+/*
+			if ((bufdelta-=2)<0) bufdelta=0;  by my meening, this should be in place   TODO stian */
 			for (i=0; i<bufdelta; i++)
 			{
 				wpm1=ymbufpos-1; if (wpm1<0) wpm1+=YMBUFLEN;
 				wp1=ymbufpos+1; if (wp1>=YMBUFLEN) wp1-=YMBUFLEN;
 				wp2=ymbufpos+2; if (wp2>=YMBUFLEN) wp2-=YMBUFLEN;
-				
+
 				c0 = *(uint16_t *)(ymbuf_post+(ymbufpos<<1))^0x8000;
 				vm1= *(uint16_t *)(ymbuf_post+(wpm1<<1))^0x8000;
 				v1 = *(uint16_t *)(ymbuf_post+(wp1<<1))^0x8000;
@@ -614,7 +620,7 @@ void __attribute__ ((visibility ("internal"))) ymIdle(void)
 					ls=65535;
 				else if (ls<0)
 					ls=0;
-				
+
 				c0 = *(uint16_t *)(ymbuf_post+(ymbufpos<<1)+1)^0x8000;
 				vm1= *(uint16_t *)(ymbuf_post+(wpm1<<1)+1)^0x8000;
 				v1 = *(uint16_t *)(ymbuf_post+(wp1<<1)+1)^0x8000;
@@ -634,7 +640,7 @@ void __attribute__ ((visibility ("internal"))) ymIdle(void)
 					rs=0;
 				buf16[2*i]=(uint16_t)ls^0x8000;
 				buf16[2*i+1]=(uint16_t)rs^0x8000;
-				
+
 				pre_pos=ymbufpos;
 				ymbuffpos+=ymbufrate;
 				ymbufpos+=(ymbuffpos>>16);
@@ -924,7 +930,7 @@ void __attribute__ ((visibility ("internal"))) ymIdle(void)
 		if (devp_bufpos>=devp_buflen)
 			devp_bufpos-=devp_buflen;
 	}
-	
+
 	bufdelta=quietlen;
 	if (bufdelta)
 	{
