@@ -160,7 +160,8 @@ static void drawvolbar(uint16_t *buf, int l, int r, unsigned char st)
 
 static void drawlongvolbar(uint16_t *buf, int l, int r, unsigned char st)
 {
-/*	logvolbar(l, r);
+/*
+	logvolbar(l, r);
 	l=(l+2)>>2;
 	r=(r+2)>>2;*/
 	if (plPause)
@@ -179,19 +180,20 @@ static void drawlongvolbar(uint16_t *buf, int l, int r, unsigned char st)
 
 static void ymDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 {
-      	long tim;
+	long tim;
 	ymMusicInfo_t globinfo;
 
 	ymMusicGetInfo(pMusic, &globinfo);
 
-/*       	mcpDrawGStrings(buf);*/
+/*
+	mcpDrawGStrings(buf);*/
 
 	if (plPause)
 		tim=(pausetime-starttime)/DOS_CLK_TCK;
 	else
 		tim=(dos_clock()-starttime)/DOS_CLK_TCK;
 
-      	if (plScrWidth<128)
+	if (plScrWidth<128)
 	{
 		memset(buf[0]+80, 0, (plScrWidth-80)*sizeof(uint16_t));
 		memset(buf[1]+80, 0, (plScrWidth-80)*sizeof(uint16_t));
@@ -209,7 +211,8 @@ static void ymDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 			writestring(buf[0], 38-((pan+70)>>4), 0x0F, "l", 1);
 		}
 		writestring(buf[0], 46+((bal+70)>>4), 0x0F, "I", 1);
-/*		_writenum(buf[0], 62, 0x0F, speed*100/256, 10, 3);*/
+/*
+		_writenum(buf[0], 62, 0x0F, speed*100/256, 10, 3);*/
 		_writenum(buf[0], 75, 0x0F, ymbufrate*100/65536, 10, 3);
 
 		writestring(buf[1],  0, 0x09, " author: .......................... comment: ...................... type: .....",80);
@@ -254,7 +257,8 @@ static void ymDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 			writestring(buf[0], 70-((pan+68)>>3), 0x0F, "l", 1);
 		}
 		writestring(buf[0], 83+((bal+68)>>3), 0x0F, "I", 1);
-	/*	_writenum(buf[0], 110, 0x0F, speed*100/256, 10, 3);*/
+	/*
+		_writenum(buf[0], 110, 0x0F, speed*100/256, 10, 3);*/
 		_writenum(buf[0], 124, 0x0F, ymbufrate*100/65536, 10, 3);
 
 		writestring(buf[1],  0, 0x09, " author: ......................................................... comment: ........................................ type: .....",128);
@@ -287,7 +291,7 @@ static void ymDrawGStrings(uint16_t (*buf)[CONSOLE_MAX_X])
 
 static void drawchannel(uint16_t *buf, int len, int i)
 {
-	int voll, volr;
+	int voll=15, volr=15;
 	int env = 0;
 #warning TODO
         unsigned char st=plMuteCh[i]; /* TODO */
@@ -295,9 +299,9 @@ static void drawchannel(uint16_t *buf, int len, int i)
         unsigned char tcol=st?0x08:0x0F;
         unsigned char tcold=st?0x08:0x07;
 
-	unsigned char channel_mode;
-	int freq;
-	
+	unsigned char channel_mode=0;
+	int freq=0;
+
 	const char *waves4 []= {"t+s ", "nois", "tone", "    ", "gene",
 	"\\___",  /* 0 0 0 0 */
 	"\\___",  /* 0 0 0 1 */
@@ -334,7 +338,8 @@ static void drawchannel(uint16_t *buf, int len, int i)
 	"env:saw         ", /* 1 1 1 0 */
 	"env:spike       "  /* 1 1 1 1 */
 	};
-/*	const char *waves4 []= {"sine", "half", "2x  ", "saw "};
+/*
+	const char *waves4 []= {"sine", "half", "2x  ", "saw "};
 	const char *waves16[]= {"sine curves     ", "half sine curves", "positiv sines   ", "sawtooth        "};*/
 	struct channel_info_t *info = ymRegisters();
 
@@ -389,7 +394,7 @@ static void drawchannel(uint16_t *buf, int len, int i)
 			break;
 		case 128:
 			writestring(buf, 0, tcold, "                   \263        \263       \263       \263                \263               \263   \372\372\372\372\372\372\372\372\372\372\372\372\372\372\372\372 \372\372\372\372\372\372\372\372\372\372\372\372\372\372\372\372", 128);
-			break;                                                                      
+			break;
 		case 76:
 			writestring(buf, 0, tcold, "                  \263      \263     \263     \263     \263             \263 \372\372\372\372\372\372\372\372 \372\372\372\372\372\372\372\372", 76);
 			break;
@@ -399,9 +404,11 @@ static void drawchannel(uint16_t *buf, int len, int i)
 		break;
 	}
 
-/*	oplpGetChanInfo(i,ci);*/
+/*
+	oplpGetChanInfo(i,ci);*/
 
-/*	if (!ci.vol)
+/*
+	if (!ci.vol)
 		return;*/
 	uint8_t nte=convnote(freq);
 	char nchar[4];
@@ -422,71 +429,80 @@ static void drawchannel(uint16_t *buf, int len, int i)
 			writestring(buf+6, 0, tcol, nchar, 3);
 			if (env)
 				writestring(buf+10, 0, tcol, "En", 2);
-/*#			writenum(buf+10, 0, tcol, ci.pulse>>4, 16, 2, 0);
-  #			if (ci.filtenabled && ftype)
-  #				writenum(buf+13, 0, tcol, ftype, 16, 1, 0);
-  #			if (efx)
-  #				writestring(buf+15, 0, tcol, fx2[efx], 2);*/
+/*
+			writenum(buf+10, 0, tcol, ci.pulse>>4, 16, 2, 0);
+			if (ci.filtenabled && ftype)
+				writenum(buf+13, 0, tcol, ftype, 16, 1, 0);
+			if (efx)
+				writestring(buf+15, 0, tcol, fx2[efx], 2);*/
 			drawvolbar(buf+18, voll, volr, st);
 			break;
 		case 44:
 			writestring(buf+1, 0, tcol, waves4[channel_mode], 4);
-/*#			writenum(buf+6, 0, tcol, ci.ad, 16, 2, 0);
-  #			writenum(buf+8, 0, tcol, ci.sr, 16, 2, 0);*/
+/*
+			writenum(buf+6, 0, tcol, ci.ad, 16, 2, 0);
+			writenum(buf+8, 0, tcol, ci.sr, 16, 2, 0);*/
 			writestring(buf+11, 0, tcol, nchar, 3);
 			if (env)
 				writestring(buf+15, 0, tcol, "En", 2);
-/*#			writenum(buf+15, 0, tcol, ci.pulse>>4, 16, 2, 0);
-  #			if (ci.filtenabled && ftype)
-  #				writestring(buf+18, 0, tcol, filters3[ftype], 3);
-  #			if (efx)
-  #				writestring(buf+22, 0, tcol, fx2[efx], 2);*/
+/*
+			writenum(buf+15, 0, tcol, ci.pulse>>4, 16, 2, 0);
+			if (ci.filtenabled && ftype)
+				writestring(buf+18, 0, tcol, filters3[ftype], 3);
+			if (efx)
+				writestring(buf+22, 0, tcol, fx2[efx], 2);*/
 			drawvolbar(buf+26, voll, volr, st);
 			break;
 		case 62:
 			writestring(buf+1, 0, tcol, waves16[channel_mode], 16);
-/*#			writenum(buf+18, 0, tcol, ci.ad, 16, 2, 0);
-  #			writenum(buf+20, 0, tcol, ci.sr, 16, 2, 0);*/
+/*
+			writenum(buf+18, 0, tcol, ci.ad, 16, 2, 0);
+			writenum(buf+20, 0, tcol, ci.sr, 16, 2, 0);*/
 			writestring(buf+23, 0, tcol, nchar, 3);
 
 			if (env)
 				writestring(buf+27, 0, tcol, "Env", 3);
-/*#			writenum(buf+27, 0, tcol, ci.pulse, 16, 3, 0);
-  #			if (ci.filtenabled && ftype)
-  #				writestring(buf+31, 0, tcol, filters3[ftype], 3);
-  #			if (efx)
-  #				writestring(buf+35, 0, tcol, fx7[efx], 7);*/
+/*
+			writenum(buf+27, 0, tcol, ci.pulse, 16, 3, 0);
+			if (ci.filtenabled && ftype)
+				writestring(buf+31, 0, tcol, filters3[ftype], 3);
+			if (efx)
+				writestring(buf+35, 0, tcol, fx7[efx], 7);*/
 			drawvolbar(buf+44, voll, volr, st);
 			break;
 		case 76:
 			writestring(buf+1, 0, tcol, waves16[channel_mode], 16);
 			writenum(buf+19, 0, tcol, freq, 10, 6, 0);
-/*#			writenum(buf+20, 0, tcol, ci.ad, 16, 2, 0);
-  #			writenum(buf+22, 0, tcol, ci.sr, 16, 2, 0);*/
+/*
+			writenum(buf+20, 0, tcol, ci.ad, 16, 2, 0);
+			writenum(buf+22, 0, tcol, ci.sr, 16, 2, 0);*/
 			writestring(buf+27, 0, tcol, nchar, 3);
 			if (env)
 				writestring(buf+33, 0, tcol, "Env", 3);
-/*#			writenum(buf+33, 0, tcol, ci.pulse, 16, 3, 0);
-  #			if (ci.filtenabled && ftype)
-  #				writestring(buf+39, 0, tcol, filters3[ftype], 3);
-  #			writestring(buf+45, 0, tcol, fx11[efx], 11);*/
+/*
+			writenum(buf+33, 0, tcol, ci.pulse, 16, 3, 0);
+			if (ci.filtenabled && ftype)
+				writestring(buf+39, 0, tcol, filters3[ftype], 3);
+			writestring(buf+45, 0, tcol, fx11[efx], 11);*/
 			drawvolbar(buf+59, voll, volr, st);
 			break;
 		case 128:
 			writestring(buf+1, 0, tcol, waves16[channel_mode], 16);
 			writenum(buf+21, 0, tcol, freq, 10, 6, 0);
-/*#			writenum(buf+22, 0, tcol, ci.ad, 16, 2, 0);
-  #			writenum(buf+24, 0, tcol, ci.sr, 16, 2, 0);*/
+/*
+			writenum(buf+22, 0, tcol, ci.ad, 16, 2, 0);
+			writenum(buf+24, 0, tcol, ci.sr, 16, 2, 0);*/
 			writestring(buf+31, 0, tcol, nchar, 3);
 			if (env)
 				writestring(buf+39, 0, tcol, "Env", 3);
-/*#			writenum(buf+39, 0, tcol, ci.pulse, 16, 3, 0);
-  #			if (ci.filtenabled && ftype)
-  #				writestring(buf+47, 0, tcol, filters12[ftype], 12);
-  #			writestring(buf+64, 0, tcol, fx11[efx], 11);*/
+/*
+			writenum(buf+39, 0, tcol, ci.pulse, 16, 3, 0);
+			if (ci.filtenabled && ftype)
+				writestring(buf+47, 0, tcol, filters12[ftype], 12);
+			writestring(buf+64, 0, tcol, fx11[efx], 11);*/
 			drawlongvolbar(buf+81, voll, volr, st);
 			break;
-	}			
+	}
 }
 
 static int ymProcessKey(uint16_t key)
@@ -516,6 +532,7 @@ static int ymProcessKey(uint16_t key)
 			startpausefade();
 			break;
 		case KEY_CTRL_P:
+			pausefadedirect=0;
 			if (plPause)
 				starttime=starttime+dos_clock()-pausetime;
 			else
@@ -586,12 +603,14 @@ static int ymOpenFile(const char *path, struct moduleinfostruct *info, FILE *fil
 	plDrawGStrings=ymDrawGStrings;
 	plGetMasterSample=plrGetMasterSample;
 	plGetRealMasterVolume=plrGetRealMasterVolume;
-	
+
 	if (!ymOpenPlayer(file))
 		return -1;
-	
+
 	starttime=dos_clock();
+	plPause=0;
 	normalize();
+	pausefadedirect=0;
 
 	plNLChan=plNPChan=5;
 	plUseChannels(drawchannel);
@@ -603,5 +622,5 @@ static int ymOpenFile(const char *path, struct moduleinfostruct *info, FILE *fil
 extern "C"
 {
   cpifaceplayerstruct ymPlayer = {ymOpenFile, ymCloseFile};
-  struct linkinfostruct dllextinfo = {"playym", "OpenCP STYMulator Player (c) 2010 Stian Skjelstad", DLLVERSION, 0 LINKINFOSTRUCT_NOEVENTS};
+  struct linkinfostruct dllextinfo = {"playym", "OpenCP STYMulator Player (c) 2010-2011 Stian Skjelstad", DLLVERSION, 0 LINKINFOSTRUCT_NOEVENTS};
 }
