@@ -108,8 +108,10 @@ void _splitpath(const char *src, char *drive, char *path, char *file, char *ext)
 		ref1=src+strlen(src);
 	while (/*(*src)*/(src<ref1))
 	{
-/*		if (!strchr(src+1, '.'))
-			break;*/
+/*
+		if (!strchr(src+1, '.'))
+			break;
+*/
 		if (!strcasecmp(src, ".tar.gz")) /* I am a bad boy */
 			break;
 		if (!strcasecmp(src, ".tar.bz2")) /* very bad */
@@ -194,15 +196,21 @@ void _makepath(char *dst, const char *drive, const char *path, const char *file,
 			strcat(dst, ext);
 }
 
-void strupr(char *src)
+#ifndef HAVE_STRUPR
+
+char *strupr(char *src)
 {
+	char *retval = src;
 	while (*src)
 	{
 		*src=toupper(*src);
 		src++;
 	}
+	return retval;
 }
 
+#endif
+
 size_t filelength(int fd)
 {
 	off_t cur=lseek(fd, 0, SEEK_CUR);
