@@ -8,7 +8,13 @@
 extern time_t dos_clock(void);
 extern void _splitpath(const char *src, char *drive, char *path, char *file, char *ext);
 extern void _makepath(char *dst /* PATH_MAX+1 */, const char *drive, const char *path, const char *file, const char *ext);
-extern void strupr(char *src);
+
+#ifndef HAVE_STRUPR
+extern char *strupr(char *src);
+#else
+#include <string.h>
+#endif
+
 extern size_t filelength(int fd);
 extern size_t _filelength(const char *path);
 extern int memicmp(const void *s1, const void *s2, size_t n);
