@@ -82,15 +82,16 @@ static int console_init(void)
 #ifdef __linux
 	char _stdout[128];
 	char _stdin[128];
-
+# ifdef HAVE_FRAMEBUFFER
 	int test_fb=0;
 	int test_vcsa=0;
+# endif
 #endif
 
 	vgaMakePal();
-	
+
 	reset_api();
-	
+
 	fprintf(stderr, "Initing console... \n");
 	fflush(stderr);
 	{
@@ -169,7 +170,7 @@ static int console_init(void)
 #ifdef __linux
 	memset(_stdin, 0, sizeof(_stdin));
 	memset(_stdout, 0, sizeof(_stdout));
-	
+
 	if (readlink("/proc/self/fd/0", _stdin, sizeof(_stdin)-1)<0)
 	if (readlink("/dev/fd/0", _stdin, sizeof(_stdin)-1)<0)
 	{
@@ -220,8 +221,10 @@ static int console_init(void)
 	{
 		case TTY_MAJOR:
 			fprintf(stderr, "We have a tty, testing:\n    Framebuffer (/dev/fb)\n    VCSA (/dev/vcsa)\n    Curses\n");
+#ifdef HAVE_FRAMEBUFFER
 			test_fb=1;
 			test_vcsa=1;
+#endif
 			break;
 		case UNIX98_PTY_SLAVE_MAJOR:
 #if (UNIX98_PTY_MAJOR_COUNT>=2)
@@ -405,13 +408,13 @@ static void __gdrawchar8p(unsigned short x, unsigned short y, unsigned char c, u
 #ifdef CONSOLE_DEBUG
 	fprintf(stderr, "gdrawchar8p not implemented in this console driver\n");
 #endif
-}	
+}
 static void __gdrawstr(unsigned short y, unsigned short x, const char *s, unsigned short len, unsigned char f, unsigned char b)
 {
 #ifdef CONSOLE_DEBUG
 	fprintf(stderr, "gdrawstr not implemented in this console driver\n");
 #endif
-}	
+}
 static void __gupdatestr(unsigned short y, unsigned short x, const uint16_t *str, unsigned short len, uint16_t *old)
 {
 #ifdef CONSOLE_DEBUG
