@@ -3,7 +3,7 @@
 
 extern int mcpGetFreq8363(int note);
 extern int mcpGetFreq6848(int note);
-extern int mcpGetNote8363(int frq);
-extern int mcpGetNote6848(int frq);
+extern int mcpGetNote8363(unsigned int frq);
+extern int mcpGetNote6848(unsigned int frq);
 
 #endif
