@@ -86,10 +86,10 @@ int ___peek_key(void)
 	}
 	if (ring_head==ring_tail)
 		return retval;
-	
+
 	/* this code now expects escape code not to enter this part of the code
 	 * broken up into more than one single buffer read
-	 */	
+	 */
 #ifdef KEYBOARD_DEBUG
 	fprintf(stderr, "ring_head=%d ring_tail=%d\n", ring_head, ring_tail);
 #endif
@@ -112,7 +112,7 @@ int ___peek_key(void)
 #ifdef KEYBOARD_DEBUG
 	fprintf(stderr, "\n");
 #endif
-	
+
 	retval=ring_buffer[ring_tail];
 	ring_tail=(ring_tail+1)%BUFFER_LEN;
 	key_len--;
@@ -125,7 +125,8 @@ int ___peek_key(void)
 	if ((retval==27)&&key_len&&(ring_buffer[ring_tail]=='O')) /* aterm on gentoo -> ssh -> redhat -> ncurses gives wierd results */
 	{
 		escapelevel+=10;
-/*		ring_tail=(ring_tail+1)%BUFFER_LEN;
+/*
+		ring_tail=(ring_tail+1)%BUFFER_LEN;
 		key_len--;*/
 	}
 	while ((retval==27)&&key_len&&(ring_buffer[ring_tail]=='['))
@@ -142,12 +143,12 @@ int ___peek_key(void)
 		if ((((ring_buffer[ring_tail]>='a') && (ring_buffer[ring_tail]<='z')) || (ring_buffer[ring_tail] == 10) || (ring_buffer[ring_tail] == 13)) && (key_len==1) )
 		{
 			upcode=ring_buffer[ring_tail]+512;
-			ring_tail=(ring_tail+1)%BUFFER_LEN;	
+			ring_tail=(ring_tail+1)%BUFFER_LEN;
 			key_len--;
 		} else if ((ring_buffer[ring_tail]>='A') && (ring_buffer[ring_tail]<='Z') && (key_len==1) )
 		{
 			upcode=ring_buffer[ring_tail]+256;
-			ring_tail=(ring_tail+1)%BUFFER_LEN;	
+			ring_tail=(ring_tail+1)%BUFFER_LEN;
 			key_len--;
 		} else if ( (ring_buffer[ring_tail]>='0') && (ring_buffer[ring_tail]<='9') )
 		{
@@ -155,12 +156,12 @@ int ___peek_key(void)
 			{
 				upcode*=10;
 				upcode+=ring_buffer[ring_tail]-'0';
-				ring_tail=(ring_tail+1)%BUFFER_LEN;			
+				ring_tail=(ring_tail+1)%BUFFER_LEN;
 				key_len--;
 			}
 			if (key_len&&(ring_buffer[ring_tail]=='~'))
 			{
-				ring_tail=(ring_tail+1)%BUFFER_LEN;	
+				ring_tail=(ring_tail+1)%BUFFER_LEN;
 				key_len--;
 			}
 		} else if ( ( ring_buffer[ring_tail] == 'O') && key_len>=3)
@@ -183,7 +184,7 @@ int ___peek_key(void)
 		{
 			if ((ring_buffer[ring_tail]>='A') && (ring_buffer[ring_tail]<='Z'))
 				upcode=ring_buffer[ring_tail]+256;
-			ring_tail=(ring_tail+1)%BUFFER_LEN;	
+			ring_tail=(ring_tail+1)%BUFFER_LEN;
 			key_len--;
 		}
 	}
@@ -278,8 +279,8 @@ int ___peek_key(void)
 			case 'D'+256:
 				retval=KEY_LEFT;
 				break;
-
-	/*		case 'P'+256:
+	/*
+			case 'P'+256:
 				retval=KEY_BREAK;
 				break;*/
 			case 1:
@@ -301,7 +302,8 @@ int ___peek_key(void)
 				retval=KEY_NPAGE;
 				break;
 
-/*			case 25:
+/*
+			case 25:
 				retval=KEY_SHIFT_F1;
 				break;
 			case 26:
@@ -344,27 +346,35 @@ int ___peek_key(void)
 			case 'c'+512:
 				retval=KEY_ALT_C;
 				break;
-/*			case 'd'+512:
+/*
+			case 'd'+512:
 				retval=KEY_ALT_D;
-				break;*/
+				break;
+*/
 			case 'e'+512:
 				retval=KEY_ALT_E;
 				break;
-/*			case 'f'+512:
+/*
+			case 'f'+512:
 				retval=KEY_ALT_F;
-				break;*/
+				break;
+*/
 			case 'g'+512:
 				retval=KEY_ALT_G;
 				break;
-/*			case 'h'+512:
+/*
+			case 'h'+512:
 				retval=KEY_ALT_H;
-				break;*/
+				break;
+*/
 			case 'i'+512:
 				retval=KEY_ALT_I;
 				break;
-/*			case 'j'+512:
+/*
+			case 'j'+512:
 				retval=KEY_ALT_J;
-				break;*/
+				break;
+*/
 			case 'k'+512:
 				retval=KEY_ALT_K;
 				break;
@@ -374,42 +384,50 @@ int ___peek_key(void)
 			case 'm'+512:
 				retval=KEY_ALT_M;
 				break;
-/*			case 'n'+512:
+/*
+			case 'n'+512:
 				retval=KEY_ALT_N;
-				break;*/
+				break;
+*/
 			case 'o'+512:
 				retval=KEY_ALT_O;
 				break;
 			case 'p'+512:
 				retval=KEY_ALT_P;
 				break;
-/*			case 'q'+512:
+/*
+			case 'q'+512:
 				retval=KEY_ALT_Q;
-				break;*/
+				break;
+*/
 			case 'r'+512:
 				retval=KEY_ALT_R;
 				break;
 			case 's'+512:
 				retval=KEY_ALT_S;
 				break;
-/*			case 't'+512:
+/*
+			case 't'+512:
 				retval=KEY_ALT_T;
-				break;*/
-/*			case 'u'+512:
+				break;
+			case 'u'+512:
 				retval=KEY_ALT_U;
-				break;*/
-/*			case 'v'+512:
+				break;
+			case 'v'+512:
 				retval=KEY_ALT_V;
-				break;*/
-/*			case 'w'+512:
+				break;
+			case 'w'+512:
 				retval=KEY_ALT_W;
-				break;*/
+				break;
+*/
 			case 'x'+512:
 				retval=KEY_ALT_X;
 				break;
-/*			case 'y'+512:
+/*
+			case 'y'+512:
 				retval=KEY_ALT_Y;
-				break;*/
+				break;
+*/
 			case 'z'+512:
 				retval=KEY_ALT_Z;
 				break;
