@@ -50,7 +50,7 @@ typedef struct
 	int height;
 } mode_gui_data_t;
 
-static const mode_gui_data_t mode_gui_data[] = 
+static const mode_gui_data_t mode_gui_data[] =
 {
 	{MODE_320_200, 320, 200},
 	{MODE_640_400, 640, 400},
@@ -72,7 +72,7 @@ typedef enum {
 	_FONT_MAX = 2
 } FontSizeEnum;
 
-const struct FontSizeInfo_t FontSizeInfo[] = 
+const struct FontSizeInfo_t FontSizeInfo[] =
 {
 	{4, 4},
 	{8, 8},
@@ -101,7 +101,7 @@ static const mode_tui_data_t mode_tui_data[] =
 	{ 160, 128, MODE_1280_1024, _8x8/*, MODE_1280x1024*/},
 	{ -1, -1, -1, -1}
 };
-	
+
 typedef struct
 {
 	int is_possible;
@@ -148,7 +148,7 @@ static void set_state_textmode(int fullscreen, int width, int height)
 #warning TODO, is this right?
 	if (current_surface)
 	{
-//		SDL_FreeSurface(current_surface);
+		// SDL_FreeSurface(current_surface);
 		current_surface = 0;
 	}
 
@@ -255,7 +255,7 @@ static void plSetTextMode(unsigned char x)
 		if (current_surface)
 		{
 #warning TODO, is this right?
-//			SDL_FreeSurface(current_surface);
+			// SDL_FreeSurface(current_surface);
 			current_surface = 0;
 		}
 		plScrMode=255;
@@ -306,7 +306,7 @@ static void set_state_graphmode(int fullscreen, int width, int height)
 	if (current_surface)
 	{
 #warning TODO, is this right?
-//		SDL_FreeSurface(current_surface);
+		// SDL_FreeSurface(current_surface);
 		current_surface = 0;
 	}
 
@@ -406,7 +406,7 @@ static void FindFullscreenModes_SDL(Uint32 flags)
 	modes = SDL_ListModes(NULL, flags);
 
 	if (modes == (SDL_Rect**)0)
-	{			
+	{
 		fprintf(stderr, "[SDL video] No modes available!\n");
 		return;
 	}
@@ -472,7 +472,8 @@ static void plDisplaySetupTextMode(void)
 		displaystr(1, 15, plCurrentFont == _4x4 ? 0x0f : 0x07 , "4x4", 3);
 		displaystr(1, 19, plCurrentFont == _8x8 ? 0x0f : 0x07, "8x8", 3);
 		displaystr(1, 23, plCurrentFont == _8x16 ? 0x0f : 0x07, "8x16", 4);
-/*		displaystr(2, 0, 0x07, "2:  fullscreen: ", 16);
+/*
+		displaystr(2, 0, 0x07, "2:  fullscreen: ", 16);
 		displaystr(3, 0, 0x07, "3:  resolution in fullscreen:", 29);*/
 
 		displaystr(plScrHeight-1, 0, 0x17, "  press the number of the item you wish to change and ESC when done", plScrWidth);
@@ -650,7 +651,7 @@ void sdl_done(void)
 		free(vgatextram);
 		vgatextram=0;
 	}
-	
+
 	need_quit = 0;
 }
 
@@ -992,7 +993,7 @@ static void RefreshScreenText(void)
 
 	if (!current_surface)
 		return;
-	
+
 	if (curshape)
 	if (time(NULL)&1)
 		doshape=curshape;
@@ -1460,7 +1461,7 @@ static void RefreshScreenGraph(void)
 				exit(-1);
 
 			case 4:
-			{ 
+			{
 				uint32_t *dst;
 				while (1)
 				{
@@ -1474,7 +1475,7 @@ static void RefreshScreenGraph(void)
 				break;
 			}
 			case 2:
-			{ 
+			{
 				uint16_t *dst;
 				while (1)
 				{
@@ -1487,7 +1488,7 @@ static void RefreshScreenGraph(void)
 				}
 			}
 			case 1:
-			{ 
+			{
 				uint8_t *dst;
 				while (1)
 				{
@@ -1504,7 +1505,6 @@ static void RefreshScreenGraph(void)
 				}
 			}
 		}
-		
 	}
 
 	SDL_UnlockSurface(current_surface);
