@@ -164,7 +164,8 @@ static int set_font(int lines, int verbose)
 		return -1;
 	}
 	/* KERNEL-BUGS ARE SO FUN!!!.. if you get 16 lines, using 8 line font or the oposite way around, the stuff below helps */
-/*	newfontdesc.height=16;
+/*
+	newfontdesc.height=16;
 	ioctl(1, KDFONTOP, &newfontdesc);
 	newfontdesc.height=lines;
 	ioctl(1, KDFONTOP, &newfontdesc);*/
@@ -177,11 +178,11 @@ static int set_font(int lines, int verbose)
 static int init_fonts(void)
 {
 	int i;
-	
+
 #ifdef VCSA_VERBOSE
 	fprintf(stderr, "vcsa: Storing the original font.. ");
 #endif
-	
+
 	orgfontdesc.op=KD_FONT_OP_GET;
 	orgfontdesc.flags=0;
 	orgfontdesc.height=32;
@@ -252,7 +253,7 @@ static void make_chr_table(void)
 #ifdef VCSA_VERBOSE
 	fprintf(stderr, "vcsa: Making iconv conversion for characters to display\n");
 #endif
-	
+
 	for (i=0;i<256;i++)
 	{
 		src[i]=i;
@@ -464,7 +465,7 @@ static void plSetTextMode(unsigned char x)
 		switch (x)
 		{
 			case 0:
-			case 1:	/* 80 * 25 */
+			case 1: /* 80 * 25 */
 			case 4: /* 132 * 25 */
 			case 5: /* 132 * 30 */
 				/*if (((plScrHeight==50)||(plScrHeight==60))&&font_replaced==8)
@@ -472,7 +473,7 @@ static void plSetTextMode(unsigned char x)
 					if (!set_font(16, 0))
 					{
 						font_replaced=16;
-						plScrHeight/=2;	
+						plScrHeight/=2;
 						set_plScrType();
 					}
 				}*/
@@ -592,7 +593,7 @@ static void setcurshape(unsigned short shape)
 {
 	char *buffer="";
 	int l;
-	
+
 	switch (shape)
 	{
 		case 0: buffer="\033[?1c"; break;
@@ -690,7 +691,7 @@ int vcsa_init(int minor)
 
 	{
 		struct kbentry k;
-#ifdef VCSA_VERBOSE		
+#ifdef VCSA_VERBOSE
 		fprintf(stderr, "vcsa: Setting up non-blocking keyboard..\n");
 #endif
 		if (tcgetattr(0, &orgterm))
@@ -713,8 +714,8 @@ int vcsa_init(int minor)
 			return -1;
 		}
 		tcsetattr(0, TCSANOW, &orgterm),
-	
-#ifdef FIX_BACKSPACE	
+
+#ifdef FIX_BACKSPACE
 		/* On a lot of linux distros, the backspace and delete keys are
 		 * merged together. This fixes the backspace key to make
 		 * character 8, and leaves the delete button to continue make
