@@ -78,9 +78,6 @@ static XSizeHints Textmode_SizeHints;
 static unsigned long Textmode_Window_Width = 0;
 static unsigned long Textmode_Window_Height = 0;
 
-
-	
-
 /* "stolen" from Mplayer START */
 static void vo_hidecursor(Display * disp, Window win)
 {
@@ -110,15 +107,15 @@ static int xvidmode_event_base=-1, xvidmode_error_base;
 static XF86VidModeModeInfo **xvidmode_modes=NULL;
 
 static XF86VidModeModeInfo *modelines[6], *Graphmode_modeline, default_modeline;
-enum MODE_LINES 
+enum MODE_LINES
 {
 	MODE_320x200,
-/*	MODE_320x240,*/
-/*	MODE_640x400,*/
+	/* MODE_320x240,*/
+	/* MODE_640x400,*/
 	MODE_640x480,
 	MODE_1024x768,
-/*	MODE_1280x1024*/
-/*	MODE_1600x1200*/
+	/* MODE_1280x1024*/
+	/* MODE_1600x1200*/
 };
 
 static Atom XA_NET_SUPPORTED;
@@ -156,14 +153,14 @@ static void xvidmode_init(void)
 	memset(&default_modeline, 0, sizeof(default_modeline));
 
 	XGetWindowAttributes(mDisplay, DefaultRootWindow(mDisplay), &xwa);
-	fprintf(stderr, "[x11] rootwindow: width:%d height:%d\n", xwa.width, xwa.height); 
+	fprintf(stderr, "[x11] rootwindow: width:%d height:%d\n", xwa.width, xwa.height);
 	default_modeline.hdisplay = xwa.width;
 	default_modeline.vdisplay = xwa.height;
 	/* TODO */
 
 	if ((!cfGetProfileBool("x11", "xvidmode", 1, 0)) )
 	{
-        	if (!XF86VidModeQueryExtension(mDisplay, &xvidmode_event_base, &xvidmode_error_base))
+		if (!XF86VidModeQueryExtension(mDisplay, &xvidmode_event_base, &xvidmode_error_base))
 		{
 			fprintf(stderr, "[x11] XF86VidModeQueryExtension() failed\n");
 			xvidmode_event_base=-1;
@@ -275,7 +272,7 @@ static void ewmh_init(void)
 	unsigned long bytes_after_return;
 	Atom *args;
 	unsigned char *tmp;
-	
+
 	XA_NET_SUPPORTED = XInternAtom(mDisplay, "_NET_SUPPORTED", False);
 	XA_NET_WM_STATE = XInternAtom(mDisplay, "_NET_WM_STATE", False);
 	XA_NET_WM_STATE_FULLSCREEN = XInternAtom(mDisplay, "_NET_WM_STATE_FULLSCREEN", False);
@@ -314,7 +311,7 @@ static int ewmh_fullscreen(Window window, int action)
 	xev.xclient.data.l[2] = 0;
 	xev.xclient.data.l[3] = 0;
 	xev.xclient.data.l[4] = 0;
-	
+
 	if (!XSendEvent(mDisplay, DefaultRootWindow(mDisplay), False, SubstructureRedirectMask | SubstructureNotifyMask, &xev))
 	{
 		fprintf(stderr, "[x11] (EWMH) Failed to set NET_WM_STATE_FULLSCREEN\n");
@@ -355,17 +352,17 @@ static void motif_decoration(Window window, int action)
 
 	typedef struct
 	{
-    		long flags;
+		long flags;
 		long functions;
 		long decorations;
 		long input_mode;
 		long state;
 	} MotifWmHints;
-	
+
 	static Atom vo_MotifHints = None;
-	
-     	vo_MotifHints = XInternAtom(mDisplay, "_MOTIF_WM_HINTS", 0);
-	
+
+	vo_MotifHints = XInternAtom(mDisplay, "_MOTIF_WM_HINTS", 0);
+
 	if (vo_MotifHints != None)
 	{
 		MotifWmHints vo_MotifWmHints;
@@ -481,7 +478,7 @@ static void set_state_graphmode(int target)
 		XSetWMNormalHints(mDisplay, window, &SizeHints);
 		XResizeWindow(mDisplay, window, Graphmode_modeline->hdisplay, Graphmode_modeline->vdisplay);
 		XSync(mDisplay, FALSE);
-		XClearWindow(mDisplay, window);		
+		XClearWindow(mDisplay, window);
 	} else {
 		SizeHints.min_width=SizeHints.max_width=plScrLineBytes;
 		SizeHints.min_height=SizeHints.max_height=plScrLines;
@@ -535,7 +532,7 @@ static void TextModeSetState(FontSizeEnum FontSize, int FullScreen)
 	Textmode_SizeHints.flags=PMinSize|PMaxSize|USSize|PSize;
 	Textmode_SizeHints.max_width=default_modeline.hdisplay;
 	Textmode_SizeHints.max_height=default_modeline.vdisplay;
-	
+
 	switch (FontSize)
 	{
 		/* find the min value, if screen is too small, force smaller font */
@@ -687,7 +684,7 @@ static void x11_common_event_loop(void)
 					fprintf(stderr, "Resize income pixels: %d %d\n", event.xresizerequest.width, event.xresizerequest.height);
 					x=event.xresizerequest.width;
 					y=event.xresizerequest.height;
-	
+
 					switch (plUseFont)
 					{
 						case _4x4:
@@ -738,6 +735,7 @@ static void x11_common_event_loop(void)
 				key=0;
 				if ((n_chars==1)/*&&(buf[0]>=32*/&&ks!=XK_Delete)
 				{
+					/* fprintf (stderr, "PRESS: %d %c, ShiftMask=%d, ControlMask=%d, Mod1Mask=%d\n", buf[0], buf[0], event.xkey.state & ShiftMask, event.xkey.state & ControlMask, event.xkey.state & Mod1Mask); */
 					if ((event.xkey.state&(ShiftMask|ControlMask|Mod1Mask))==ControlMask)
 					{
 						switch (toupper(buf[0]))
@@ -790,17 +788,19 @@ static void x11_common_event_loop(void)
 						case XK_Right:     key=KEY_CTRL_RIGHT;  break;
 						case XK_Left:      key=KEY_CTRL_LEFT;   break;
 						case XK_Page_Up:   key=KEY_CTRL_PGUP;   break;
-						case XK_Page_Down: key=KEY_CTRL_PGDN;   break;	
+						case XK_Page_Down: key=KEY_CTRL_PGDN;   break;
 						case XK_Home:      key=KEY_CTRL_HOME;   break;
 					}
 				} else if ((event.xkey.state&(ControlMask|Mod1Mask))==Mod1Mask)
-				{	
+				{
 				} else if ((event.xkey.state&(ShiftMask|ControlMask|Mod1Mask))==ShiftMask)
 				{
 					switch (ks)
 					{
 						case XK_ISO_Left_Tab:
 						case XK_Tab: ___push_key(KEY_SHIFT_TAB); return;
+						default:
+							___push_key(buf[0]);
 					}
 				} else switch (ks)
 				{
@@ -869,13 +869,13 @@ static void create_window(void)
 	}
 
 	XChangeProperty (mDisplay, window,
-			XA_NET_WM_NAME,
-			XA_UTF8_STRING, 8,
-     			PropModeReplace, (unsigned char *)"Open Cubic Player", 17);
+	                XA_NET_WM_NAME,
+	                XA_UTF8_STRING, 8,
+	                PropModeReplace, (unsigned char *)"Open Cubic Player", 17);
 	XChangeProperty (mDisplay, window,
-			XA_WM_NAME,
-			XA_STRING, 8,
-			PropModeReplace, (unsigned char *)"Open Cubic Player", 17);
+	                XA_WM_NAME,
+	                XA_STRING, 8,
+	                PropModeReplace, (unsigned char *)"Open Cubic Player", 17);
 
 	if (XpmCreatePixmapFromData (mDisplay, window,
 	                             opencubicplayer_xpm,
@@ -887,7 +887,7 @@ static void create_window(void)
 		hints.flags = IconPixmapHint|IconMaskHint;
 		hints.icon_pixmap = icon;
 		hints.icon_mask = icon_mask;
-		XSetWMHints (mDisplay, window, &hints); 	
+		XSetWMHints (mDisplay, window, &hints);
 	}
 
 	GCvalues.function=GXcopy;
@@ -895,7 +895,7 @@ static void create_window(void)
 	{
 		fprintf(stderr, "[x11] Failed to create GC object\n");
 		exit(-1);
-	}		
+	}
 }
 
 static void create_image(void)
@@ -920,13 +920,13 @@ static void create_image(void)
 			fprintf(stderr, "[x11/shm] shmat: %s\n", strerror(errno));
 			exit(-1);
 		}
-		
+
 		image->data = shminfo[0].shmaddr;
 		shminfo[0].readOnly = False;
 		XShmAttach(mDisplay, &shminfo[0]);
-		
+
 		XSync(mDisplay, False);
-		
+
 		shmctl(shminfo[0].shmid, IPC_RMID, 0);
 	} else {
 		if (!(image=XGetImage(mDisplay, window, 0, 0, plScrLineBytes, plScrLines, AllPlanes, ZPixmap)))
@@ -1215,8 +1215,10 @@ static void plSetTextMode(unsigned char x)
 	/*set_state(do_fullscreen);*/
 	TextModeSetState(plUseFont, do_fullscreen);
 	plUseFont=plCurrentFont;
-	
-/*	XSetWMProtocols (mDisplay, window, &wm_delete_window, 1);*/
+
+/*
+	XSetWMProtocols (mDisplay, window, &wm_delete_window, 1);
+*/
 
 	create_image();
 
@@ -1356,7 +1358,7 @@ static void RefreshScreenGraph(void)
 		int Y=0, j;
 
 		if (plDepth==32)
-		{ 
+		{
 			uint32_t *dst;
 			while (1)
 			{
@@ -1368,7 +1370,7 @@ static void RefreshScreenGraph(void)
 				dst_line += image->bytes_per_line;
 			}
 		} else if (plDepth==24)
-		{ 
+		{
 			uint8_t *dst;
 			while (1)
 			{
@@ -1384,7 +1386,7 @@ static void RefreshScreenGraph(void)
 				dst_line += image->bytes_per_line;
 			}
 		} else if (plDepth==16)
-		{ 
+		{
 			uint16_t *dst;
 			while (1)
 			{
@@ -1396,7 +1398,7 @@ static void RefreshScreenGraph(void)
 				dst_line += image->bytes_per_line;
 			}
 		} else if (plDepth==15)
-		{ 
+		{
 			uint16_t *dst;
 			while (1)
 			{
@@ -1408,7 +1410,7 @@ static void RefreshScreenGraph(void)
 				dst_line += image->bytes_per_line;
 			}
 		} else if (plDepth==8)
-		{ 
+		{
 			uint8_t *dst;
 			while (1)
 			{
@@ -1439,7 +1441,7 @@ static void RefreshScreenText(void)
 		return;
 	if (!image)
 		return;
-	
+
 	if (curshape)
 	if (time(NULL)&1)
 		doshape=curshape;
@@ -2189,7 +2191,7 @@ static void RefreshScreenText(void)
 			case _8x8:
 				for (y=0;y<plScrHeight;y++)
 				{
-					uint32_t *scr_precalc = ((uint32_t *)image->data)+y*8*image->bytes_per_line/sizeof(uint32_t);	
+					uint32_t *scr_precalc = ((uint32_t *)image->data)+y*8*image->bytes_per_line/sizeof(uint32_t);
 					for (x=0;x<plScrWidth;x++)
 					{
 						uint32_t f, b;
@@ -2234,7 +2236,7 @@ static void RefreshScreenText(void)
 			case _4x4:
 				for (y=0;y<plScrHeight;y++)
 				{
-					uint32_t *scr_precalc = ((uint32_t *)image->data)+y*4*image->bytes_per_line/sizeof(uint32_t);	
+					uint32_t *scr_precalc = ((uint32_t *)image->data)+y*4*image->bytes_per_line/sizeof(uint32_t);
 					for (x=0;x<plScrWidth;x++)
 					{
 						uint32_t f, b;
@@ -2330,7 +2332,7 @@ static void plDosShell(void)
 {
 	pid_t child;
 	XEvent event;
-	
+
 	if (xvidmode_event_base>=0)
 	{
 		XF86VidModeSwitchToMode(mDisplay, mScreen, &default_modeline);
@@ -2611,10 +2613,10 @@ int x11_init(int use_explicit)
 		return -1;
 
 	plScrMode=255;
-	
+
 	xvidmode_init();
 
-	ewmh_init();	
+	ewmh_init();
 
 	_plSetGraphMode=__plSetGraphMode;
 	_gdrawstr=generic_gdrawstr;
@@ -2646,7 +2648,7 @@ int x11_init(int use_explicit)
 #else
 	_idrawbar=drawbar;
 #endif
-		
+
 	_conRestore=conRestore;
 	_conSave=conSave;
 	_plDosShell=plDosShell;
